#!/bin/sh

# usage: CollectProductInfo.sh [-i iwss_home] [-d target_file_location] [-f target_file_name] [-s setting_str]
# -s "CollectSystemInfo=0,CoreDump=0,FileList=0" : Turn off "CollectSystemInfo", "CoreDump", "FileList"

Module_Name=CollectProductInfo

case $1 in
	"-i")
		iwss_home=$2
		;;
	"-d")
		target_file_location=$2
		;;
	"-f")
		target_file_name=$2
		;;
	"-s")
		setting_str=$2
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$1]"
		exit 1
		;;
esac

case $3 in
	"-i")
		iwss_home=$4
		;;
	"-d")
		target_file_location=$4
		;;
	"-f")
		target_file_name=$4
		;;
	"-s")
		setting_str=$4
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$3]"
		exit 1
		;;
esac

case $5 in
	"-i")
		iwss_home=$6
		;;
	"-d")
		target_file_location=$6
		;;
	"-f")
		target_file_name=$6
		;;
	"-s")
		setting_str=$6
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$5]"
		exit 1
		;;
esac

case $7 in
	"-i")
		iwss_home=$8
		;;
	"-d")
		target_file_location=$8
		;;
	"-f")
		target_file_name=$8
		;;
	"-s")
		setting_str=$8
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$7]"
		exit 1
		;;
esac

# Parser setting_str
if [ ! -z "$setting_str" ] ; then
	bDebugLogTurnOn=`echo "$setting_str" | grep DebugLog= | sed 's/^.*DebugLog=//g' | sed 's/,.*$//g'`
	bCollectBasicInfo=`echo "$setting_str" | grep BasicInfo= | sed 's/^.*BasicInfo=//g' | sed 's/,.*$//g'`
	bCollectLogList=`echo "$setting_str" | grep LogList= | sed 's/^.*LogList=//g' | sed 's/,.*$//g'`
	bCollectFileList=`echo "$setting_str" | grep FileList= | sed 's/^.*FileList=//g' | sed 's/,.*$//g'`
	bCollectProductIni=`echo "$setting_str" | grep ProductIni= | sed 's/^.*ProductIni=//g' | sed 's/,.*$//g'`
	bCollectTomcatIni=`echo "$setting_str" | grep TomcatIni= | sed 's/^.*TomcatIni=//g' | sed 's/,.*$//g'`
	bCollectAUIni=`echo "$setting_str" | grep AUIni= | sed 's/^.*AUIni=//g' | sed 's/,.*$//g'`
	bCollectAUBackupIni=`echo "$setting_str" | grep AUBackupIni= | sed 's/^.*AUBackupIni=//g' | sed 's/,.*$//g'`
	bCollectODBCIni=`echo "$setting_str" | grep ODBCIni= | sed 's/^.*ODBCIni=//g' | sed 's/,.*$//g'`
	bCollectDBInfo=`echo "$setting_str" | grep DBInfo= | sed 's/^.*DBInfo=//g' | sed 's/,.*$//g'`
	bCollectPostgreIni=`echo "$setting_str" | grep PostgreIni= | sed 's/^.*PostgreIni=//g' | sed 's/,.*$//g'`
	bCollectLicenseInfo=`echo "$setting_str" | grep LicenseInfo= | sed 's/^.*LicenseInfo=//g' | sed 's/,.*$//g'`
	bCollectHotfix=`echo "$setting_str" | grep Hotfix= | sed 's/^.*Hotfix=//g' | sed 's/,.*$//g'`
	bCollectTMICfg=`echo "$setting_str" | grep TMICfg= | sed 's/^.*TMICfg=//g' | sed 's/,.*$//g'`
	bCollectTMIEntityCfg=`echo "$setting_str" | grep TMIEntityCfg= | sed 's/^.*TMIEntityCfg=//g' | sed 's/,.*$//g'`
	bCollectMCPIni=`echo "$setting_str" | grep MCPIni= | sed 's/^.*MCPIni=//g' | sed 's/,.*$//g'`
	bCollectMCPProductProfile=`echo "$setting_str" | grep MCPProductProfile= | sed 's/^.*MCPProductProfile=//g' | sed 's/,.*$//g'`
	bCollectIWSACfg=`echo "$setting_str" | grep IWSACfg= | sed 's/^.*IWSACfg=//g' | sed 's/,.*$//g'`
	bCollectCustomizedList=`echo "$setting_str" | grep CustomizedList= | sed 's/^.*CustomizedList=//g' | sed 's/,.*$//g'`
	bCollectCustomizedMsg=`echo "$setting_str" | grep CustomizedMsg= | sed 's/^.*CustomizedMsg=//g' | sed 's/,.*$//g'`
	bCollectIntelliWebPerfInfo=`echo "$setting_str" | grep IntelliWebPerfInfo= | sed 's/^.*IntelliWebPerfInfo=//g' | sed 's/,.*$//g'`
fi

CURDATE=`date '+%Y%m%d'`
IWSS_HOME_CONFIG=/etc/iscan/pkg/ISVWROOT
IWSS_HOME=/var/iwss
CURRENT_DIR=`dirname "$0"`
TARGET_FILE_NAME=ProductInfo_$CURDATE.txt
TARGET_INI_NAME=ProductIni
TARGET_INI_FOLDER_NAME=${TARGET_INI_NAME}_${CURDATE}
TARGET_DIR=CDT_TEMP
LOG_DIR=log

HOTFIX_INFO=/etc/iscan/pkg/ISHOTFIX

CDT_CONFIG_FILE_NAME=CDT_Config.ini
CDT_CONFIG_TEMP_FILE_NAME=CDT_Config.ini.tmp

PATH=/sbin:$PATH

TEMP_CURRENT_DIR=`echo $CURRENT_DIR | grep '^\/'`
	
# Not start with "/"
if [ -z "$TEMP_CURRENT_DIR" ] ; then	
	CURRENT_DIR=`pwd`/$CURRENT_DIR
fi

TMI_AGENTDIR_CONFIG=/etc/iscan/pkg/ISAGENT
MCPDIR_CONFIG=/etc/iscan/pkg/ISAGENT_MCP

bCreateConfigTemp=0

# Create $CDT_CONFIG_TEMP_FILE_NAME (without comments) if not exist
if [ ! -f $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME ] ; then	
	bCreateConfigTemp=1
	cat $CURRENT_DIR/$CDT_CONFIG_FILE_NAME | sed 's/;.*$//g' | sed '/^$/d' > $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME
	chmod a+rw $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME > /dev/null 2> /dev/null
fi

# Check/get $iwss_home
if [ -z "$iwss_home" ] ; then
	# Get iwss_home from IWSS_HOME_CONFIG file
	if [ -f $IWSS_HOME_CONFIG ]; then
  		iwss_home=`cat $IWSS_HOME_CONFIG`
  		echo "Get IWSS Home directory = [$iwss_home] from [$IWSS_HOME_CONFIG]"
	fi
	
	if [ -z "$iwss_home" ] ; then
		iwss_home=$IWSS_HOME	
	fi
	
	# Confirm the default iwss_home with user	
	#echo -n "IWSS home directory ? [$iwss_home]  "
	#read TMP
	#if [ ! -z "$TMP" ] ; then
	#	iwss_home=$TMP
	#fi
fi

# Check/get $target_file_location
if [ -z "$target_file_location" ] ; then
	target_file_location=$CURRENT_DIR/$TARGET_DIR
	
	# Confirm the default target file location with user			
	#echo -n "Target product info directory ? [$target_file_location]  "
	#read TMP
	#if [ ! -z "$TMP" ] ; then
	#	target_file_location=$TMP
	#fi
fi

# Check/get $target_file_name
if [ -z "$target_file_name" ] ; then
	target_file_name=$TARGET_FILE_NAME
	
	# Confirm the default target file name with user	
	#echo -n "Target product info file name ? [$TARGET_FILE_NAME]  "
	#read TMP
	#if [ ! -z "$TMP" ] ; then
	#	target_file_name = $TMP
	#fi
fi

# Check and create [$target_file_location] if not exit
if [ ! -d $target_file_location ]; then	
	mkdir -p -m 777 $target_file_location
fi

# Check and create [$target_file_location/$TARGET_INI_FOLDER_NAME] if not exit
if [ ! -d $target_file_location/$TARGET_INI_FOLDER_NAME ]; then
  mkdir -m 777 $target_file_location/$TARGET_INI_FOLDER_NAME
fi

# Check for Debug Log is turned on or not from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bDebugLogTurnOn" ] ; then 
	bDebugLogTurnOn=`sed -e '/^\[Common\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep DebugLog= | cut -d'=' -f2`
fi
	
if [ $bDebugLogTurnOn -ne 0 ] ; then
	if [ -d $iwss_home/log ] ; then
		CDT_LOG_FILE_NAME=$iwss_home/log/CDT.log.$CURDATE
	else
		CDT_LOG_FILE_NAME=$CURRENT_DIR/CDT.log.$CURDATE
	fi
	
	touch $CDT_LOG_FILE_NAME
	chmod a+rw $CDT_LOG_FILE_NAME > /dev/null 2> /dev/null
else
	CDT_LOG_FILE_NAME=/dev/null	
fi

echo "`date` [$Module_Name] IWSS home directory [$iwss_home]" | tee -a $CDT_LOG_FILE_NAME | more

echo "`date` [$Module_Name] Target product info directory [$target_file_location]" | tee -a $CDT_LOG_FILE_NAME | more

echo "`date` [$Module_Name] Target product info file name [$target_file_name]" | tee -a $CDT_LOG_FILE_NAME | more

TMIDIR=$iwss_home/TMI

# Get TMI_AGENTDIR from TMI_AGENTDIR_CONFIG file
if [ -f $TMI_AGENTDIR_CONFIG ]; then
	TMI_AGENTDIR=`cat /etc/iscan/pkg/ISAGENT`
 	echo "`date` [$Module_Name] Get TMI AGENT directory = [$TMI_AGENTDIR] from [$TMI_AGENTDIR_CONFIG]" | tee -a $CDT_LOG_FILE_NAME | more
fi
	
if [ -z "$TMI_AGENTDIR" ] ; then
	TMI_AGENTDIR=$iwss_home/ISAGENT
fi

echo "`date` [$Module_Name] TMI AGENT directory [$TMI_AGENTDIR]" | tee -a $CDT_LOG_FILE_NAME | more

# Get MCPDIR from MCPDIR_CONFIG file
if [ -f $MCPDIR_CONFIG ]; then
	MCPDIR=`cat /etc/iscan/pkg/ISAGENT_MCP`
 	echo "`date` [$Module_Name] Get MCP directory = [$MCPDIR] from [$MCPDIR_CONFIG]" | tee -a $CDT_LOG_FILE_NAME | more
fi
	
if [ -z "$MCPDIR" ] ; then
	MCPDIR=$iwss_home/ISAGENT_MCP
fi

echo "`date` [$Module_Name] MCP directory [$MCPDIR]" | tee -a $CDT_LOG_FILE_NAME | more

#while [ -f $target_file_location/$target_file_name ]
#do
#	echo -n "File already exists, target product info filename ? [$target_file_name]  "
#	read TMP
#	if [ ! -z "$TMP" ] ; then
#		target_file_name=$TMP
#	else
#		break
#	fi
#done

echo "`date` [$Module_Name] Target Product Info File Name = [$target_file_name]" | tee -a $CDT_LOG_FILE_NAME | more

# Check for "collect product basic info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectBasicInfo" ] ; then 
	bCollectBasicInfo=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep BasicInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi 

if [ $bCollectBasicInfo -ne 0 ] ; then
 	echo "`date` [$Module_Name] Collect BasicInfo" | tee -a $CDT_LOG_FILE_NAME | more
 	
	# Get Basic information
	echo "---------- Basic Information ----------" > $target_file_location/$target_file_name
	
	chmod a+rw $target_file_location/$target_file_name > /dev/null 2> /dev/null

	echo "HomeDir=$iwss_home" >> $target_file_location/$target_file_name

	sed -n '/ProductName/p' $iwss_home/intscan.ini >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo "ProductVersion=`$iwss_home/iwssd -v`" >> $target_file_location/$target_file_name
	
	# Get engine/pattern version
	echo -e "\n[Engine/Pattern Version]" >> $target_file_location/$target_file_name
	$iwss_home/getupdate INFO >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi	

# Check for "collect product log file list or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectLogList" ] ; then 
	bCollectLogList=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep LogList= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectLogList -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect LogList" | tee -a $CDT_LOG_FILE_NAME | more
	
	# Get Log Files List
	echo -e "\n---------- Log Files List ----------" >> $target_file_location/$target_file_name

	ls -RAlh $iwss_home/$LOG_DIR/ >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME	
fi

# Check for "collect product file list or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectFileList" ] ; then
	bCollectFileList=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep FileList= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectFileList -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect FileList" | tee -a $CDT_LOG_FILE_NAME | more
	# Get Files Listed Under the Product Home Directory exclusive of directories mailq/, quarantine/, AdminUI/, and PostgreSQL/
	# The files/folders list of directories mailq/, quarantine/, AdminUI/, and PostgreSQL/ are too much and useless	
	echo -e "\n---------- Files Listed Under the Product Home Directory ----------" >> $target_file_location/$target_file_name
	
	echo -e "\nProduct Home Directory = [$iwss_home]" >> $target_file_location/$target_file_name
	
	cd $iwss_home
	
	echo -e "\n[First Level Files/Folders List]" >> $target_file_location/$target_file_name
	
	ls -Alh $iwss_home/ >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	echo -e "\n[Sub-directory Files/Folders List] - exclusive of mailq/ and quarantine/" >> $target_file_location/$target_file_name
	
	ls -RAlh `ls -F $iwss_home/ | grep -e '.*/$' | grep -v mailq | grep -v quarantine` >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	echo -e "\n[Symbolic-Link Sub-directory Files/Folders List] - exclusive of AdminUI/ and PostgreSQL/" >> $target_file_location/$target_file_name
	
	ls -RAlh `ls -F $iwss_home/ | grep -e '.*@$'  | grep -v AdminUI | grep -v PostgreSQL | sed 's/@$/\//g'` >> $target_file_location/$target_file_name 2> /dev/null

	cd - > /dev/null 2> /dev/null

	# Collect files info under /usr/iwss
	echo -e "\n---------- Files Listed Under the /usr/iwss ----------" >> $target_file_location/$target_file_name
	cd /usr/iwss

	echo -e "\n[First Level Files/Folders List]" >> $target_file_location/$target_file_name
	ls -Alh /usr/iwss/ >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo -e "\n[Sub-directory Files/Folders List] - exclusive of PostgreSQL/" >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	ls -RAlh `ls -F /usr/iwss/ | grep -e '.*/$' | grep -v PostgreSQL` >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo -e "\n------------ End of collecting file info under /usr/iwss ------------" >> $target_file_location/$target_file_name
	cd - > /dev/null 2> /dev/null
fi	

#if [ $? -eq 0 ] ; then
#	echo "Product information is saved in $target_file_location/$target_file_name" | tee -a $CDT_LOG_FILE_NAME | more
#else
#	echo "Error occurred" | tee -a $CDT_LOG_FILE_NAME | more
#fi

# Check for "collect product config files or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectProductIni" ] ; then
	bCollectProductIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep ProductIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectProductIni -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect ProductIni" | tee -a $CDT_LOG_FILE_NAME | more
	# pni, ini, dsc, lst, conf files
	FILE_LIST="$iwss_home/*.pni $iwss_home/*.dsc $iwss_home/*.ini $iwss_home/*.lst $iwss_home/*.conf"
fi

# Check for "collect product tomcat config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectTomcatIni" ] ; then
	bCollectTomcatIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep TomcatIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectTomcatIni -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect TomcatIni" | tee -a $CDT_LOG_FILE_NAME | more
	# tomcat config files	
	FILE_LIST="$FILE_LIST $iwss_home/AdminUI/tomcat/conf/*"
fi

# Check for "collect product AU config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectAUIni" ] ; then
	bCollectAUIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep AUIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectAUIni -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect AUIni" | tee -a $CDT_LOG_FILE_NAME | more
	# AU config files	
	FILE_LIST="$FILE_LIST $iwss_home/lib/*.ini"
fi

# Check for "collect product AU backup config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectAUBackupIni" ] ; then
	bCollectAUBackupIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep AUBackupIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectAUBackupIni -ne 0 ] ; then
	if [ -f $iwss_home/actupdate/AU_Backup/AuBackup.ini ] ; then
		echo "`date` [$Module_Name] Collect AUBackupIni" | tee -a $CDT_LOG_FILE_NAME | more
		# AUBackup config files	
		FILE_LIST="$FILE_LIST $iwss_home/actupdate/AU_Backup/AuBackup.ini"
	else
		echo "`date` [$Module_Name] Collect AUBackupIni but AUBackupIni doesn't existed." | tee -a $CDT_LOG_FILE_NAME | more
	fi		
fi

# Check for "collect product odbc config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectODBCIni" ] ; then
	bCollectODBCIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep ODBCIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectODBCIni -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect ODBCIni" | tee -a $CDT_LOG_FILE_NAME | more
	# unix odbc config files - included in the ini files
	FILE_LIST="$FILE_LIST $iwss_home/odbc.ini $iwss_home/odbcinst.ini"
fi

# Check for "collect database information or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectDBInfo" ] ; then
	bCollectDBInfo=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep DBInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectDBInfo -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect DBInfo" | tee -a $CDT_LOG_FILE_NAME | more

	# Set HOME env for using .pgpass
	HOMEDIR=`echo $HOME`

	HOME=$iwss_home	
	
	DBCollectSettings=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep DBCollectSettings= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
	
	tbCount=`echo $DBCollectSettings | awk 'BEGIN {FS=","} {print NF}'`
	
	echo "`date` [$Module_Name] Total $tbCount tables, CollectSettings=$DBCollectSettings" | tee -a $CDT_LOG_FILE_NAME | more
	
	DBNAME=`sed -e '/^\[Database\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep DB= | cut -d'=' -f2`
	
	USERNAME=`sed -e '/^\[Database\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep User= | cut -d'=' -f2`
		
	i=1
	
	# Export tables	
	while [ $i -le $tbCount ]
	do		
		tbName=`echo "$DBCollectSettings" | cut -d ',' -f $i`
		
		echo "`date` [$Module_Name] Export $tbName" | tee -a $CDT_LOG_FILE_NAME | more	
		
		/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "copy $tbName to '$target_file_location/$TARGET_INI_FOLDER_NAME/$tbName.csv' using delimiters ',';" >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
		
		i=`expr $i + 1`
	done
	
	HOME=$HOMEDIR
fi

# Check for "collect product postgre config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectPostgreIni" ] ; then
	bCollectPostgreIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep PostgreIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectPostgreIni -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect PostgreIni" | tee -a $CDT_LOG_FILE_NAME | more
	# postgre config files
	FILE_LIST="$FILE_LIST $iwss_home/postgres/pgdata/*.conf"
fi

# Check for "collect product licesne info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectLicenseInfo" ] ; then
	bCollectLicenseInfo=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep LicenseInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectLicenseInfo -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect LicenseInfo" | tee -a $CDT_LOG_FILE_NAME | more
	# License info files	
	FILE_LIST="$FILE_LIST $iwss_home/*.dat"
fi

# Check for "collect hotfix info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectHotfix" ] ; then
	bCollectHotfix=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep Hotfix= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectHotfix -ne 0 ] ; then
	if [ -f $HOTFIX_INFO ] ; then
		echo "`date` [$Module_Name] Collect Hotfix" | tee -a $CDT_LOG_FILE_NAME | more
		# hotfix information
		FILE_LIST="$FILE_LIST $HOTFIX_INFO"
	else
		echo "`date` [$Module_Name] Collect Hotfix but Hotfix isn't installed." | tee -a $CDT_LOG_FILE_NAME | more
	fi
fi

# Check for "collect CM Agent (TMI) config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectTMICfg" ] ; then
	bCollectTMICfg=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep TMICfg= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectTMICfg -ne 0 ] ; then
	if [ -f $TMI_AGENTDIR_CONFIG ] ; then
		echo "`date` [$Module_Name] Collect TMICfg" | tee -a $CDT_LOG_FILE_NAME | more
		# TMICfg information	
		FILE_LIST="$FILE_LIST $TMIDIR/TMI.cfg" 
	else
		echo "`date` [$Module_Name] Collect TMICfg but TMI isn't installed." | tee -a $CDT_LOG_FILE_NAME | more
	fi
fi

# Check for "collect CM Agent (TMI) config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectTMIEntityCfg" ] ; then
	bCollectTMIEntityCfg=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep TMIEntityCfg= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

# Check for "collect CM Agent (TMI) entity config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ $bCollectTMIEntityCfg -ne 0 ] ; then
	if [ -f $TMI_AGENTDIR_CONFIG ] ; then
		echo "`date` [$Module_Name] Collect TMIEntityCfg" | tee -a $CDT_LOG_FILE_NAME | more
		# TMIEntityCfg information	
		FILE_LIST="$FILE_LIST $TMI_AGENTDIR/Entity.cfg" 
	else
		echo "`date` [$Module_Name] Collect TMIEntityCfg but TMI isn't installed." | tee -a $CDT_LOG_FILE_NAME | more
	fi
fi

# Check for "collect CM Agent (MCP) config or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectMCPIni" ] ; then
	bCollectMCPIni=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep MCPIni= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectMCPIni -ne 0 ] ; then
	if [ -f $MCPDIR_CONFIG ] ; then
		echo "`date` [$Module_Name] Collect MCPIni" | tee -a $CDT_LOG_FILE_NAME | more
		# MCPIni information	
		FILE_LIST="$FILE_LIST $MCPDIR/*.ini"
	else
		echo "`date` [$Module_Name] Collect MCPIni but MCP isn't installed." | tee -a $CDT_LOG_FILE_NAME | more
	fi
fi

# Check for "collect CM Agent (MCP) product profile or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectMCPProductProfile" ] ; then
	bCollectMCPProductProfile=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep MCPProductProfile= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectMCPProductProfile -ne 0 ] ; then
	if [ -f $MCPDIR_CONFIG ] ; then
		echo "`date` [$Module_Name] Collect MCPProductProfile" | tee -a $CDT_LOG_FILE_NAME | more
		MCPPRODUCTPROFILENAME=`sed -e '/^\[Common\]/,/^\[.*\]/p;d' $MCPDIR/Agent.ini | grep -v -e '^\[.*\]' | grep Profile_File_Name= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
	
		TEMP_MCPPRODUCTPROFILENAME=`echo $MCPPRODUCTPROFILENAME | grep '^\/' 2>>$CDT_LOG_FILE_NAME`
	
		# MCPProductProfile information		
		if [ -z "$TEMP_MCPPRODUCTPROFILENAME" ] ; then	
			FILE_LIST="$FILE_LIST $MCPDIR/$MCPPRODUCTPROFILENAME"
		else
			FILE_LIST="$FILE_LIST $MCPPRODUCTPROFILENAME"
		fi		
	else
		echo "`date` [$Module_Name] Collect MCPProductProfile but MCP isn't installed." | tee -a $CDT_LOG_FILE_NAME | more
	fi
fi

# Check for "collect IWSA config files or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectIWSACfg" ] ; then
	bCollectIWSACfg=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep IWSACfg= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi

if [ $bCollectIWSACfg -ne 0 ] ; then
	if [ -f /etc/conf/ggb.conf ] ; then
		echo "`date` [$Module_Name] Collect IWSACfg" | tee -a $CDT_LOG_FILE_NAME | more
		# ggb.conf
		FILE_LIST="$FILE_LIST /etc/conf/ggb.conf"
	else
		echo "`date` [$Module_Name] Collect IWSACfg but ggb.conf doesn't existed." | tee -a $CDT_LOG_FILE_NAME | more
	fi
fi

# Check for "collect product customized list or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectCustomizedList" ] ; then
	bCollectCustomizedList=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep CustomizedList= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectCustomizedList -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect Customized list files" | tee -a $CDT_LOG_FILE_NAME | more
	# Customized notification / blocking page files	
	
	# ClientConnectionQuotaWhiteList.ini
	TEMP_LIST_FILE="`sed -e '/^\[main\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep client_connection_quota_white_list_file= | cut -d'=' -f2`"
	
	# ServerIPWhiteList_ftp.ini	
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[ftp\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep skip_server_ip_file= | cut -d'=' -f2`"
	
	# ClientACL_ftp.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[ftp\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep client_acl_file= | cut -d'=' -f2`"
	
	# HttpPortPermissions_ftp.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[ftp\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep port_acl_file= | cut -d'=' -f2`"
	
	# ClientACL_http.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[http\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep client_acl_file= | cut -d'=' -f2`"
	
	# HttpPortPermissions_http.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[http\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep port_acl_file= | cut -d'=' -f2`"
	
	# HttpsConnectACL_http.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[http\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep https_connect_acl_file= | cut -d'=' -f2`"
	
	# ServerIPWhiteList_http.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[Scan-configuration\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep skip_server_ip_file= | cut -d'=' -f2`"
	
	# URLB.ini	
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[URL-blocking\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep normalLists= | cut -d'=' -f2`"
	
	# OPP.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[URL-blocking\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep OPPLists= | cut -d'=' -f2`"
	
	# infectedB.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[URL-blocking\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep infectedLists= | cut -d'=' -f2`"
		
	# TrustedURLs.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[URL-trusting\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep normalLists= | cut -d'=' -f2`"
		
	# ServerFarmMemberList_http.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[Server-farm\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep farm_member_file= | cut -d'=' -f2`"
	
	#dcs_serverlist.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[DCS\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep dcs_list= | cut -d'=' -f2`"
	
	# spywareiplist.ini
	TEMP_LIST_FILE="$TEMP_LIST_FILE `sed -e '/^\[DCS\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep spywareip_list= | cut -d'=' -f2`"
	
	if [ -z "$TEMP_LIST_FILE" ] ; then	
		FILE_LIST="$FILE_LIST $iwss_home/*.ini"
	else
		FILE_LIST="$FILE_LIST $TEMP_LIST_FILE"
	fi			
fi

# Check for "collect product customized notification / blocking page or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectCustomizedMsg" ] ; then
	bCollectCustomizedMsg=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep CustomizedMsg= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectCustomizedMsg -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect Customized message files" | tee -a $CDT_LOG_FILE_NAME | more
	# Customized notification / blocking page files	
	
	# filetypeblock_warnmsg.txt
	TEMP_MESSAGE_FILE="`sed -e '/^\[http\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep addtl_type_message= | cut -d'=' -f2`"
	
	# virusdownload_warnmsg.txt
	TEMP_MESSAGE_FILE="$TEMP_MESSAGE_FILE `sed -e '/^\[http\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep addtl_virus_message= | cut -d'=' -f2`"
	
	# urlblock_warnmsg.txt
	TEMP_MESSAGE_FILE="$TEMP_MESSAGE_FILE `sed -e '/^\[Request-scan\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep addtl_url_block_message= | cut -d'=' -f2`"
	
	# virusupload_warnmsg.txt
	TEMP_MESSAGE_FILE="$TEMP_MESSAGE_FILE `sed -e '/^\[Request-scan\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep addtl_virus_message= | cut -d'=' -f2`"
	
	# mmc_warnmsg.txt
	TEMP_MESSAGE_FILE="$TEMP_MESSAGE_FILE `sed -e '/^\[mmc\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep addtl_mmc_message= | cut -d'=' -f2`"
	
	# dcsredirect.txt
	TEMP_MESSAGE_FILE="$TEMP_MESSAGE_FILE `sed -e '/^\[DCS\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep redirect_message= | cut -d'=' -f2`"
	
	# filetypeblock_warnmsg_ftp.txt
	TEMP_MESSAGE_FILE="$TEMP_MESSAGE_FILE `sed -e '/^\[ftp\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep addtl_type_message= | cut -d'=' -f2`"
	
	if [ -z "$TEMP_MESSAGE_FILE" ] ; then	
		FILE_LIST="$FILE_LIST $iwss_home/*.txt"
	else
		FILE_LIST="$FILE_LIST $TEMP_MESSAGE_FILE"
	fi			
fi
 
# Check for "collect product IntelliWeb performance information or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectIntelliWebPerfInfo" ] ; then
	bCollectIntelliWebPerfInfo=`sed -e '/^\[ProductInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep IntelliWebPerfInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectIntelliWebPerfInfo -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect IntelliWeb performance information" | tee -a $CDT_LOG_FILE_NAME | more
	
	# Set HOME env for using .pgpass
	HOMEDIR=`echo $HOME`

	HOME=$iwss_home	
	
	DBNAME=`sed -e '/^\[Database\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep DB= | cut -d'=' -f2`
	
	USERNAME=`sed -e '/^\[Database\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep User= | cut -d'=' -f2`
		
	# IntelliWeb performance information		
	echo -e "\n---------- IntelliWeb Performance Information ----------" >> $target_file_location/$target_file_name

	BeginTime=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select date_field from tb_res_utilization where resource_type='11' order by date_field asc limit 1;" | grep : | sed 's/^ //g' 2>>$CDT_LOG_FILE_NAME`
	EndTime=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select date_field from tb_res_utilization where resource_type='11' order by date_field desc limit 1;" | grep : | sed 's/^ //g' 2>>$CDT_LOG_FILE_NAME`
	
	if [ -z "$BeginTime" ] ; then
		echo -e "There is no IntelliWeb Performance Data!" >> $target_file_location/$target_file_name
	else
	echo -e "Begin Time = [$BeginTime], End Time = [$EndTime]" >> $target_file_location/$target_file_name
	
	WRS_CACHEHIT_COUNT=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select sum(usage1) from tb_res_utilization where resource_type='11';" | sed -n '3p' | sed 's/^ *//g' 2>>$CDT_LOG_FILE_NAME`
	WRS_DNSHIT_COUNT=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select sum(usage1) from tb_res_utilization where resource_type='12';" | sed -n '3p' | sed 's/^ *//g' 2>>$CDT_LOG_FILE_NAME`
	WRS_HTTPHIT_COUNT=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select sum(usage1) from tb_res_utilization where resource_type='13';" | sed -n '3p' | sed 's/^ *//g' 2>>$CDT_LOG_FILE_NAME`
	WRS_MISS_COUNT=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select sum(usage1) from tb_res_utilization where resource_type='14';" | sed -n '3p' | sed 's/^ *//g' 2>>$CDT_LOG_FILE_NAME`
	WRS_REMOTE_SCANFLAGOFF_COUNT=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select sum(usage1) from tb_res_utilization where resource_type='15';" | sed -n '3p' | sed 's/^ *//g' 2>>$CDT_LOG_FILE_NAME`
	WRS_CACHE_SCANFLAGOFF_COUNT=`/usr/iwss/PostgreSQL/bin/psql $DBNAME $USERNAME -c "select sum(usage1) from tb_res_utilization where resource_type='16';" | sed -n '3p' | sed 's/^ *//g' 2>>$CDT_LOG_FILE_NAME`	
	WRS_SCANFLAGOFF_COUNT=`echo "$WRS_REMOTE_SCANFLAGOFF_COUNT $WRS_CACHE_SCANFLAGOFF_COUNT" | awk '{printf "%d\n", $1 + $2}'`
	
	# Handle division by zero
	if [ $WRS_CACHEHIT_COUNT -eq 0 ] && [ $WRS_DNSHIT_COUNT -eq 0 ] && [ $WRS_HTTPHIT_COUNT -eq 0 ] && [ $WRS_MISS_COUNT -eq 0 ]; then
		TOTAL_WRS_QUERY_COUNT=1
	else
		TOTAL_WRS_QUERY_COUNT=`echo "$WRS_CACHEHIT_COUNT $WRS_DNSHIT_COUNT $WRS_HTTPHIT_COUNT $WRS_MISS_COUNT" | awk '{printf "%d\n", $1 + $2 + $3 + $4}'`	
	fi	
	
	WRS_CACHEHIT_RATE=`echo "$WRS_CACHEHIT_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`
	WRS_DNSHIT_RATE=`echo "$WRS_DNSHIT_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`
	WRS_HTTPHIT_RATE=`echo "$WRS_HTTPHIT_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`
	WRS_MISS_RATE=`echo "$WRS_MISS_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`
	WRS_REMOTE_SCANFLAGOFF_RATE=`echo "$WRS_REMOTE_SCANFLAGOFF_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`
	WRS_CACHE_SCANFLAGOFF_RATE=`echo "$WRS_CACHE_SCANFLAGOFF_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`
	WRS_SCANFLAGOFF_RATE=`echo "$WRS_SCANFLAGOFF_COUNT $TOTAL_WRS_QUERY_COUNT" | awk '{printf "%3.2f\n", $1 / $2 * 100}'`	
	
	echo -e "\nTotal WRS (with valid rating data) Count = $TOTAL_WRS_QUERY_COUNT" >> $target_file_location/$target_file_name	
	
	echo -e "WRS Cache Hit Count (Rate) = $WRS_CACHEHIT_COUNT \t($WRS_CACHEHIT_RATE %)" >> $target_file_location/$target_file_name
	echo -e "WRS DNS Hit Count (Rate) = $WRS_DNSHIT_COUNT \t($WRS_DNSHIT_RATE %)" >> $target_file_location/$target_file_name
	echo -e "WRS HTTP Hit Count (Rate) = $WRS_HTTPHIT_COUNT \t($WRS_HTTPHIT_RATE %)" >> $target_file_location/$target_file_name
	echo -e "WRS Miss Count (Rate) = $WRS_MISS_COUNT \t($WRS_MISS_RATE %)" >> $target_file_location/$target_file_name			
	
	echo -e "\nWRS ScanFlag OFF Count (Rate) = $WRS_SCANFLAGOFF_COUNT \t($WRS_SCANFLAGOFF_RATE %)" >> $target_file_location/$target_file_name
	echo -e "\t - Remote ScanFlag OFF Count (Rate) = $WRS_REMOTE_SCANFLAGOFF_COUNT \t($WRS_REMOTE_SCANFLAGOFF_RATE %)" >> $target_file_location/$target_file_name
	echo -e "\t - Cache ScanFlag OFF Count (Rate) = $WRS_CACHE_SCANFLAGOFF_COUNT \t($WRS_CACHE_SCANFLAGOFF_RATE %)" >> $target_file_location/$target_file_name		
	fi
	
	HOME=$HOMEDIR
fi	
	 
# Zip up FILE_LIST (with directory) to target_file_location
if [ ! -z "$FILE_LIST" ] ; then
	echo "`date` [$Module_Name] Zip up $FILE_LIST to $target_file_location/$TARGET_INI_FOLDER_NAME" >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
	tar -czf $target_file_location/$TARGET_INI_FOLDER_NAME/$TARGET_INI_NAME.tgz $FILE_LIST >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
fi	

#if [ $? -eq 0 ] ; then
#	echo "`date` [$Module_Name] Product configuration files are saved in $target_file_location/$TARGET_INI_FOLDER_NAME" | tee -a $CDT_LOG_FILE_NAME | more
#else
#	echo "`date` [$Module_Name] Error occurred during collecting product configuration files" | tee -a $CDT_LOG_FILE_NAME | more
#fi

# Remove $CDT_CONFIG_TEMP_FILE_NAME (without comments) if it is created by this shell script
if [ $bCreateConfigTemp -eq 1 ] ; then
	if [ -f $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME ] ; then
		rm -f $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
	fi
fi
