#!/bin/sh

# usage: CollectSystemInfo.sh [-i iwss_home] [-d target_file_location] [-f target_file_name] [-s setting_str]
# -s "CollectSystemInfo=0,CoreDump=0,FileList=0" : Turn off "CollectSystemInfo", "CoreDump", "FileList"

Module_Name=CollectSystemInfo

case $1 in
	"-i")
		iwss_home=$2
		;;
	"-d")
		target_file_location=$2
		;;
	"-f")
		target_file_name=$2
		;;
	"-s")
		setting_str=$2
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$1]"
		exit 1
		;;
esac

case $3 in
	"-i")
		iwss_home=$4
		;;
	"-d")
		target_file_location=$4
		;;
	"-f")
		target_file_name=$4
		;;
	"-s")
		setting_str=$4
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$3]"
		exit 1
		;;
esac

case $5 in
	"-i")
		iwss_home=$6
		;;
	"-d")
		target_file_location=$6
		;;
	"-f")
		target_file_name=$6
		;;
	"-s")
		setting_str=$6
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$5]"
		exit 1
		;;
esac

case $7 in
	"-i")
		iwss_home=$8
		;;
	"-d")
		target_file_location=$8
		;;
	"-f")
		target_file_name=$8
		;;
	"-s")
		setting_str=$8
		;;
	"")
		;;
	*)
		echo "Incorrect argement [$7]"
		exit 1
		;;
esac

# Parser setting_str
if [ ! -z "$setting_str" ] ; then
	bDebugLogTurnOn=`echo "$setting_str" | grep DebugLog= | sed 's/^.*DebugLog=//g' | sed 's/,.*$//g'`
	bCollectOSInfo=`echo "$setting_str" | grep OSInfo= | sed 's/^.*OSInfo=//g' | sed 's/,.*$//g'`
	bCollectHardwareInfo=`echo "$setting_str" | grep HardwareInfo= | sed 's/^.*HardwareInfo=//g' | sed 's/,.*$//g'`
	bCollectMemoryInfo=`echo "$setting_str" | grep MemoryInfo= | sed 's/^.*MemoryInfo=//g' | sed 's/,.*$//g'`
	bCollectInstalledProgramInfo=`echo "$setting_str" | grep InstalledProgramInfo= | sed 's/^.*InstalledProgramInfo=//g' | sed 's/,.*$//g'`
	bCollectStartupProgramInfo=`echo "$setting_str" | grep StartupProgramInfo= | sed 's/^.*StartupProgramInfo=//g' | sed 's/,.*$//g'`
	bCollectProcessInfo=`echo "$setting_str" | grep ProcessInfo= | sed 's/^.*ProcessInfo=//g' | sed 's/,.*$//g'`
	bCollectNetInfo=`echo "$setting_str" | grep SystemResource= | sed 's/^.*SystemResource=//g' | sed 's/,.*$//g'`
	bCollectSystemResource=`echo "$setting_str" | grep NetInfo= | sed 's/^.*NetInfo=//g' | sed 's/,.*$//g'`
	bCollectDmesgInfo=`echo "$setting_str" | grep DmesgInfo= | sed 's/^.*DmesgInfo=//g' | sed 's/,.*$//g'`
fi

CURDATE=`date '+%Y%m%d'`
IWSS_HOME_CONFIG=/etc/iscan/pkg/ISVWROOT
IWSS_HOME=/var/iwss
CURRENT_DIR=`dirname "$0"`
TARGET_DIR=CDT_TEMP
TARGET_FILE_NAME=SystemInfo_$CURDATE.txt

CDT_CONFIG_FILE_NAME=CDT_Config.ini
CDT_CONFIG_TEMP_FILE_NAME=CDT_Config.ini.tmp

PATH=/sbin:$PATH

TEMP_CURRENT_DIR=`echo $CURRENT_DIR | grep '^\/'`
	
# Not start with "/"
if [ -z "$TEMP_CURRENT_DIR" ] ; then	
	CURRENT_DIR=`pwd`/$CURRENT_DIR
fi

bCreateConfigTemp=0

# Create $CDT_CONFIG_TEMP_FILE_NAME (without comments) if not exist
if [ ! -f $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME ] ; then	
	bCreateConfigTemp=1
	cat $CURRENT_DIR/$CDT_CONFIG_FILE_NAME | sed 's/;.*$//g' | sed '/^$/d' > $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME
	chmod a+rw $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME > /dev/null 2> /dev/null
fi

# Check/get $iwss_home
if [ -z "$iwss_home" ] ; then
	# Get iwss_home from IWSS_HOME_CONFIG file
	if [ -f $IWSS_HOME_CONFIG ]; then
  		iwss_home=`cat $IWSS_HOME_CONFIG`
  		echo "Get IWSS Home directory = [$iwss_home] from [$IWSS_HOME_CONFIG]"
	fi
	
	if [ -z "$iwss_home" ] ; then
		iwss_home=$IWSS_HOME	
	fi
	
	# Confirm the default iwss_home with user	
	#echo -n "IWSS home directory ? [$iwss_home]  "
	#read TMP
	#if [ ! -z "$TMP" ] ; then
	#	iwss_home=$TMP
	#fi
fi

# Check/get $target_file_location
if [ -z "$target_file_location" ] ; then
	target_file_location=$CURRENT_DIR/$TARGET_DIR
	
	# Confirm the default target file location with user	
	#echo -n "Target system info directory ? [$target_file_location]  "
	#read TMP
	#if [ ! -z "$TMP" ] ; then
	#	target_file_location=$TMP
	#fi
fi

# Check/get $target_file_name
if [ -z "$target_file_name" ] ; then	
	target_file_name=$TARGET_FILE_NAME
	
	# Confirm the default target file name with user
	#echo -n "Target system info file name ? [$TARGET_FILE_NAME]  "
	#read TMP
	#if [ ! -z "$TMP" ] ; then
	#	target_file_name = $TMP
	#fi
fi

# Check and create [$target_file_location] if not exit
if [ ! -d $target_file_location ]; then	
	mkdir -p -m 777 $target_file_location
fi

# Check and create [$target_file_location/$TARGET_FOLDER_NAME] if not exit
if [ ! -d $target_file_location/$TARGET_FOLDER_NAME ]; then
  mkdir -m 777 $target_file_location
fi

# Check for Debug Log is turned on or not from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bDebugLogTurnOn" ] ; then 
	bDebugLogTurnOn=`sed -e '/^\[Common\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep DebugLog= | cut -d'=' -f2`
fi
	
if [ $bDebugLogTurnOn -ne 0 ] ; then
	if [ -d $iwss_home/log ] ; then
		CDT_LOG_FILE_NAME=$iwss_home/log/CDT.log.$CURDATE
	else
		CDT_LOG_FILE_NAME=$CURRENT_DIR/CDT.log.$CURDATE
	fi
	
	touch $CDT_LOG_FILE_NAME
	chmod a+rw $CDT_LOG_FILE_NAME > /dev/null 2> /dev/null
else
	CDT_LOG_FILE_NAME=/dev/null	
fi

echo "`date` [$Module_Name] IWSS home directory [$iwss_home]" | tee -a $CDT_LOG_FILE_NAME | more

echo "`date` [$Module_Name] Target system info directory [$target_file_location]" | tee -a $CDT_LOG_FILE_NAME | more

echo "`date` [$Module_Name] Target system info file name [$target_file_name]" | tee -a $CDT_LOG_FILE_NAME | more

#while [ -f $target_file_location/$target_file_name ]
#do	
#	echo -n "File already exists, target system info filename ? [$target_file_name]  "
#	read TMP
#	if [ ! -z "$TMP" ] ; then
#		target_file_name=$TMP
#	else
#		break
#	fi
#done

echo "`date` [$Module_Name] Target System Info File Name = [$target_file_name]" | tee -a $CDT_LOG_FILE_NAME | more

# Check for "collect system OS info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectOSInfo" ] ; then 
	bCollectOSInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep OSInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectOSInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect OSInfo" | tee -a $CDT_LOG_FILE_NAME | more
	
	echo "[Operating System]" > $target_file_location/$target_file_name
	
	chmod a+rw $target_file_location/$target_file_name > /dev/null 2> /dev/null
	
	# Get Operating System information	
	if [ -f /etc/asianux-release ]; then
		echo "`date` [$Module_Name] > cat /etc/SuSE-release" | tee -a $CDT_LOG_FILE_NAME | more
  		cat /etc/SuSE-release > $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	elif [ -f /etc/miraclelinux-release ]; then
		echo "`date` [$Module_Name] > cat /etc/miraclelinux-release" | tee -a $CDT_LOG_FILE_NAME | more
  		cat /etc/miraclelinux-release >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	elif [ -f /etc/turbolinux-release ]; then
		echo "`date` [$Module_Name] > cat /etc/turbolinux-release" | tee -a $CDT_LOG_FILE_NAME | more
  		cat /etc/turbolinux-release >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	elif [ -f /etc/redhat-release ]; then
		echo "`date` [$Module_Name] > cat /etc/redhat-release" | tee -a $CDT_LOG_FILE_NAME | more
  		cat /etc/redhat-release >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	elif [ -f /etc/SuSE-release ]; then
		echo "`date` [$Module_Name] > cat /etc/SuSE-release" | tee -a $CDT_LOG_FILE_NAME | more
  		cat /etc/SuSE-release >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	else
		echo "`date` [$Module_Name] > uname -a" | tee -a $CDT_LOG_FILE_NAME | more
  		kernelName=`uname -a 2>>$CDT_LOG_FILE_NAME`
		
		if [ ! -z "$kernelName" ] ; then
			echo "$kernelName" >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
		else			
  			echo "Unknown" >> $target_file_location/$target_file_name
		fi
	fi

	# Get Computer Name
	echo -e "\n[Computer Name]" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > hostname" | tee -a $CDT_LOG_FILE_NAME | more
	hostname >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get User Information
	echo -e "\n[User Information]" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > id" | tee -a $CDT_LOG_FILE_NAME | more
	id >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get Elapsed time system has been running
	echo -e "\n[Elapsed time system has been running]" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > uptime" | tee -a $CDT_LOG_FILE_NAME | more
	uptime >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get Current Local Time
	echo -e "\n[Current Local Time]" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > date" | tee -a $CDT_LOG_FILE_NAME | more
	date >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME	
fi

# Check for "collect system hardware info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectHardwareInfo" ] ; then 
	bCollectHardwareInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep HardwareInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectHardwareInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect HardwareInfo" | tee -a $CDT_LOG_FILE_NAME | more
	# Get Hardware Information
	echo -e "\n[Hardware Information]" >> $target_file_location/$target_file_name

	echo "	[CPU] (from /proc/cpuinfo)" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > cat /proc/cpuinfo" | tee -a $CDT_LOG_FILE_NAME | more
	cat /proc/cpuinfo >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get Disk Information
	echo -e "\n[Disk Information] (Run Command \"df\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > df" | tee -a $CDT_LOG_FILE_NAME | more
	df >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi

# Check for "collect system memory info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectMemoryInfo" ] ; then 
	bCollectMemoryInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep MemoryInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectMemoryInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect MemoryInfo" | tee -a $CDT_LOG_FILE_NAME | more
	# Get Memory Information
	echo -e "\n[Physical Memory] (from /proc/meminfo)" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > cat /proc/meminfo" | tee -a $CDT_LOG_FILE_NAME | more
	cat /proc/meminfo >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo -e "\n[Swap File] (from /proc/spwas)" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > cat /proc/swaps" | tee -a $CDT_LOG_FILE_NAME | more
	cat /proc/swaps >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi

# Check for "collect system installed program info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectInstalledProgramInfo" ] ; then 
	bCollectInstalledProgramInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep InstalledProgramInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectInstalledProgramInfo -ne 0 ] ; then
	echo "`date` [$Module_Name] Collect InstalledProgramInfo" | tee -a $CDT_LOG_FILE_NAME | more	
	# Get Program Installed
	echo -e "\n[Program Installed] (Run Command \"rpm -qa\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > rpm -qa" | tee -a $CDT_LOG_FILE_NAME | more
	rpm -qa >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi	

# Check for "collect system startup program info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectStartupProgramInfo" ] ; then 
	bCollectStartupProgramInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep StartupProgramInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectStartupProgramInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect StartupProgramInfo" | tee -a $CDT_LOG_FILE_NAME | more
	# Get Startup Programs
	echo -e "\n[Startup Programs]" >> $target_file_location/$target_file_name

	echo "Retrieve Information from chkconfig --list" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > chkconfig --list" | tee -a $CDT_LOG_FILE_NAME | more
	chkconfig --list >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo "`date` [$Module_Name] > runlevel" | tee -a $CDT_LOG_FILE_NAME | more
	RUNLEVEL=`runlevel | sed 's/^.*N //g' | sed 's/,.*$//g' 2>>$CDT_LOG_FILE_NAME`

	echo -e "\nRun level = $RUNLEVEL" >> $target_file_location/$target_file_name
 
	echo "Retrieve Information from /etc/rc.d/rc$RUNLEVEL.d" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > ls -Al /etc/rc.d/rc$RUNLEVEL.d/" | tee -a $CDT_LOG_FILE_NAME | more
	ls -Al /etc/rc.d/rc$RUNLEVEL.d/ >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi

# Check for "collect system process info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectProcessInfo" ] ; then 
	bCollectProcessInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep ProcessInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectProcessInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect ProcessInfo" | tee -a $CDT_LOG_FILE_NAME | more
	
	# Get Processes Running
	echo -e "\n[Processes Running] (Run Command \"ps -eo user,pid,ppid,c,stime,tty,vsz,rss,time,args\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > ps -eo user,pid,ppid,c,stime,tty,vsz,rss,time,args" | tee -a $CDT_LOG_FILE_NAME | more
	ps -eo user,pid,ppid,c,stime,tty,vsz,rss,time,args >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	# Get HTTP Daemon Processes Count
	echo -e "\n[HTTP Daemon Processes Count] (Run Command \"ps ax | grep iwssd | grep -v grep | wc -l\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > ps ax | grep iwssd | grep -v grep | wc -l" | tee -a $CDT_LOG_FILE_NAME | more
	ps ax | grep iwssd | grep -v grep | wc -l >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get FTP Daemon Processes Count
	echo -e "\n[FTP Daemon Processes Count] (Run Command \"ps ax | grep isftpd | grep -v grep | wc -l\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > ps ax | grep isftpd | grep -v grep | wc -l" | tee -a $CDT_LOG_FILE_NAME | more
	ps ax | grep isftpd | grep -v grep | wc -l >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi

# Check for "collect system network info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectNetInfo" ] ; then 
	bCollectNetInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep NetInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectNetInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect NetInfo" | tee -a $CDT_LOG_FILE_NAME | more
	
	# Get active network interface
	echo -e "\n[Active Network Interface] Active network interface (Run Command \"ifconfig\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > ifconfig" | tee -a $CDT_LOG_FILE_NAME | more
	ifconfig >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	# Get all network interface
	echo -e "\n[All Network Interface] All network interface (Run Command \"ifconfig -a\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > ifconfig -a" | tee -a $CDT_LOG_FILE_NAME | more
	ifconfig -a >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get iptable
	echo -e "\n[iptable] (Run Command \"iptables -L\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > iptables -L" | tee -a $CDT_LOG_FILE_NAME | more
	/etc/iscan/AdminUI/uihelper "/sbin/iptables -L" >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get iptable -- NAT table
	echo -e "\n[iptable -- NAT table] (Run Command \"iptables -L -t nat\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > iptables -L -t nat" | tee -a $CDT_LOG_FILE_NAME | more
	/etc/iscan/AdminUI/uihelper "/sbin/iptables -L -t nat" >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get routing table
	echo -e "\n[routing table] (Run Command \"route\")" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > route" | tee -a $CDT_LOG_FILE_NAME | more
	
	# Clear the LD_LIBRARY_PATH before using route command because the library path (/usr/iwss/lib/) of AdminUI
	# incurs route command to link with libssl.so.4 -> libssl.so.0.9.7 and comes with a core dump after execution
	TMP_LD_LIBRARY_PATH=$LD_LIBRARY_PATH

	export LD_LIBRARY_PATH=
	  	
	route >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Set the LD_LIBRARY_PATH back
	export LD_LIBRARY_PATH=$TMP_LD_LIBRARY_PATH

	# Get TCP Active Connection
	echo -e "\n[TCP Active Connection]" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > netstat -tn" | tee -a $CDT_LOG_FILE_NAME | more
	netstat -tn > $target_file_location/TCP_CONNECTION 2>>$CDT_LOG_FILE_NAME
	
	cat $target_file_location/TCP_CONNECTION >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	# Get UDP Active Connection
	echo -e "\n[UDP ACtive Connection]" >> $target_file_location/$target_file_name

	echo "`date` [$Module_Name] > netstat -un" | tee -a $CDT_LOG_FILE_NAME | more
	netstat -un >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
		
	# Get HTTP daemon Connection	
	HTTPPniPath=`sed -e '/^\[main\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep http_pni_path= | cut -d'=' -f2`
	
	HTTP_PORT=`sed -e '/^\[main\]/,/^\[.*\]/p;d' $HTTPPniPath | grep -v -e '^\[.*\]' | grep '^port=' | cut -d'=' -f2`
	
	echo -e "\n[HTTP daemon connections on port $HTTP_PORT]" >> $target_file_location/$target_file_name	
	
	echo "`date` [$Module_Name] HTTP daemon connections on port $HTTP_PORT" | tee -a $CDT_LOG_FILE_NAME | more
	
	grep "^.*\ *.*\ *.*\ *[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}:${HTTP_PORT}.\ *[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}:[0-9]\{1,5\}\ *.*$" $target_file_location/TCP_CONNECTION > $target_file_location/HTTP_CONNECTION
	
	echo -e "\nESTABLISHED State: " >> $target_file_location/$target_file_name
					
	grep ESTA $target_file_location/HTTP_CONNECTION | wc -l >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo "" >> $target_file_location/$target_file_name
	
	grep ESTA $target_file_location/HTTP_CONNECTION >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	echo -e "\nRECV State: " >> $target_file_location/$target_file_name
	
	grep RECV $target_file_location/HTTP_CONNECTION | wc -l >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo "" >> $target_file_location/$target_file_name
	
	grep RECV $target_file_location/HTTP_CONNECTION >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	# Get FTP daemon Connection
	
	FTPPniPath=`sed -e '/^\[ftp\]/,/^\[.*\]/p;d' $iwss_home/intscan.ini | grep -v -e '^\[.*\]' | grep protocol_config_path= | cut -d'=' -f2`
	
	FTP_PORT=`sed -e '/^\[main\]/,/^\[.*\]/p;d' $FTPPniPath | grep -v -e '^\[.*\]' | grep '^port=' | cut -d'=' -f2`
	
	echo -e "\n[FTP daemon connections on port $FTP_PORT ]" >> $target_file_location/$target_file_name
	
	echo "`date` [$Module_Name] FTP daemon connections on port $FTP_PORT" | tee -a $CDT_LOG_FILE_NAME | more	
	
	grep "^.*\ *.*\ *.*\ *[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}:${FTP_PORT}.\ *[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}:[0-9]\{1,5\}\ *.*$" $target_file_location/TCP_CONNECTION > $target_file_location/FTP_CONNECTION
		
	echo -e "\nESTABLISHED State: " >> $target_file_location/$target_file_name
	
	grep ESTA $target_file_location/FTP_CONNECTION | wc -l >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo "" >> $target_file_location/$target_file_name
	
	grep ESTA $target_file_location/FTP_CONNECTION >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	echo "" >> $target_file_location/$target_file_name
	
	echo -e "\nRECV State: " >> $target_file_location/$target_file_name
	
	grep RECV $target_file_location/FTP_CONNECTION | wc -l >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME

	echo "" >> $target_file_location/$target_file_name
	
	grep RECV $target_file_location/FTP_CONNECTION >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
	
	echo "" >> $target_file_location/$target_file_name
	
	if [ -f $target_file_location/TCP_CONNECTION ] ; then
		rm -f $target_file_location/TCP_CONNECTION >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
	fi
	
	if [ -f $target_file_location/HTTP_CONNECTION ] ; then
		rm -f $target_file_location/HTTP_CONNECTION >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
	fi
	
	if [ -f $target_file_location/FTP_CONNECTION ] ; then
		rm -f $target_file_location/FTP_CONNECTION >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
	fi
fi

# Check for "collect system resource info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectSystemResource" ] ; then 
	bCollectSystemResource=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep SystemResource= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectSystemResource -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect SystemResource" | tee -a $CDT_LOG_FILE_NAME | more
	# Get System Resource Status
	echo -e "\n[System Resource Status]" >> $target_file_location/$target_file_name

	ipcs >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi

# Check for "collect system dmesg info or not" from $CDT_CONFIG_TEMP_FILE_NAME
if [ -z "$bCollectDmesgInfo" ] ; then 
	bCollectDmesgInfo=`sed -e '/^\[SystemInfo\]/,/^\[.*\]/p;d' $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME | grep -v -e '^\[.*\]' | grep DmesgInfo= | cut -d'=' -f2 2>>$CDT_LOG_FILE_NAME`
fi	

if [ $bCollectDmesgInfo -ne 0 ] ; then	
	echo "`date` [$Module_Name] Collect DmesgInfo" | tee -a $CDT_LOG_FILE_NAME | more
	
	# Get System dmesg info
	echo -e "\n[dmesg Information]" >> $target_file_location/$target_file_name
	
	echo "`date` [$Module_Name] > dmesg" | tee -a $CDT_LOG_FILE_NAME | more
	dmesg >> $target_file_location/$target_file_name 2>>$CDT_LOG_FILE_NAME
fi

#if [ $? -eq 0 ] ; then
#	echo "`date` [$Module_Name] System information is saved in $target_file_location/$target_file_name" | tee -a $CDT_LOG_FILE_NAME | more
#else
#	echo "`date` [$Module_Name] Error occurred during collecting system information" | tee -a $CDT_LOG_FILE_NAME | more
#fi

# Remove $CDT_CONFIG_TEMP_FILE_NAME (without comments) if it is created by this shell script
if [ $bCreateConfigTemp -eq 1 ] ; then
	if [ -f $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME ] ; then
		rm -f $CURRENT_DIR/$CDT_CONFIG_TEMP_FILE_NAME >>$CDT_LOG_FILE_NAME 2>>$CDT_LOG_FILE_NAME
	fi
fi
