#!/bin/sh

#set -x

# Usage: ./ImEx_CleanPkg.sh [-i] [-e]
#       [-i] means clean the imported package
#       [-e] means clean the exported package
# Ex: ./ImEx_CleanPkg.sh -i
#     ./ImEx_CleanPkg.sh -e
#     ./ImEx_CleanPkg.sh -i -e

IMPORT_PKG_PATH="/var/iwss/tomcat/import"
EXPORT_PKG_PATH="/var/iwss/export"
IMEX_TMP_FILE="/tmp/ImEx_tmp"

F_usage() {
  echo "Usage: $0 [-i] [-e]"
  echo "      [-i] means clean the imported package"
  echo "      [-e] means clean the exported package"
  echo "Ex: $0 -i"
  echo "    $0 -e"
  echo "    $0 -i -e"
  
  exit 1
}

_cur_user=`id -un`
_cur_group=`id -gn`
if [ "$_cur_user" != "iscan" ]; then
  echo "This binary is executed only by \"iscan:iscan\"."
  exit 1
fi
if [ "$_cur_group" != "iscan" ]; then
  echo "This binary is executed only by \"iscan:iscan\"."
  exit 1
fi


### Handle parameters
CLEAN_IMPORT=0
CLEAN_EXPORT=0
while getopts ":ie" _opt; do
  case $_opt in
    i ) CLEAN_IMPORT=1
        ;;
    e ) CLEAN_EXPORT=1
        ;;        
    \? ) F_usage
        ;;
  esac
done
shift $(($OPTIND - 1))

if [ $CLEAN_IMPORT -eq 0 ] && [ $CLEAN_EXPORT -eq 0 ]; then
  F_usage
fi

if [ $CLEAN_IMPORT -eq 1 ]; then
  if [ -d "$IMPORT_PKG_PATH" ]; then
    _pre_date=`date -d "14 days ago" "+%Y%m%d%H%M"`
    rm -rf $IMEX_TMP_FILE
    touch -t $_pre_date $IMEX_TMP_FILE
    
    set -- "$IMPORT_PKG_PATH"/*
    for name do
      #echo "$name"
      if [ "$name" -ot "$IMEX_TMP_FILE" ]; then
        echo "remove file $name because it is too old."
        rm -rf $name
      fi
    done
    rm -rf $IMEX_TMP_FILE    
  else
    echo "This import folder \"$IMPORT_PKG_PATH\" doesn't exist."
  fi
fi

if [ $CLEAN_EXPORT -eq 1 ]; then
  if [ -d "$EXPORT_PKG_PATH" ]; then
    _pre_date=`date -d "14 days ago" "+%Y%m%d%H%M"`
    rm -rf $IMEX_TMP_FILE
    touch -t $_pre_date $IMEX_TMP_FILE
    
    set -- "$EXPORT_PKG_PATH"/*
    for name do
      #echo "$name"
      if [ "$name" -ot "$IMEX_TMP_FILE" ]; then
        echo "remove file $name because it is too old."
        rm -rf $name
      fi
    done
    rm -rf $IMEX_TMP_FILE  
  else
    echo "This export folder \"$IMPORT_PKG_PATH\" doesn't exist."
  fi
fi

echo "Execute successfully."
