#!/bin/sh

#set -x

# Usage: ./ImEx_Import.sh [-f imported_file] | [-f imported_file -c] | [-m]
#       [-m] means do the multiple process check
#       [-c] means do the pre-check before import
# Ex: ./ImEx_Import.sh -f /tmp/Info_20080220_112006.tar.gz
#     ./ImEx_Import.sh -f /tmp/Info_20080220_112006.tar.gz -c
#     ./ImEx_Import.sh -m

. ./ImEx_Common.sh

F_usage() {
  echo "Usage: $0 [-f imported_file] | [-f imported_file -c] | [-m]"
  echo "      [-m] means do the multiple process check"
  echo "      [-c] means do the pre-check before import"
  echo "Ex: $0 -f /tmp/Info_20080220_112006.tar.gz"
  echo "    $0 -f /tmp/Info_20080220_112006.tar.gz -c"
  echo "    $0 -m"
    
  # input error
  exit 150
}

F_check_format() {
  F_debug_log "F_check_format() in"
  _extended=`expr "$IMPORT_TMP_DIR/$IMPORT_FILE" : '.*\(\..*\)'`
  if [ "$_extended" = ".zip" ] || [ "$_extended" = ".ZIP" ]; then
    F_debug_log "Using unzip to list the package contents..."
    PRODUCT_INI_DIR=`unzip -l "$IMPORT_TMP_DIR/$IMPORT_FILE" | egrep /ProductIni/intscan.ini$ | awk '{print $4}' | awk 'BEGIN {FS="/"} {print $1 "/" $2 "/" $3}'`
    if [ -z "$PRODUCT_INI_DIR" ] ; then
      #F_debug_log "check fail"
      return 1
    fi
    PRODUCT_INFO_FILE=`unzip -l "$IMPORT_TMP_DIR/$IMPORT_FILE" | grep CollectedFile/ProductInfo.txt | awk '{print $4}'`
    if [ -z "$PRODUCT_INFO_FILE" ] ; then
      #F_debug_log "check fail"
      return 1
    fi
    
    SYSTEM_INI_DIR=""
  else
    F_debug_log "Using tar to list the package contents..."
    PRODUCT_INI_DIR=`tar ztf "$IMPORT_TMP_DIR/$IMPORT_FILE" | egrep /ProductIni_[0-9]{8}/$ | awk 'BEGIN {FS="/"} {print $1 "/" $2}'`
    if [ -z "$PRODUCT_INI_DIR" ] ; then
      #F_debug_log "check fail"
      return 1
    fi
    PRODUCT_INFO_FILE=`tar ztf "$IMPORT_TMP_DIR/$IMPORT_FILE" | egrep /ProductInfo_[0-9]{8}.txt$`
    if [ -z "$PRODUCT_INFO_FILE" ] ; then
      #F_debug_log "check fail"
      return 1
    fi
    
    SYSTEM_INI_DIR=`tar ztf "$IMPORT_TMP_DIR/$IMPORT_FILE" | egrep /SystemIni_[0-9]{8}/$ | awk 'BEGIN {FS="/"} {print $1 "/" $2}'`	
  fi
  
  F_debug_log "PRODUCT_INI_DIR=$PRODUCT_INI_DIR"
  F_debug_log "PRODUCT_INFO_FILE=$PRODUCT_INFO_FILE"
  F_debug_log "SYSTEM_INI_DIR=$SYSTEM_INI_DIR"
  
  F_debug_log "F_check_format() out"
  return 0  
}

F_untar() {
  F_debug_log "F_untar() in"
  _extended=`expr "$IMPORT_TMP_DIR/$IMPORT_FILE" : '.*\(\..*\)'`
  if [ "$_extended" = ".zip" ] || [ "$_extended" = ".ZIP" ]; then
    F_debug_log "Using unzip to extract..."
    mkdir -p $IMPORT_TMP_DIR/CDT
    unzip -P trend "$IMPORT_TMP_DIR/$IMPORT_FILE" -d $IMPORT_TMP_DIR/CDT
    $PROMOTE_PERMISSION "chown -R iscan:iscan $IMPORT_TMP_DIR/CDT"
    
    cp -f $IMPORT_TMP_DIR/CDT/$PRODUCT_INI_DIR/* $IMPORT_TMP_DIR > /dev/null 2>&1
    F_debug_log "Remove the BOM(Byte-Order Marks) of all csv files"
    for csvfile in `ls $IMPORT_TMP_DIR/*.csv`
    do
      /usr/iwss/bin/RemoveBOM $csvfile UTF8
    done
    F_debug_log "Execute dos2unix to all files"
    dos2unix $IMPORT_TMP_DIR/*.* > /dev/null 2>&1
  else
    F_debug_log "Using tar to extract..."
    mkdir -p $IMPORT_TMP_DIR/CDT
    tar zxpf "$IMPORT_TMP_DIR/$IMPORT_FILE" -C $IMPORT_TMP_DIR/CDT
    $PROMOTE_PERMISSION "chown -R iscan:iscan $IMPORT_TMP_DIR/CDT"
    
    mkdir -p $IMPORT_TMP_DIR/ProductIni	
    tar zxpf $IMPORT_TMP_DIR/CDT/$PRODUCT_INI_DIR/ProductIni.tgz -C $IMPORT_TMP_DIR/ProductIni
    $PROMOTE_PERMISSION "chown -R iscan:iscan $IMPORT_TMP_DIR/ProductIni"
    cp -f $IMPORT_TMP_DIR/ProductIni/etc/iscan/* $IMPORT_TMP_DIR > /dev/null 2>&1
    cp -f $IMPORT_TMP_DIR/ProductIni/etc/conf/* $IMPORT_TMP_DIR > /dev/null 2>&1
    cp -f $IMPORT_TMP_DIR/ProductIni/var/iwss/* $IMPORT_TMP_DIR >  /dev/null 2>&1
    cp -f $IMPORT_TMP_DIR/CDT/$PRODUCT_INI_DIR/*.csv $IMPORT_TMP_DIR > /dev/null 2>&1
    
    if [ -n "$SYSTEM_INI_DIR" ] && [ -f "$IMPORT_TMP_DIR/CDT/$SYSTEM_INI_DIR/SystemIni.tgz" ]; then
      mkdir -p $IMPORT_TMP_DIR/SystemIni
      tar zxpf $IMPORT_TMP_DIR/CDT/$SYSTEM_INI_DIR/SystemIni.tgz -C $IMPORT_TMP_DIR/SystemIni
      $PROMOTE_PERMISSION "chown -R iscan:iscan $IMPORT_TMP_DIR/SystemIni"
      cp -f $IMPORT_TMP_DIR/SystemIni/etc/passwd $IMPORT_TMP_DIR > /dev/null 2>&1
      cp -f $IMPORT_TMP_DIR/SystemIni/etc/group $IMPORT_TMP_DIR > /dev/null 2>&1
      cp -f $IMPORT_TMP_DIR/SystemIni/etc/shadow $IMPORT_TMP_DIR > /dev/null 2>&1
      cp -f $IMPORT_TMP_DIR/SystemIni/etc/sysconfig/clock $IMPORT_TMP_DIR > /dev/null 2>&1
      cp -f $IMPORT_TMP_DIR/SystemIni/etc/squid/* $IMPORT_TMP_DIR > /dev/null 2>&1
    fi
  fi
  
  F_debug_log "untar finished"
  F_debug_log "F_untar() out"
}

F_verify() {
  F_debug_log "F_verify() in"
  
  if [ -z "$MIGRATE_FROM" ]; then
    # pass verify
    return 0
  fi
  
  _verify_count=`echo $MIGRATE_FROM | awk 'BEGIN {FS=","} {print NF}'`
  F_debug_log "_verify_count=$_verify_count"
  if [ "$_verify_count" = "0" ]; then
    # pass verify
    return 0
  fi
  
  MIGRATION=0
  k=0
  while [ $k -lt $_verify_count ]
  do
    k=`expr $k + 1`
    _verify_item=`echo $MIGRATE_FROM | cut -d ',' -f$k`
    _verify_product=`echo $_verify_item | cut -d '|' -f1`
    _verify_version=`echo $_verify_item | cut -d '|' -f2`
    _verify_language=`echo $_verify_item | cut -d '|' -f3`
    _verify_platform=`echo $_verify_item | cut -d '|' -f4`
    
    F_debug_log "_verify_product=$_verify_product"
    F_debug_log "_verify_version=$_verify_version"
    F_debug_log "_verify_language=$_verify_language"
    F_debug_log "_verify_platform=$_verify_platform"
    
    if [ -z "$_verify_product" ] || [ -z "$_verify_version" ] || [ -z "$_verify_language" ]; then
      # verification string format error
      return 1
    fi
    if [ -z "$_verify_platform" ]; then
      if [ "$_verify_product" = "$PACKAGE_PRODUCT" ] && [ "$_verify_version" = "$PACKAGE_VERSION" ] && 
         [ "$_verify_language" = "$PACKAGE_LANGUAGE" ]; then
        # pass verify
        MIGRATION=1
        return 0  
      fi  	
    else
      if [ "$_verify_product" = "$PACKAGE_PRODUCT" ] && [ "$_verify_version" = "$PACKAGE_VERSION" ] && 
         [ "$_verify_language" = "$PACKAGE_LANGUAGE" ] && [ "$_verify_platform" = "$PACKAGE_PLATFORM" ]; then
        # pass verify
        MIGRATION=1
        return 0    	
      fi    
    fi
  done
  
  _cur_product=`$IWSS_HOME/iwssd -v | cut -d' ' -f1`
  _cur_version=`$IWSS_HOME/iwssd -v | cut -d' ' -f2 | cut -d'_' -f1`
  _cur_language=`F_ini_get "$IWSS_HOME/intscan.ini" "Common" "lang"`
  
  _cur_platform=""
  if [ $_cur_product = "IWSS" ]; then
    _cur_platform=`$IWSS_HOME/iwssd -v | cut -d' ' -f2 | cut -d'_' -f3`
  fi
  
  if [ -z "$_cur_platform" ]; then
    if [ "$_cur_product" = "$PACKAGE_PRODUCT" ] && [ "$_cur_version" = "$PACKAGE_VERSION" ] && 
       [ "$_cur_language" = "$PACKAGE_LANGUAGE" ]; then
      # pass verify
      return 0  
    fi  	
  else
    if [ "$_cur_product" = "$PACKAGE_PRODUCT" ] && [ "$_cur_version" = "$PACKAGE_VERSION" ] && 
       [ "$_cur_language" = "$PACKAGE_LANGUAGE" ] && [ "$_cur_platform" = "$PACKAGE_PLATFORM" ]; then
      # pass verify
      return 0    	
    fi    
  fi
  
  F_debug_log "F_verify() out"
  return 1
}

F_get_package_info() {
  F_debug_log "F_get_package_info() in"
  
  #The product info string(./iwssd -v) of each product line
  # IWSVA 3.1_Build_Linux_1046      #IWSVA 3.1
  # IWSA 3.1_Build_Linux_1101       #IWSA 3.1
  # IWSA 3.1-SP1_Build_Linux_1211   #IWSA 3.1 sp1
  # IWSS 3.1_Build_Linux_1026       #IWSS 3.1 Linux
  # IWSS 3.1_Build_Win_1055         #IWSS 3.1 Windows
  
  _product_info_string=`cat $IMPORT_TMP_DIR/CDT/$PRODUCT_INFO_FILE | grep "ProductVersion" | cut -d'=' -f2`
  F_debug_log "_product_info_string=$_product_info_string"
  PACKAGE_PRODUCT=`echo $_product_info_string | cut -d' ' -f1`
  PACKAGE_VERSION=`echo $_product_info_string | cut -d' ' -f2 | cut -d'_' -f1`
  
  PACKAGE_LANGUAGE=`F_ini_get "$IMPORT_TMP_DIR/intscan.ini" "Common" "lang"`
  
  PACKAGE_PLATFORM=""
  if [ $PACKAGE_PRODUCT = "IWSS" ]; then
  	PACKAGE_PLATFORM=`echo $_product_info_string | cut -d' ' -f2 | cut -d'_' -f3`
  fi
    
  F_debug_log "PACKAGE_PRODUCT=$PACKAGE_PRODUCT"
  F_debug_log "PACKAGE_VERSION=$PACKAGE_VERSION"
  F_debug_log "PACKAGE_LANGUAGE=$PACKAGE_LANGUAGE"
  F_debug_log "PACKAGE_PLATFORM=$PACKAGE_PLATFORM"
  
  F_debug_log "F_get_package_info() out"
}  
  
F_get_default_values() {
  if [ -f "$IMEX_CONFIG_INI" ]; then
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Common" "IWSSHome"`
    if [ -n "$_value" ]; then
      IWSS_HOME=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Common" "IMEXHome"`
    if [ -n "$_value" ]; then
      IMEX_HOME=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Common" "DebugLog"`
    if [ -n "$_value" ]; then
      DEBUGLOG=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Common" "logfile"`
    if [ -n "$_value" ]; then
      IMEX_LOG_DIR=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Common" "logfile_prefix"`
    if [ -n "$_value" ]; then
      IMEX_LOG_PREFIX=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Import" "TempDir"`
    if [ -n "$_value" ]; then
      IMPORT_TMP_DIR=$_value
    fi 
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Import" "ConfigFileRule"`
    if [ -n "$_value" ]; then
      CONFIG_FILE_RULE=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Import" "DBTables"`
    if [ -n "$_value" ]; then
      DATABASE_TABLES=$_value
    fi
    _value=`F_ini_get "$IMEX_CONFIG_INI" "Import" "MigrateFrom"`
    if [ -n "$_value" ]; then
      MIGRATE_FROM=$_value
    fi
  fi
  DEBUG_FLAG=""
  if [ $DEBUGLOG = "1" ]; then
    DEBUG_FLAG="-d"
  fi
}

F_migrate_DB_password_for_WIN() {
  if [ $MIGRATION -eq 1 ] && [ "$PACKAGE_PRODUCT" = "IWSS" ] && [ "$PACKAGE_PLATFORM" = "Win" ]; then
    DB_PASSWD_TMP=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "Password"`
    DB_PASSWD=`/usr/iwss/bin/encpw -d $DB_PASSWD_TMP`
    F_ini_set "$IWSS_HOME/odbc.ini" "IWSS" "Password            " " $DB_PASSWD"
  fi
}

F_import_db_policies() {
  F_debug_log "F_import_db_policies() in"
  
  RET=0
  
  REMOTE_DB=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "remote_db"`
  DB_NAME=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "DB"`
  DB_HOSTNAME=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "DB_HOSTNAME"`
  DB_PORT=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "DB_PORT"`
  DB_USER=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "User"`
  DB_PASSWD_TMP=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "Password"`
  DB_PASSWD=`/usr/iwss/bin/encpw -d $DB_PASSWD_TMP`

  F_debug_log "REMOTE_DB=$REMOTE_DB"
  F_debug_log "DB_NAME=$DB_NAME"
  F_debug_log "DB_HOSTNAME=$DB_HOSTNAME"
  F_debug_log "DB_PORT=$DB_PORT"
  F_debug_log "REMOTE_DB=$REMOTE_DB"
  F_debug_log "DB_USER=$DB_USER"
  F_debug_log "DB_PASSWD=$DB_PASSWD"
  
  SER_FARM_ENABLE=`F_ini_get "$IWSS_HOME/intscan.ini" "Server-farm" "enabled"`
  SER_FARM_ROLE=`F_ini_get "$IWSS_HOME/intscan.ini" "Server-farm" "servertype"`
  SER_FARM_MASTER="0"
  if [ "$SER_FARM_ENABLE" = "yes" ] && [ "$SER_FARM_ROLE" = "master" ]; then
   SER_FARM_MASTER="1"
  fi
  
  F_debug_log "SER_FARM_MASTER=$SER_FARM_MASTER"
  
  if [ "$REMOTE_DB" = "no" ] || [ "$SER_FARM_MASTER" = "1" ] ; then
    # Use the local DB, so chanage the local DB password.
    # We assume the SrvFarm Master must use the local DB.
  
    cp -a $IWSS_HOME/intscan.ini $IWSS_HOME/intscan.ini.new
    cp $IWSS_HOME/intscan.ini.backup $IWSS_HOME/intscan.ini
    
    cp -a $IWSS_HOME/odbc.ini $IWSS_HOME/odbc.ini.new
    cp $IWSS_HOME/odbc.ini.backup $IWSS_HOME/odbc.ini

    ORI_DB_NAME=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "DB"`
    ORI_DB_HOSTNAME=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "DB_HOSTNAME"`
    ORI_DB_PORT=`F_ini_get "$IWSS_HOME/intscan.ini" "Database" "DB_PORT"`
    
    F_debug_log "ORI_DB_NAME=$ORI_DB_NAME"
    F_debug_log "ORI_DB_HOSTNAME=$ORI_DB_HOSTNAME"
    F_debug_log "ORI_DB_PORT=$ORI_DB_PORT"
    
    F_debug_log "start DB"
    $IWSS_HOME/S99ISdatabase start
    F_debug_log "change DB password..."
    /usr/iwss/PostgreSQL/bin/psql -h $ORI_DB_HOSTNAME -p $ORI_DB_PORT -U iscan -d $ORI_DB_NAME << end_of_file
alter user iscan with password '$DB_PASSWD';
alter user sa with password '$DB_PASSWD';
end_of_file
    F_debug_log "change DB password finished."
    F_debug_log "stop DB"
    $IWSS_HOME/S99ISdatabase stop
    
    cp -a $IWSS_HOME/intscan.ini.new $IWSS_HOME/intscan.ini
    rm -rf $IWSS_HOME/intscan.ini.backup
    rm -rf $IWSS_HOME/intscan.ini.new
    
    cp -a $IWSS_HOME/odbc.ini.new $IWSS_HOME/odbc.ini
    rm -rf $IWSS_HOME/odbc.ini.backup
    rm -rf $IWSS_HOME/odbc.ini.new
  fi
    

  
  cp -a $IWSS_HOME/.pgpass $IWSS_HOME/.pgpass.bak
  if [ "$REMOTE_DB" = "no" ] || [ "$SER_FARM_MASTER" = "1" ] ; then
    # modify .pgpass
    echo "localhost:$DB_PORT:*:$DB_USER:$DB_PASSWD" > $IWSS_HOME/.pgpass.bak
    echo "localhost:$DB_PORT:*:iscan:$DB_PASSWD" >> $IWSS_HOME/.pgpass.bak
  fi
  
  if [ "$REMOTE_DB" = "yes" ]; then
  	pgpassline=`cat $IWSS_HOME/.pgpass.bak | grep "$DB_HOSTNAME:$DB_PORT:\*:$DB_USER:$DB_PASSWD"`
	  if [ $? -ne 0 ]; then
	    echo "$DB_HOSTNAME:$DB_PORT:*:$DB_USER:$DB_PASSWD" >> $IWSS_HOME/.pgpass.bak	  
	  fi
  	pgpassline=`cat $IWSS_HOME/.pgpass.bak | grep "$DB_HOSTNAME:$DB_PORT:\*:iscan:$DB_PASSWD"`
	  if [ $? -ne 0 ]; then
	    echo "$DB_HOSTNAME:$DB_PORT:*:iscan:$DB_PASSWD" >> $IWSS_HOME/.pgpass.bak	  
	  fi
  fi
  
  cp -a $IWSS_HOME/.pgpass.bak $IWSS_HOME/.pgpass
  rm -rf $IWSS_HOME/.pgpass.bak
  
  # Fix IWSx-02454: CLI - admin db related command could not work when import the previous configuration
  _enable_home=/home/enable
  id enable > /dev/null 2> /dev/null
  if [ $? -eq 0 ]; then
    F_debug_log "Modify $_enable_home/.pgpass"
    $PROMOTE_PERMISSION "cp -af $_enable_home/.pgpass $_enable_home/.pgpass.bak"    
    if [ "$REMOTE_DB" = "no" ] || [ "$SER_FARM_MASTER" = "1" ] ; then
      $PROMOTE_PERMISSION "echo \"localhost:$DB_PORT:iwss:$DB_USER:$DB_PASSWD\" > $_enable_home/.pgpass.bak"
    fi    
    if [ "$REMOTE_DB" = "yes" ]; then
      pgpassline=`$PROMOTE_PERMISSION "cat $_enable_home/.pgpass.bak" | grep "$DB_HOSTNAME:$DB_PORT:iwss:$DB_USER:$DB_PASSWD"`
      if [ $? -ne 0 ]; then
        $PROMOTE_PERMISSION "echo \"$DB_HOSTNAME:$DB_PORT:iwss:$DB_USER:$DB_PASSWD\" >> $_enable_home/.pgpass.bak"
      fi
    fi    
    $PROMOTE_PERMISSION "cp -a $_enable_home/.pgpass.bak $_enable_home/.pgpass"
    $PROMOTE_PERMISSION "rm -rf $_enable_home/.pgpass.bak"
  fi
  
  # modify S99ISdatabase
  if [ "$REMOTE_DB" = "yes" ] ; then
    sed -i -e "s/REMOTE_DB=NO/REMOTE_DB=YES/" $IWSS_HOME/S99ISdatabase
  else
    sed -i -e "s/REMOTE_DB=YES/REMOTE_DB=NO/" $IWSS_HOME/S99ISdatabase  
  fi  
  
  if [ "$REMOTE_DB" = "no" ] || [ "$SER_FARM_MASTER" = "1" ] ; then
    # start database
    $IWSS_HOME/S99ISdatabase start
    
    # import policies
    tbCount=`echo $DATABASE_TABLES | awk 'BEGIN {FS=","} {print NF}'`
    #F_debug_log "tbCount=$tbCount"
    k=0   
    while [ $k -lt $tbCount ]
    do
     k=`expr $k + 1`
     tbName=`echo $DATABASE_TABLES | cut -d ',' -f$k`
     #F_debug_log "tbName=$tbName"
     fileName=$tbName.csv
     if [ -f "$IMPORT_TMP_DIR/$fileName" ]; then
       F_debug_log "Clean up $tbName before importing $tbName"
       /usr/iwss/PostgreSQL/bin/psql $DB_NAME $DB_USER -c "truncate $tbName;"
       
       F_debug_log "Import $tbName from $IMPORT_TMP_DIR/$fileName"
       if [ $MIGRATION -eq 1 ] && [ "$PACKAGE_PRODUCT" = "IWSS" ] && [ "$PACKAGE_PLATFORM" = "Win" ]; then
         /usr/iwss/PostgreSQL/bin/psql $DB_NAME $DB_USER -c "copy $tbName from '$IMPORT_TMP_DIR/$fileName' using delimiters ';';"
       else
         /usr/iwss/PostgreSQL/bin/psql $DB_NAME $DB_USER -c "copy $tbName from '$IMPORT_TMP_DIR/$fileName' using delimiters ',';"
       fi
       if [ $? -eq 0 ]; then
         F_debug_log "Import successfully"
       else
         F_log "Import $tbName unsuccessfully [$?]"
         RET=1
       fi
       
       F_debug_log "Vacuum $tbName after importing $tbName"
       /usr/iwss/PostgreSQL/bin/psql $DB_NAME $DB_USER -c "vacuum analyze $tbName;"
     else
       break
     fi
    done
    
    # stop database
    $IWSS_HOME/S99ISdatabase stop
  fi
  F_debug_log "F_import_db_policies() out"
  return $RET
}

F_UI_not_import_list() {
  F_UI_log "$IMEX_RES_FILE" "not_import" "list01" "NotImported"
  if [ $MIGRATION -eq 1 ]; then
    F_UI_log "$IMEX_RES_FILE" "not_import" "list02" "NotImported"
  fi
  F_UI_log "$IMEX_RES_FILE" "not_import" "list03" "NotImported"
  F_UI_log "$IMEX_RES_FILE" "not_import" "list04" "NotImported"
  F_UI_log "$IMEX_RES_FILE" "not_import" "list05" "NotImported"
  F_UI_log "$IMEX_RES_FILE" "not_import" "list06" "NotImported"
}

F_import_timezone() {
  cur_zone_str=`cat /etc/sysconfig/clock | grep "ZONE=" | cut -d'"' -f2`
  F_debug_log "current timezone=$cur_zone_str"
  
  if [ $MIGRATION -eq 1 ] && [ "$PACKAGE_PRODUCT" = "IWSA" ]; then
    if [ -f "$IMPORT_TMP_DIR/ggb.conf" ]; then
      _zone_str=`cat $IMPORT_TMP_DIR/ggb.conf | grep '<tz' | cut -d'=' -f2 | cut -d'"' -f2`
    else
      F_debug_log "Doesn't has file \"ggb.conf\""
      return 2
    fi
  elif [ $MIGRATION -eq 0 ]; then
    if [ -f "$IMPORT_TMP_DIR/clock" ]; then
      _zone_str=`cat $IMPORT_TMP_DIR/clock | grep "ZONE=" | cut -d'"' -f2`
    else
      F_debug_log "Doesn't has file \"clock\""
      return 2
    fi
  fi
  
  F_debug_log "_zone_str=$_zone_str"
  
  if [ -n "$_zone_str" ] && [ "$_zone_str" != "$cur_zone_str" ]; then
    _zone_front=`echo $_zone_str | cut -d'/' -f1`
    _zone_rear=`echo $_zone_str | cut -d'/' -f2`
    
    F_debug_log "_zone_front=$_zone_front"
    F_debug_log "_zone_rear=$_zone_rear"
    
    $PROMOTE_PERMISSION "ln -sf /usr/share/zoneinfo/$_zone_front/$_zone_rear /etc/localtime"
    #$PROMOTE_PERMISSION "sed -i s?ZONE=.*?ZONE=\\\"$_zone_front/$_zone_rear\\\"? /etc/sysconfig/clock"
    $PROMOTE_PERMISSION "/usr/bin/rwconfig -ct -d '=' -f /etc/sysconfig/clock -s ZONE -n \"$_zone_front/$_zone_rear\\\"\""
    $PROMOTE_PERMISSION "/sbin/hwclock --systohc"
    F_log "Change timezone to $_zone_str"
    return 0
  fi
  
  return 1
}

F_make_home_dir_for_OS_account() {
  if [ $MIGRATION -eq 0 ]; then
    _pass_file="/etc/passwd"
    _tmp_pass="/tmp/tmp-pass"
    rm -f $_tmp_pass
    
    $PROMOTE_PERMISSION "cp $_pass_file $_tmp_pass"
    $PROMOTE_PERMISSION "chown iscan:iscan $_tmp_pass"
    _user_id_list=`cat $_tmp_pass | cut -d':' -f3`
    
    _count=0
    for _id in $_user_id_list
    do
      _count=`expr $_count + 1`
      
      if [ $_id -ge 500 ]; then
        F_debug_log "_id=$_id, _count=$_count"
        _account_info=`sed -n "$_count,$_count p" $_tmp_pass`
        _user_info=`echo $_account_info | cut -d':' -f3`
        _group_info=`echo $_account_info | cut -d':' -f4`
        _homedir_info=`echo $_account_info | cut -d':' -f6`
        if [ ! -d "$_homedir_info" ]; then
          $PROMOTE_PERMISSION "mkdir -p $_homedir_info"
          F_debug_log "mkdir -p $_homedir_info"
        fi
        $PROMOTE_PERMISSION "chown -R $_user_info:$_group_info $_homedir_info"
        $PROMOTE_PERMISSION "chmod 700 $_homedir_info"
      fi
    done
    rm -f $_tmp_pass
  fi
}

F_import_service_port() {
  if [ $MIGRATION -eq 1 ] && [ "$PACKAGE_PRODUCT" = "IWSA" ]; then
    if [ -f "$IMPORT_TMP_DIR/ggb.conf" ]; then
      _http_service_port=`cat $IMPORT_TMP_DIR/ggb.conf | grep '<service_ports_http' | cut -d'=' -f2 | cut -d'"' -f2`
      _ftp_service_port=`cat $IMPORT_TMP_DIR/ggb.conf | grep '<service_ports_ftp' | cut -d'=' -f2 | cut -d'"' -f2`
      
      F_debug_log "_http_service_port=$_http_service_port"
      F_debug_log "_ftp_service_port=$_ftp_service_port"   
      
      F_ini_set "$IWSS_HOME/IWSSPIProtocolHttpProxy.pni" "main" "interested_port" "$_http_service_port"
      F_ini_set "$IWSS_HOME/IWSSPIProtocolFtp.pni" "main" "interested_port" "$_ftp_service_port"
      F_log "Set http/ftp service port finished."
    else
      F_debug_log "Doesn't has file \"ggb.conf\""
    fi
  fi
}

F_stop_squid() {
  if [ -f "/usr/iwss/squid.sh" ]; then
    _squid_status=`/usr/iwss/squid.sh get status`
    F_debug_log "Squid status=$_squid_status"
    if [ "$_squid_status" = "on" ]; then
      SQUID_MODE=`/usr/iwss/squid.sh get mode`
      F_debug_log "Squid mode=$SQUID_MODE"
      if [ "$SQUID_MODE" != "" ]; then
        F_debug_log "Prepare to stop squid..."
        if [ "$DEBUGLOG" = "1" ] && [ "$LOG_FILE" != "" ]; then
          $PROMOTE_PERMISSION "/usr/iwss/squid.sh disable $SQUID_MODE"  >> $IMEX_LOG_DIR/$LOG_FILE 2>> $IMEX_LOG_DIR/$LOG_FILE
        else
          $PROMOTE_PERMISSION "/usr/iwss/squid.sh disable $SQUID_MODE"  > /dev/null 2>> $IMEX_LOG_DIR/$LOG_FILE
        fi
      fi
    fi
  fi
}

F_start_squid() {
  if [ -f "/usr/iwss/squid.sh" ]; then
    _squid_flag=`F_ini_get "$IWSS_HOME/intscan.ini" "squid" "squidmode"`
    if [ "$_squid_flag" = "1" ]; then
      SQUID_MODE="upstream"
    elif  [ "$_squid_flag" = "2" ]; then
      SQUID_MODE="downstream"
    else
      SQUID_MODE=""
    fi
    F_debug_log "Squid mode=$SQUID_MODE"
    if [ "$SQUID_MODE" != "" ]; then
      F_ini_set "$IWSS_HOME/intscan.ini" "squid" "squidmode" "0"
      F_debug_log "Prepare to start squid..."
      if [ "$DEBUGLOG" = "1" ] && [ "$LOG_FILE" != "" ]; then
        $PROMOTE_PERMISSION "/usr/iwss/squid.sh enable $SQUID_MODE"  >> $IMEX_LOG_DIR/$LOG_FILE 2>> $IMEX_LOG_DIR/$LOG_FILE
      else
        $PROMOTE_PERMISSION "/usr/iwss/squid.sh enable $SQUID_MODE"  > /dev/null 2>> $IMEX_LOG_DIR/$LOG_FILE
      fi    
    fi
  fi
}

### Check user
F_check_user "iscan" "iscan"
if [ $? -ne 0 ]; then
  echo "This binary is executed only by \"iscan:iscan\"."
  exit 1
fi

### Handle parameters
if [ $# -eq 0 ]; then
  F_usage
fi

MULTI_CHECK=0
PRE_CHECK=0
while getopts ":f:mc" _opt; do
  case $_opt in
    f ) IMPORT_FULL_FILE=$OPTARG
        ;;
    m ) MULTI_CHECK=1
        ;;
    c ) PRE_CHECK=1
        ;;
    \? ) F_usage
        ;;
  esac
done
shift $(($OPTIND - 1))

USER_ACTION=0
if [ "$IMPORT_FULL_FILE" != "" ] && [ -f "$IMPORT_FULL_FILE" ] && [ $PRE_CHECK -eq 0 ] && [ $MULTI_CHECK -eq 0 ]; then
  USER_ACTION=1 #./ImEx_Import.sh -f imported_file
elif [ "$IMPORT_FULL_FILE" != "" ] && [ -f "$IMPORT_FULL_FILE" ] && [ $PRE_CHECK -eq 1 ] && [ $MULTI_CHECK -eq 0 ]; then
  USER_ACTION=2 #./ImEx_Import.sh -f imported_file -c
elif [ "$IMPORT_FULL_FILE" = "" ] && [ $PRE_CHECK -eq 0 ] && [ $MULTI_CHECK -eq 1 ]; then
  USER_ACTION=3 #./ImEx_Import.sh -m
else
  F_usage
fi

if [ $USER_ACTION -eq 1 ] || [ $USER_ACTION -eq 2 ]; then
  IMPORT_FILE=`basename "$IMPORT_FULL_FILE"`
fi

### Get settings from ImEx_Config.ini
if [ $USER_ACTION -eq 1 ] || [ $USER_ACTION -eq 2 ]; then
  F_get_default_values
fi

### Initialize logs
if [ $USER_ACTION -eq 1 ]; then
  F_log_initialize
  
  F_log "================= Import Product Configurations Start ================"
  echo
  
  F_debug_log "IWSS_HOME=$IWSS_HOME"
  F_debug_log "IMEX_HOME=$IMEX_HOME"
  F_debug_log "DEBUGLOG=$DEBUGLOG"
  F_debug_log "DEBUG_FLAG=$DEBUG_FLAG"
  F_debug_log "IMEX_LOG_DIR=$IMEX_LOG_DIR"
  F_debug_log "IMEX_LOG_PREFIX=$IMEX_LOG_PREFIX"
  F_debug_log "IMPORT_TMP_DIR=$IMPORT_TMP_DIR"
  F_debug_log "CONFIG_FILE_RULE=$CONFIG_FILE_RULE"
  F_debug_log "DATABASE_TABLES=$DATABASE_TABLES"
  F_debug_log "MIGRATE_FROM=$MIGRATE_FROM"
fi

### check multiple process 
_result=`F_IsMultipleProcess`
if [ $? -ne 0 ] ; then
  F_log "F_IsMultipleProcess() function error"
  exit 151
fi
if [ "$_result" = "true" ]; then
  F_log "Another Import/Export is running"
	exit 152
else
  F_debug_log "No other Import/Export is running"
fi

if [ $USER_ACTION -eq 3 ]; then
  exit 0
fi

### lock
F_lock

### pre-check
rm -rf $IMPORT_TMP_DIR
mkdir -p $IMPORT_TMP_DIR
cp "$IMPORT_FULL_FILE" $IMPORT_TMP_DIR
  
### check package format
F_check_format
if [ $? -ne 0 ] ; then
  F_log "Not pass the package format checking"
  exit 153
else
  F_debug_log "Pass the package format checking"
fi

### untar the package to temp folder
F_untar

### get the infomation from the package
F_get_package_info

### verify the version of package could be imported
F_verify
if [ $? -ne 0 ]; then
  F_log "verify error"
  exit 154
else
  F_debug_log "MIGRATION=$MIGRATION"
  F_debug_log "pass verify"
fi

if [ $USER_ACTION -eq 2 ]; then
  exit 0
fi

### for debug
F_debug_log "IMEX_CONFIGFILE_IMPORT_BINARY=$IMEX_CONFIGFILE_IMPORT_BINARY"
F_debug_log "CONFIG_FILE_RULE=$CONFIG_FILE_RULE"
F_debug_log "PACKAGE_PRODUCT=$PACKAGE_PRODUCT"
F_debug_log "PACKAGE_VERSION=$PACKAGE_VERSION"
F_debug_log "PACKAGE_LANGUAGE=$PACKAGE_LANGUAGE"
F_debug_log "PACKAGE_PLATFORM=$PACKAGE_PLATFORM"
F_debug_log "DEBUG_FLAG=$DEBUG_FLAG"

### stop daemons
F_log "********** Stopping Daemons... ********** "

F_stop_squid

if [ "$DEBUGLOG" = "1" ] && [ "$LOG_FILE" != "" ]; then
  $IWSS_HOME/rcIwss stop >> $IMEX_LOG_DIR/$LOG_FILE
else
  $IWSS_HOME/rcIwss stop
fi
F_log "********** Stop Daemons Finished ********** "
echo

### backup some files for DB password modification
cp -a $IWSS_HOME/intscan.ini $IWSS_HOME/intscan.ini.backup
cp -a $IWSS_HOME/odbc.ini $IWSS_HOME/odbc.ini.backup

### import configuration files
F_log "********** Importing Configuration Files... **********"  
export LD_LIBRARY_PATH=/usr/iwss/lib:
if [ "$PACKAGE_PLATFORM" = "" ]; then
  $IMEX_CONFIGFILE_IMPORT_BINARY -r $CONFIG_FILE_RULE -p $PACKAGE_PRODUCT -v $PACKAGE_VERSION -l $PACKAGE_LANGUAGE $DEBUG_FLAG
else
  $IMEX_CONFIGFILE_IMPORT_BINARY -r $CONFIG_FILE_RULE -p $PACKAGE_PRODUCT -v $PACKAGE_VERSION -l $PACKAGE_LANGUAGE -f $PACKAGE_PLATFORM $DEBUG_FLAG
fi
RET=$?
if [ $RET -ne 0 ]; then
  F_log "error when execute $IMEX_CONFIGFILE_IMPORT_BINARY, exit code=[$RET]"
else
  F_debug_log "Execute $IMEX_CONFIGFILE_IMPORT_BINARY successfully."
fi

F_migrate_DB_password_for_WIN

F_import_timezone
if [ $? -eq 0 ]; then
  #message04=Import timezone configuration finished.
  F_UI_log "$IMEX_RES_FILE" "import" "message04" "Imported"
fi

F_import_service_port

F_make_home_dir_for_OS_account

F_log "********** Import Configuration Files Finished **********"  
echo

### import database policy
F_log "********** Importing Database Policies... **********"
F_import_db_policies
if [ $? -ne 0 ]; then
  F_log "error when import DB policies"
  #message01=Import DB policies failed.
  F_UI_log "$IMEX_RES_FILE" "import" "message01" "ImportFail"
else
  F_debug_log "Import DB polices successfully."
  #message02=Import DB policies successfully.
  F_UI_log "$IMEX_RES_FILE" "import" "message02" "Imported"
fi  
F_log "********** Import Database Policies Finished **********"
echo

### remove the temp folder
rm -rf $IMPORT_TMP_DIR

### restart network & iptables
F_log "********** Restarting Network & Firewall... **********"
if [ "$DEBUGLOG" = "1" ] && [ "$LOG_FILE" != "" ]; then
  $PROMOTE_PERMISSION "/etc/init.d/network restart"  >> $IMEX_LOG_DIR/$LOG_FILE 2>> $IMEX_LOG_DIR/$LOG_FILE
  $PROMOTE_PERMISSION "/etc/init.d/iptables restart"  >> $IMEX_LOG_DIR/$LOG_FILE 2>> $IMEX_LOG_DIR/$LOG_FILE
else
  $PROMOTE_PERMISSION "/etc/init.d/network restart"  > /dev/null 2>> $IMEX_LOG_DIR/$LOG_FILE
  $PROMOTE_PERMISSION "/etc/init.d/iptables restart"  > /dev/null 2>> $IMEX_LOG_DIR/$LOG_FILE
fi
F_log "********** Restart Network & Firewall Finished **********"

### start daemons
F_log "********** Starting Daemons... **********"
if [ "$DEBUGLOG" = "1" ] && [ "$LOG_FILE" != "" ]; then
  $IWSS_HOME/rcIwss start >> $IMEX_LOG_DIR/$LOG_FILE
else
  $IWSS_HOME/rcIwss start
fi

F_start_squid

F_log "********** Start Daemons Finished **********"
echo
F_UI_polling_start

### write not import list
F_UI_not_import_list

#message03=Import configuration finished.
F_UI_log "$IMEX_RES_FILE" "import" "message03" "Finish"

F_log "================== Import Product Configurations End ================="
