#!/bin/sh

_SAVED_PWD=
F_pushd() {
	_SAVED_PWD=`pwd`
}
F_popd() {
	 cd $_SAVED_PWD
}

if [ -f "./LOCAL_DEBUG" ] ; then 
	. ./LOCAL_DEBUG
else
	ROOT=/etc/iscan/patch
	INSTALL_ROOT=/etc/iscan	
fi

if [ "$1" = "untar" ] ; then
	FILE1="$2"
elif [ "$1" = "apply" ] ; then
	printf ""	
else
	echo "Usage: $0 untar example_patch.tar  | apply"
	exit 1
fi

BACKUP_DIR=${ROOT}/backup

EXTRACT_DIR=/tmp/extract_patch

FILE2_ORIG=stargate_patch.tgz
FILE2=${EXTRACT_DIR}/${FILE2_ORIG}
FILE2_MD5=${EXTRACT_DIR}/MD5SUM.txt

APPLY_SCRIPT=stargate_patch_apply.sh
ROLLBACK_SCRIPT=stargate_patch_rollback.sh
THISPATCHINI=stargate_patch.ini
README=README.txt

PATCH_MGM_INI=${ROOT}/config/patch_management.ini

#error codes that communicates by apply.sh and PatchExe.sh

ERR_REQ_F=111
ERR_DEP=112
ERR_REQ_P=113
ERR_BAK=114
ERR_APP=115
ERR_VER=116
ERR_OTHER=117

# F_ini_get
# Get the value of a key in an INI file
# Usage: Catch the value using an variable.
# e.g. VAR=`F_ini_get "file" "section" "key"`
#
# param: full path to an INI file 
# param: section name excluding '[' ']'
# param: key name
#
# print: the ini value or error
#
F_ini_get()
{
    INI_F="$1"
    INI_SECTION="$2"
    INI_KEY="$3"

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
        return 1
    fi
        
    RANGE_START="/^\[${INI_SECTION}\]/"
    RANGE_END="/^\[.*\]/"
        
    MY_SEDCMD_1="${RANGE_START},${RANGE_END}p"
    MY_SEDCMD_2="/${INI_KEY}=/p"

    _R=`sed -n -e "${MY_SEDCMD_1}" ${INI_F} | sed -n -e "${MY_SEDCMD_2}" | awk -F= '{ printf $2 }'`
	printf "%s\n" "$_R"
	if [ -z "$_R" ] ; then
		return 1
	else
		return 0
	fi
}

#get a whole section of ini without the section headers and without the Number=xxxx line
F_ini_get_section()
{
    INI_F="$1"
    INI_SECTION="$2"

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
        return 1
    fi
        
    RANGE_START="/^\[${INI_SECTION}\]/"
    RANGE_END="/^\[.*\]/"
        
    MY_SEDCMD_1="${RANGE_START},${RANGE_END}p"

    _R=`sed -n -e "${MY_SEDCMD_1}" ${INI_F} | grep -v '\[.*\]' | grep -v 'Number='`
	printf "%s\n" "$_R"
	if [ -z "$_R" ] ; then
		return 1
	else
		return 0
	fi

}

F_ini_rename_section()
{
	INI_F="$1"
	OLD_SECTION_NAME="$2"
	NEW_SECTION_NAME="$3"
    TMP_F=/tmp/temp$$
	
	grep -v "^[ 	]*#"  $INI_F | grep "\[$OLD_SECTION_NAME\]"  > /dev/null 2>&1
	if [ $? -ne 0 ] ; then
		echo "Section $OLD_SECTION_NAME doesn't exist in $INI_F. Cannot rename."
		return 2
	fi
	sed -e "s/\[$OLD_SECTION_NAME\]/[$NEW_SECTION_NAME]/" ${INI_F} > $TMP_F
	cp -f ${TMP_F} ${INI_F}
    rm -f ${TMP_F}
	return 0

}
#
# detect if a section header exist in the ini
# param: ini file
# param: section_name
F_ini_exist_section()
{
	INI_F="$1"
	INI_NEW_SECTION="$2"
	
	#tab and space before comment still makes a comment line
	grep -v "^[ 	]*#"  $INI_F | grep "\[$INI_NEW_SECTION\]"  > /dev/null 2>&1
	if [ $? -eq 0 ] ; then
		#echo "Section $INI_NEW_SECTION has already existed in $INI_F."
		return 0
	fi
	return 1
}
F_ini_append_section()
{
	INI_F="$1"
	INI_NEW_SECTION="$2"
	INI_SECTION_DATA="$3"
    TMP_F=/tmp/temp$$

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
		return 1
    fi

	#tab and space before comment still makes a comment line
	grep -v "^[ 	]*#"  $INI_F | grep "\[$INI_NEW_SECTION\]"  > /dev/null 2>&1
	if [ $? -eq 0 ] ; then
		echo "Section $INI_NEW_SECTION has already existed in $INI_F."
		return 2
	fi

	cat $INI_F > $TMP_F
	printf "[%s]\n" "$INI_NEW_SECTION" >> $TMP_F
	printf "%s\n" "$INI_SECTION_DATA" >> $TMP_F
    cp -f ${TMP_F} ${INI_F}
    rm -f ${TMP_F}
	return 0
}

F_ini_del_from_applied_list() {
	INI_F="$1"
	PATCH_NUMBER="$2"
	NEW_APPLIED_LIST=
	APPLIED_LIST=`F_ini_get "$INI_F" "PatchManagement" AppliedPatches`
	for i in $APPLIED_LIST
	do
		if [ "$i" = "$PATCH_NUMBER" ] ; then
			continue
		fi
		NEW_APPLIED_LIST="$NEW_APPLIED_LIST $i"

	done
	F_ini_set "$INI_F" "PatchManagement" AppliedPatches  "$NEW_APPLIED_LIST"

}

F_ini_add_applied_list() {
	INI_F="$1"
	PATCH_NUMBER="$2"
	APPLIED_LIST=`F_ini_get "$INI_F" "PatchManagement" AppliedPatches`
	if [ -z "$APPLIED_LIST" ] ; then
		APPLIED_LIST="$PATCH_NUMBER"
	else
		APPLIED_LIST="$APPLIED_LIST $PATCH_NUMBER"
	fi
	F_ini_set "$INI_F" "PatchManagement" AppliedPatches  "$APPLIED_LIST"

}
F_ini_delete_section()
{
	INI_F="$1"
    INI_SECTION="$2"
    TMP_F=/tmp/temp$$

    if [ ! -f "$INI_F" ] ; then
        echo "${INI_F} not found."
		return 1
    fi

	#tab and space before comment still makes a comment line
	SECTION_BEGIN_LINE=`grep -n "^\[$INI_SECTION\]" $INI_F`  
	if [ $? -ne 0 ] ; then
		echo "Section $INI_SECTION doesn't exist in $INI_F."
		return 2
	fi
	#echo $SECTION_BEGIN_LINE
	SECTION_BEGIN_LINE=`echo $SECTION_BEGIN_LINE | cut -d: -f1`
	#echo $SECTION_BEGIN_LINE

	#tail +$SECTION_BEGIN_LINE $INI_F | grep -n "^\[.*\]" $INI_F
     
    RANGE_START="/^\[${INI_SECTION}\]/"
    RANGE_END="/^\[.*\]/"
        
    MY_SEDCMD_1="${RANGE_START},${RANGE_END}p"

    SECTION_NUMBER_OF_LINES=`sed -n -e "${MY_SEDCMD_1}" ${INI_F} | wc -l`
    LAST_LINE=`sed -n -e "${MY_SEDCMD_1}" ${INI_F} | tail -1`
	#echo $SECTION_NUMBER_OF_LINES	
	#echo $LAST_LINE
	echo $LAST_LINE | grep "^\[.*\]" > /dev/null 2>&1
	if [ $? -eq 0 ] ; then
		SECTION_NUMBER_OF_LINES=`expr $SECTION_NUMBER_OF_LINES - 1`
	fi
	#echo $SECTION_NUMBER_OF_LINES
	SECTION_END_LINE=`expr $SECTION_BEGIN_LINE + $SECTION_NUMBER_OF_LINES - 1`

	sed -e "${SECTION_BEGIN_LINE},${SECTION_END_LINE}d" $INI_F > ${TMP_F}

    cp -f ${TMP_F} ${INI_F}
    rm -f ${TMP_F}
}



# F_ini_set
# Set the value of a key in an INI file
# It uses a temp file.
# e.g. F_ini_set "file" "section" "key" "value"
#
# param: full path to an INI file 
# param: section name excluding '[' ']'
# param: key name
# param: value
#
# print: error
#
F_ini_set() {
    INI_F="$1"
    INI_SECTION="$2"
    INI_KEY="$3"
    INI_VALUE="$4"
    TMP_F=/tmp/temp$$

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
	return 1
    fi

    RANGE_START="/\[${INI_SECTION}\]/"
    RANGE_END="/\\[.*\]/"

    MY_SEDCMD="${RANGE_START},${RANGE_END}s?^[ \t]*${INI_KEY}=.*?${INI_KEY}=${INI_VALUE}?"
    sed -e "${MY_SEDCMD}" ${INI_F} > ${TMP_F}
    cp -f ${TMP_F} ${INI_F}
    rm -f ${TMP_F}
}

# F_ini_delete_key
# Delete the key in an INI file
# It uses a temp file.
# e.g. F_ini_key_delete "file" "section" "key" 
#
# param: full path to an INI file 
# param: section name excluding '[' ']'
# param: key name
#
# print: error
#
F_ini_delete_key() {
    INI_F="$1"
    INI_SECTION="$2"
    INI_KEY="$3"
    TMP_F=/tmp/temp$$
    TMP_F2=/tmp/t2emp$$

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
	return 1
    fi

    RANGE_START="/\[${INI_SECTION}\]/"
    RANGE_END="/\\[.*\]/"

    MY_SEDCMD="${RANGE_START},${RANGE_END}s?^[ \t]*${INI_KEY}=.*?DELETE_THIS_KEY?"
    sed -e "${MY_SEDCMD}" ${INI_F} > ${TMP_F}
	MY_SEDCMD2="/DELETE_THIS_KEY/d"
	sed -e "${MY_SEDCMD2}" ${TMP_F} > ${TMP_F2}
    cp -f ${TMP_F2} ${INI_F}
    rm -f ${TMP_F} ${TMP_F2}
}


# F_ini_add_key
# Add a name=value to a section, right next line to the [section] 
# e.g. F_ini_add_key "file" "section" "key" "value"
#
# param: full path to an INI file 
# param: section name excluding '[' ']'
# param: key name
# param: value
#
# print: error
#
F_ini_add_key(){

	INI_F="$1"
    INI_SECTION="$2"
    INI_KEY="$3"
    INI_VALUE="$4"
    TMP_F=/tmp/temp$$

	#if it exists, overwrite
	VAR=`F_ini_get "$INI_F" "$INI_SECTION" "$INI_KEY"`
	if [ $? -eq 0 ] ; then
		F_ini_set "$INI_F" "$INI_SECTION" "$INI_KEY" "$INI_VALUE"
		return 0
	fi


	#where the section is
	SECTION_LINE_NO=`grep -n "^\[$INI_SECTION\]" $INI_F | cut -d: -f1`
	if [ -z "$SECTION_LINE_NO" ] ; then
		echo "Cannot add key to section $INI_SECTION. The section wan not found."
		return 1
	fi
	TOTAL_LINE_NO=`wc -l $INI_F | cut -b0-8 | xargs`
	REST_LINE_NO=`expr $TOTAL_LINE_NO - $SECTION_LINE_NO`
	#copy first half
	head -$SECTION_LINE_NO ${INI_F} > $TMP_F
	echo "$INI_KEY=$INI_VALUE" >> $TMP_F
	tail -$REST_LINE_NO ${INI_F} >> $TMP_F
	cp -f ${TMP_F} ${INI_F}
    rm -f ${TMP_F}

}


PATCH_LOG=/tmp/patch.log.txt
F_log() {
#	logger -t "is-patch-system" -p local3.info "$1"
	echo "$1" 
	#>> $PATCH_LOG
}
F_log_init() {
	cat /dev/null > $PATCH_LOG
	sleep 1
}

F_internal_error_report() {
	INI_F="$1"
	CODE="$2"
	DESC="$3"

    if [ ! -f "$INI_F" ] ; then
        echo "Error: ${INI_F} not found."
	return 1
    fi

	if [ -z "${CODE}" ] ; then
		echo "Error: We need a ReturnStatus error code"
		return 2
	fi

	F_log "[[$CODE]] $DESC"
	
	F_ini_set "$INI_F" "InternalStatus" "ReturnStatus" "$CODE"

	F_ini_set "$INI_F" "InternalStatus" "ReturnDescription" "$DESC"

}

#
# Utilities to retrieve a specific file info
#
# param: file
# param: section
# param: number
P_get_file_info(){
	INI_F="$1"
	INI_SECTION="$2"
	F_NO="$3"
	F_FIELD="$4"
	F_INFO=`F_ini_get "${INI_F}" "${INI_SECTION}" "File${F_NO}"`
	if [ $? -ne 0 ] ; then
		return 1
	fi
	if [ -z "$F_INFO" ] ; then
		return 2
	fi
	F_FIELD_NO=1
	if [ "$F_FIELD" = "name" ] ; then
		F_FIELD_NO=1
	elif [ "$F_FIELD" = "version" ] ; then
		F_FIELD_NO=2
	elif [ "$F_FIELD" = "path" ] ; then
		F_FIELD_NO=3
	elif [ "$F_FIELD" = "owner" ] ; then
		F_FIELD_NO=4
	elif [ "$F_FIELD" = "permission" ] ; then
		F_FIELD_NO=5
	elif [ "$F_FIELD" = "all" ] ; then
		echo "$F_INFO"
		return 0
	else
		echo ""
		return 1
	fi
	i=1
	for f in $F_INFO
	do
		if [ "$i" = "$F_FIELD_NO" ] ; then
			echo $f
			return 0
		fi
		
		i=`expr $i + 1`
	done
	
	return 1
}

F_untar() {
	#need a absolute path to the tar
	_FILE=$1
	_DIR=$2
	F_pushd
	cd $_DIR
	echo "Decompressing ${_FILE} to ${_DIR}."
	/bin/tar zxvf ${_FILE}
	if [ $? != '0' ] ; then
		 echo "Unable to decompress ${_FILE}."
		F_popd
		return 1
	fi
	 find -type f 
	 echo "Decompression OK."
	F_popd
	return 0
}

F_file_exist() {
	_F=$1
	if [ ! -r "$_F" ] ; then
		 echo "${_F} not found."
		return 1
	fi
	return 0
}

F_dir_exist() {
	_D=$1
	if [ ! -d "$_D" ] ; then
		 echo "Dirrectory ${_D} not found."
		return 1
	fi
	return 0
}

F_untar_size() {
	# Calculate untar size. Get echo file size from verbose file list and add them together in Kilo Byte
	_FILE=$1
	_R=`tar ztvf ${_FILE} | awk ' { print "( " ; printf $3; print " / 1024 ) + " } '  | xargs`
	_R="$_R 0 "
	# echo $_R
	_UNTAR_SIZE=`expr $_R`
	echo $_UNTAR_SIZE
	return 0
}

F_check_disk_space() {
	SPACE_MIN="$2"
	DIR_TO_CHECK="$1"
	DF_STR=`df -k ${DIR_TO_CHECK} | tail -n +2`
	I=0
	for AVAIL_SPACE in ${DF_STR}
	do
		if [ "$I" = "3" ] ; then
			if [ "${AVAIL_SPACE}" -ge "${SPACE_MIN}" ] ; then
				return 0
			else
				return 1
			fi
		fi
		I=`expr $I + 1`
	done
	return 1
}

F_checksum_ok() {
	_FF=$1
	# Use the md5 to check sum
	_TAR_MD5=`grep "${FILE2_ORIG}" "$_FF" | awk '{print $1 }'`

	_FILE_MD5=`md5sum "$FILE2_ORIG" | awk '{print $1}'`
	if [ "$_TAR_MD5" != "$_FILE_MD5" ] ; then
		 echo "The checksum was incorrect."
		return 1
	fi
	 echo "The checksum was correct."
	return 0
}

F_first_untar() {

	F_file_exist ${FILE1}
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0001] The patch system cannot find the compressed patch file (titled ${FILE1}) that has been uploaded, and cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0001] Cannot find ${FILE1}."
		return 1
	fi

	#clean up extract dir
	rm -rf ${EXTRACT_DIR}
	mkdir -p ${EXTRACT_DIR}
	
	chmod 777 ${EXTRACT_DIR}

	mv ${FILE1} ${EXTRACT_DIR}
	
	FFILE1=`basename ${FILE1}`
	cd ${EXTRACT_DIR}
	#untar level1
	F_untar ${EXTRACT_DIR}/${FFILE1} ${EXTRACT_DIR}
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0002]   IWSS could not extract the specified file: ${FFILE1}. Please make sure it is a valid IWSS patch file and try again."
		#"[ERR-PAT-0002] Cannot decompress first ${FFILE1}."
		return 1
	fi


	#We require a specific tar and a md5 to exist.
	F_file_exist "$FILE2"
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0003]   The patch system cannot find the file (titled ${FILE2}) in the decompressed set of patch files, and cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0003] Cannot find `basename ${FILE2}`."
		return 1
	fi

	F_file_exist "$FILE2_MD5"
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0004]   The patch system cannot find the required MD5SUM checksum file titled ${FILE2_MD5} in the decompressed set of patch files, and cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0004] Cannot find `basename ${FILE2_MD5}`."
		return 1
	fi

	# make sure the md5 has the check summed file 
	grep `basename "$FILE2"` "$FILE2_MD5" > /dev/null 2>&1
	if [ $? != "0" ] ; then
		 echo "File $FILE2_MD5 should only have a checksum of ${FILE2}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0005]   The MD5SUM file in the patch titled ${FILE2_MD5} doesn't have a checksum line. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0005] File `basename $FILE2_MD5` should only have a checksum of `basename ${FILE2}`"
		return 1
	fi

	F_checksum_ok ${FILE2_MD5}
	if [ $? != "0" ] ; then
		 echo "The checksum in `basename ${FILE2_MD5}` is incorrect."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0006]   The patch MD5SUM check was unsuccessful, and the patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0006] Checksum in `basename ${FILE2_MD5}` is incorrect."
		return 1
	fi
	 rm ${FILE2_MD5} 
	#done checksum
}


F_second_untar() {
	F_dir_exist ${EXTRACT_DIR}
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error"  "[ERR-PAT-0007]   The patch system cannot find the temporary extraction directory titled ${EXTRACT_DIR}. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0007] Cannot find extracted directory ${EXTRACT_DIR}."
		return 1
	fi


	UNTAR_SIZE=`F_untar_size ${FILE2} `
	#plus 5 MB
	UNTAR_SIZE=`expr $UNTAR_SIZE + 5000`
	#check backup dir size larger than untar size
	F_check_disk_space ${EXTRACT_DIR} ${UNTAR_SIZE}
	if [ "$?" != "0" ] ; then
		 echo "Backup dir ${BACKUP_DIR} available disk space is too small."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0008]   Storage space on the SSM is insufficient to extract the patch files. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0008] Storage space is not enough to extract."
		return 2
	fi

	#extract after disk space check!
	F_untar ${FILE2} ${EXTRACT_DIR} 
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0009]   A compressed file inside the patch (titled ${FILE2}) cannot be decompressed. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0009] Cannot decompress ${FILE2}."
		return 1
	fi

	#make sure there is a patch number
	PATCH_NUMBER=`F_ini_get ${THISPATCHINI} PatchInfo Number`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0010]   The patch is missing a patch number entry (from the configuration file titled ${THISPATCHINI}). The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0010] Cannot retrieve patch number from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Patch-Number" "${PATCH_NUMBER}"

	#make sure there is a patch title
	PATCH_TITLE=`F_ini_get ${THISPATCHINI} PatchInfo Title`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0011]   The patch is missing a patch name (from the file titled ${THISPATCHINI}) and cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0011] Cannot retrieve patch title from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Patch-Title" "${PATCH_TITLE}"
	
	#make sure there is a patch description
	PATCH_DESC=`F_ini_get ${THISPATCHINI} PatchInfo Description`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0012]   The patch is missing a patch description (from the file titled ${THISPATCHINI}) and cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support.
		"
		#"[ERR-PAT-0012] Cannot retrieve patch description from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Patch-Description" "${PATCH_DESC}"
	
	#requires field
	PATCH_REQUIRES=`F_ini_get ${THISPATCHINI} PatchInfo Requires`
	if [ -n "$PATCH_REQUIRES" ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Patch-Requires" "${PATCH_REQUIRES}"
	fi
	
	#make sure there's an apply script
	F_file_exist ${APPLY_SCRIPT}
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0013]   The patch is missing a required patch apply scripti titled ${APPLY_SCRIPT}, and cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0013] Cannot apply this patch. The ${APPLY_SCRIPT} is missing."
		return 1
	fi

	#UI restart
	RESTARTUI=`F_ini_get ${THISPATCHINI} PatchInfo RestartUI`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0014]   The patch configuration file \"stargate_patch.ini\" is missing a required flag to indicate whether the UI should be restarted. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0014] Cannot retrieve RestartUi from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Restart-UI" "$RESTARTUI"

	#Web restart
	RESTARTWEB=`F_ini_get ${THISPATCHINI} PatchInfo RestartWeb`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0015]   The patch configuration file \"stargate_patch.ini\" is missing a required flag to indicate whether the httpd and ftpd should be restarted. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0015] Cannot retrieve RestartWeb from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Restart-Web" "$RESTARTWEB"
	
	#Mail restart
	RESTARTMAIL=`F_ini_get ${THISPATCHINI} PatchInfo RestartMail`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0016]   The patch configuration file \"stargate_patch.ini\" is missing a required flag to indicate whether the imssd should be restarted. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0016] Cannot retrieve RestartMail from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Restart-Mail" "$RESTARTMAIL"

	#System restart
	RESTARTSYSTEM=`F_ini_get ${THISPATCHINI} PatchInfo RestartSystem`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0017]   The patch configuration file \"stargate_patch.ini\" is missing a required flag to indicate whether the system should be restarted. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0017] Cannot retrieve RestartSystem from ${THISPATCHINI}."
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Restart-System" "$RESTARTSYSTEM"

	#UI restart seconds
	UIRESTARTSEC=`F_ini_get ${THISPATCHINI} PatchInfo UIRestartSec`
	if [ $? -eq 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "UIRestart-Seconds" "$UIRESTARTSEC"
	fi

	#System restart seconds
	SYSRESTARTSEC=`F_ini_get ${THISPATCHINI} PatchInfo SysRestartSec`
	if [ $? -eq 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "SysRestart-Seconds" "$SYSRESTARTSEC"
	fi

	if [ ! -f "$README" ] ; then
		echo "Cannot access $README."
		F_internal_error_report "${PATCH_MGM_INI}" "Warning" "Cannot find $README."
		#return 1
	else
		F_internal_error_report "${PATCH_MGM_INI}" "Readme-begin" ""
		/bin/cat "$README" 2> /dev/null
		F_internal_error_report "${PATCH_MGM_INI}" "Readme-end" ""
	fi

	return 0
}

F_decompress() {
	F_first_untar
	if [ $? -ne 0 ] ; then
		exit 1
	fi
	F_second_untar
	if [ $? -ne 0 ] ; then
		exit 1
	fi
	return 0
}

F_call_upload_check() {
	F_pushd
	cd ${EXTRACT_DIR} 
	if [ $? -ne 0 ] ; then
		 echo "The extracted directory doesn't exist. Please invoke '$0 untar ...' first"
		return 1
	fi
	#mkdir a backup dir according to patch number
	PATCH_NUMBER=`F_ini_get ${THISPATCHINI} PatchInfo Number`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0018]   The patch system is missing a patch number entry that should be available in the file titled ${THISPATCHINI}. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0018] Cannot retrieve patch number from ${THISPATCHINI}."
		return 1
	fi

	#BACKUP_DIR_FOR_1_PATCH=${BACKUP_DIR}/${PATCH_NUMBER}
	#mkdir -p ${BACKUP_DIR_FOR_1_PATCH}/files
	#BACKUP_DIR_FOR_1_PATCH=`cd ${BACKUP_DIR_FOR_1_PATCH} && pwd && cd - > /dev/null 2>&1`

	F_file_exist ${APPLY_SCRIPT}
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0019]   After the upload, the patch system could not find the apply script titled ${APPLY_SCRIPT}. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0019] Cannot use this patch. The ${APPLY_SCRIPT} is missing."
		return 1
	fi
	#call the patch apply script to do upload check
	/bin/sh ./${APPLY_SCRIPT} "upload_check" ${INSTALL_ROOT} ${BACKUP_DIR_FOR_1_PATCH} 
	_R=$?
	if [ $_R -ne 0 ] ; then
		ERR_MSG=""
		
		case "$_R" in 
		$ERR_REQ_F) ERR_MSG="[ERR-PAT-0020]   The patch configuration file is invalid (it either wasn't included in the patch, or is missing entries). The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support." 
		
		#"[ERR-PAT-0020] Cannot apply this patch. The patch configuration file is invalid." ;;
		;;
		$ERR_DEP)   ERR_MSG="[ERR-PAT-0021]   A patch with the same patch number is already installed. No further action is required."
		#"[ERR-PAT-0021] Cannot apply this patch. This patch has already been applied." ;;
		;;
		$ERR_REQ_P) ERR_MSG="[ERR-PAT-0022]   The patch requires another patch to be installed first. Please contact Technical Support."
		#"[ERR-PAT-0022] Cannot apply this patch. This patch requires previous patches." ;;
		;;
		$ERR_BAK)   ERR_MSG="[ERR-PAT-0023]   The patch system cannot back up the system for rollback purposes. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0023] Cannot apply this patch. Unable to backup the files." ;;
		;;
		$ERR_APP)   ERR_MSG="[ERR-PAT-0024]   The patch system cannot continue applying the patch. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0024] Cannot apply this patch. The system is not modified." ;;
		;;
		$ERR_VER)   ERR_MSG="[ERR-PAT-0025]   The patch system cannot continue applying the patch because one or more required files are missing. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0025] Cannot apply this patch. The patch lacks files." ;;
		;;
		$ERR_OTHER)   
			if [ -f ${ROOT}/config/error_msg ]; then
				ERR_MSG=`cat ${ROOT}/config/error_msg`
				rm -f ${ROOT}/config/error_msg
			else
				ERR_MSG="[ERR-PAT-0026]   The patch system cannot continue. The apply script returns error code ${_R}. This message is for diagnostic purposes only. Customers - please contact Technical Support."
			fi
		;;
		*)          ERR_MSG="[ERR-PAT-0026]   The patch system cannot continue. The apply script returns error code ${_R}. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0026] Cannot apply this patch. ($_R)";;
		;;
		esac
	
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "$ERR_MSG"
		return 1
	fi
	F_popd
}

F_call_apply_now() {
	cd ${EXTRACT_DIR} 
	if [ $? -ne 0 ] ; then
		 echo "The extracted directory doesn't exist. Please invoke '$0 untar ...' first"
		return 1
	fi
	#mkdir a backup dir according to patch number
	PATCH_NUMBER=`F_ini_get ${THISPATCHINI} PatchInfo Number`
	if [ $? -ne 0 ] ; then
		echo "Cannot access ${THISPATCHINI}."
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0027]   The patch is missing a patch number entry (from the file titled ${THISPATCHINI}). The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0027] Cannot retrieve patch number from ${THISPATCHINI}."
		return 1
	fi

	BACKUP_DIR_FOR_1_PATCH=${BACKUP_DIR}/${PATCH_NUMBER}
	mkdir -p ${BACKUP_DIR_FOR_1_PATCH}/files
	BACKUP_DIR_FOR_1_PATCH=`cd ${BACKUP_DIR_FOR_1_PATCH} && pwd && cd - > /dev/null 2>&1`

	F_file_exist ${APPLY_SCRIPT}
	if [ $? -ne 0 ] ; then
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "[ERR-PAT-0028]   The patch system cannot find the apply script titled ${APPLY_SCRIPT}, and the patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		#"[ERR-PAT-0028] Cannot use this patch. The ${APPLY_SCRIPT} is missing."
		return 1
	fi
	#call the patch backup apply script
	/bin/sh ./${APPLY_SCRIPT} "apply_now" ${INSTALL_ROOT} ${BACKUP_DIR_FOR_1_PATCH} 
	_R=$?
	if [ $_R -ne 0 ] ; then
		ERR_MSG=""
		
		case "$_R" in 
		$ERR_REQ_F) ERR_MSG="[ERR-PAT-0029]   The patch configuration file is invalid (it either wasn't included in the patch, or is missing entries). The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support." 
		;;
		$ERR_DEP)   ERR_MSG="[ERR-PAT-0030]   A patch with the same patch number is already installed. No further action is required."
		;;
		$ERR_REQ_P) ERR_MSG="[ERR-PAT-0031]   The patch requires another patch to be installed first. Please contact Technical Support."
		;;
		$ERR_BAK)   ERR_MSG="[ERR-PAT-0032]   The patch system cannot back up the system for rollback purposes. The patch cannot continue. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		;;
		$ERR_APP)   ERR_MSG="[ERR-PAT-0033]   The patch system cannot continue applying the patch. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		;;
		$ERR_VER)   ERR_MSG="[ERR-PAT-0034]   The patch system cannot continue applying the patch because one or more required files are missing. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		;;
		$ERR_OTHER)   
			if [ -f ${ROOT}/config/error_msg ]; then
				ERR_MSG=`cat ${ROOT}/config/error_msg`
				rm -f $ROOT/config/error_msg
			else
				ERR_MSG="[ERR-PAT-0035]   The patch system cannot continue. The apply script returns error code ${_R}. This message is for diagnostic purposes only. Customers - please contact Technical Support."
			fi
		;;
		*)          ERR_MSG="[ERR-PAT-0035]   The patch system cannot continue. The apply script returns error code ${_R}. This message is for diagnostic purposes only. Customers - please contact Technical Support."
		;;
		esac
	
		F_internal_error_report "${PATCH_MGM_INI}" "Error" "$ERR_MSG"
		return 1
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Finished" "The patch application is finished."
	echo "You have successfully installed Patch ${PATCH_NUMBER}." > $PATCH_SUCCESS_FILE
	chown iscan:iscan ${PATCH_SUCCESS_FILE}
	rm -rf ${EXTRACT_DIR}

}
PATCH_SUCCESS_FILE=/tmp/patch.success
#protect from apply run twice at the same time
PATCH_LOCK_FILE=/tmp/lock_patch_apply
if [ "$1" = "untar" ] ; then
	F_log_init
	F_internal_error_report "${PATCH_MGM_INI}" "Ready-to-Apply" "Ready to apply patch."
	F_decompress
	F_call_upload_check
	rm -f ${PATCH_LOCK_FILE}
else  
	# assume error check is done previously
	if [ -f "$PATCH_LOCK_FILE" ] ; then
		exit 0
	else
		touch $PATCH_LOCK_FILE
	fi
	F_internal_error_report "${PATCH_MGM_INI}" "Apply" "Begin to apply patch."
	F_call_apply_now
fi

