#!/bin/sh

THIS_SCRIPT_NAME=`basename $0`
# -- determine the home directory of this script
THIS_DIR=`dirname $0`
xstuff=`echo $0 | cut -c1-2`
if [ "." = "$THIS_DIR" -a "./" != "$xstuff" ] ; then
	# -- probably in $PATH
	THIS_DIR=`which $THIS_SCRIPT_NAME` 2> /dev/null
	if [ "" = "$THIS_DIR" ] ; then
		# -- give up
		THIS_DIR="."
	fi
fi
THIS_DIR=`cd $THIS_DIR; pwd`

ISCAN_BASE_DIR=/etc/iscan

usage()
{
	echo "Usage (export - create new migration package):"
	echo "    $THIS_SCRIPT_NAME  -e <migrationPackagePath>"
	echo "Usage (import - load existing migration package):"
	echo "    $THIS_SCRIPT_NAME  -i <migrationPackagePath>"
}

if [ "" = "$1" -o "?" = "$1" ] ; then
	usage
	exit 0
fi

xuserName=`id -un 2> /dev/null`
if [ "" != "$xuserName" -a "iscan" != "$xuserName" ] ; then
	echo "$THIS_SCRIPT_NAME: ERROR: this script must be run as user iscan" 1>&2
	exit 2
fi

setupLog()
{
	ARM_LOG=$ISCAN_BASE_DIR/log/arm_migration.log
	touch $ARM_LOG
	chmod a+w $ARM_LOG
	echo "--------------------------------------------------------------------------------" >> $ARM_LOG
	date >> $ARM_LOG
}

logErr()
{
	echo "$1" >> $ARM_LOG
	echo "$THIS_SCRIPT_NAME: $1" 1>&2
}

log()
{
	echo "$1" >> $ARM_LOG
	echo "$THIS_SCRIPT_NAME: $1"
}

setupLog

ARM_SCRIPTS_DIR=$THIS_DIR/arm_scripts

if [ ! -x $ARM_SCRIPTS_DIR ] ; then
	logErr "Cannot continue - support scripts are not available in expected directory: $ARM_SCRIPTS_DIR"
	exit 1
fi

TABLE_NAMES="tb_policy tb_rule tb_entity tb_prioritylist tb_entitytype tb_policytype"
SEQUENCE_NAMES="tb_policy_PolicyID_seq tb_rule_RuleID_seq tb_entity_EntityID_seq"

ARM_STATUS_SCRIPT=$THIS_DIR/show-arm-status.sh
ARM_IMPORT_SCRIPT_NAME=migrateImport.sh
ARM_EXPORT_SCRIPT_NAME=migrateExport.sh

MIGRATE_PKG_NAME=MigratePkg.tar.gz

ACTIVATED=`$ARM_STATUS_SCRIPT`

fullPath()
{
	xname=`basename $1`
	xdir=`dirname $1`
	xdir=`cd $xdir; pwd`
	echo "$xdir/$xname"
}

doExport()
{
	if [ -r $migratePkgPath ] ; then
		rm -f $migratePkgPath
		if [ $? -ne 0 ] ; then
			logErr "Migrate export failed: failed to remove existing output file: $migratePkgPath"
			exit 1
		fi
	fi
	
	log "Starting export ..."
	( cd $ARM_SCRIPTS_DIR; ./$ARM_EXPORT_SCRIPT_NAME $migratePkgPath "$TABLE_NAMES" ) >> $ARM_LOG 2>> $ARM_LOG
	xrc=$?
	if [ $xrc -ne 0 ] ; then
		logErr "Migrate export failed: inner script returned $xrc"
		exit 1
	fi
	
	if [ ! -r $migratePkgPath ] ; then
		logErr "Migrate export failed: package not found where expected: $migratePkgPath"
		exit 1
	fi

	log "export completed successfully"
}

doImport()
{
	if [ ! -r $migratePkgPath ] ; then
		logErr "Migrate import failed: import package is not accessible: $migratePkgPath"
		exit 1
	fi
	
	log "Starting import ..."
	( cd $ARM_SCRIPTS_DIR; ./$ARM_IMPORT_SCRIPT_NAME $migratePkgPath "$TABLE_NAMES" "$SEQUENCE_NAMES" ) >> $ARM_LOG 2>> $ARM_LOG
	xrc=$?
	if [ $xrc -ne 0 ] ; then
		logErr "Migrate import failed: inner script returned $xrc"
		exit 1
	fi
	
	( $ISCAN_BASE_DIR/S99ISagent reload& $ISCAN_BASE_DIR/S99IScanHttpd restart& $ISCAN_BASE_DIR/S99ISftp restart& ( $ISCAN_BASE_DIR/S99ISproxy stop; $ISCAN_BASE_DIR/S99ISproxy start)& wait ) >> $ARM_LOG 2>> $ARM_LOG
	
	log "import completed successfully"
}

operation=$1
migratePkgPath=$2

if [ "" = "$migratePkgPath" ] ; then
	logErr "Second parameter must be the file path of the migration package"
	usage
	exit 1
fi

migratePkgPath=`fullPath $migratePkgPath`

if [ "-e" = "$operation" ] ; then
	doExport
elif [ "-i" = "$operation" ] ; then
	doImport
else
	logErr "First parameter must be \"-e\" or \"-i\""
	usage
	exit 1
fi

exit 0
