#!/bin/sh
# ./activate <hostIp> <pgPort> <armDb> <armUser> <armPw>

export POSTGRES_HOST=$1
export POSTGRES_PORT=$2
export POSTGRES_DATABASE=$3
export DBUSER=$4
export PGPASSWORD=$5

. ./util_source.sh
. ./arm_activation_common.sh

export PATH=$PG_BIN:$PATH

error_exit()
{
	bkup_restoreFiles
	setIscanCrontab
	rm -rf $ARM_DIR
	
	echo "IWSS PostgreSQL environment set up failed. Nothing has been changed." 1>&2
	exit 1
}

handleOperationErr()
{
	echo "Script execution aborted" 1>&2
	error_exit
}

trap "handleOperationErr" 10

handleEnvErr()
{
	echo "Script execution terminated: execution problem" 1>&2
	error_exit
}

trap "handleEnvErr" 1 2 3 4 5 6 7 8 11 12 13 14 15

initx()
{
	mkdir -p $TMP_DIR
	saveFile_initEx $ARM_DIR
	bkup_initEx $BKUP_DIR
}

saveFiles()
{
	saveFile_save   $PGPASS_FILE
	saveFile_saveEx $ODBCINI_FILE
	saveFile_saveEx $ODBCINSTINI_FILE
	saveFile_saveEx $INTSCANINI_FILE
}

makePgpass()
{
	echo "$POSTGRES_HOST:$POSTGRES_PORT:*:$DBUSER:$PGPASSWORD" > $PGPASS_FILE
	echo "$POSTGRES_HOST:$POSTGRES_PORT:*:iscan:$PGPASSWORD" >> $PGPASS_FILE
	chown iscan $PGPASS_FILE
	chgrp iscan $PGPASS_FILE
	chmod 600 $PGPASS_FILE	
}

testPsqlConnection()
{
	bkup_pushFile $PGPASS_FILE
	if [ ! -z "$PGPASSWORD" ] ; then
		makePgpass
	else
		util_rmFile $PGPASS_FILE
	fi

	if $PG_BIN/psql -h $POSTGRES_HOST -p $POSTGRES_PORT -U $DBUSER -d $POSTGRES_DATABASE < /dev/null ; then
		echo "Connection via psql successful"
	else
		echo 'Connection via psql failed' 1>&2
		util_rmFile $PGPASS_FILE
		error_exit
	fi
}

testOdbcConnection()
{
	if [ ! -f $USR_DIR/isql ] ; then
		echo "$USR_DIR/isql missing" 1>&2
		error_exit
	fi

	util_cpFileEx $ODBCINI_FILE $TMP_DIR/odbc.ini
	util_cpFileEx $ODBCINSTINI_FILE $TMP_DIR/odbcinst.ini
	
	util_changeIniValueInPlaceEx $TMP_DIR/odbc.ini $TMP_DIR/odbc.ini.bak = IWSS Database   $POSTGRES_DATABASE
	util_changeIniValueInPlaceEx $TMP_DIR/odbc.ini $TMP_DIR/odbc.ini.bak = IWSS Servername $POSTGRES_HOST
	util_changeIniValueInPlaceEx $TMP_DIR/odbc.ini $TMP_DIR/odbc.ini.bak = IWSS Port       $POSTGRES_PORT
	util_changeIniValueInPlaceEx $TMP_DIR/odbc.ini $TMP_DIR/odbc.ini.bak = IWSS UserName   $DBUSER
	util_changeIniValueInPlaceEx $TMP_DIR/odbc.ini $TMP_DIR/odbc.ini.bak = IWSS Password   "$PGPASSWORD"

	# unixODBC test
	export LD_LIBRARY_PATH=$LIB_PATH
	export ODBCSYSINI=$TMP_DIR 
	export ODBCINI=$TMP_DIR/odbc.ini 
	
	$USR_DIR/isql -b -v IWSS < /dev/null
	EXIT_CODE=$?
	
	export ODBCSYSINI=$VAR_DIR 
	export ODBCINI=$VAR_DIR/odbc.ini 

	if [ $EXIT_CODE -eq 0 ] ; then
		echo "Connection via unixODBC successful"
		bkup_pushFileEx $ODBCINSTINI_FILE
		bkup_pushFileEx $ODBCINI_FILE
		util_mvFileEx $TMP_DIR/odbc.ini $VAR_DIR
		util_mvFileEx $TMP_DIR/odbcinst.ini $VAR_DIR
	else
		echo "Connection via unixODBC failed" 1>&2
		error_exit
	fi
}

updateMetricsNotifyAdmin()
{
	# 5 concatenated values (0 or 1): virus|spyware|database|hard disk|bandwidth

	xval=`util_getIniValue $INTSCANINI_FILE = metrics notifyadmin`
	if [ $? -ne 0 ] ; then
		util_funcErr updateMetricsNotifyAdmin "failed to access value for [metrics]notifyadmin in $INTSCANINI_FILE"
		return 1
	fi
	if [ "" = "$xval" ] ; then
		util_funcErr updateMetricsNotifyAdmin "empty value for [metrics]notifyadmin"
		return 0
	fi
	
	xp1=`echo $xval | cut -c1-2`
	# -- leave out database flag part
	xp2=`echo $xval | cut -c4-5`
	xnewval=${xp1}0${xp2}
	
	workFile=$TMP_DIR/intscan.ini.work
	
	util_setIniValueInPlace    $INTSCANINI_FILE $workFile = metrics notifyadmin     $xnewval
	if [ $? -ne 0 ] ; then
		util_funcErr updateMetricsNotifyAdmin "failed to update value for [metrics]notifyadmin in $INTSCANINI_FILE"
		return 1
	fi
	return 0
}

updateIntscanIni()
{
	# Modify isinst.ini
	echo "Modifying intscan.ini"
	ENCPWD=`$USR_DIR/bin/encpw $PGPASSWORD`

	bkup_pushFileEx $INTSCANINI_FILE
	
	workFile=$TMP_DIR/intscan.ini.work

	util_setIniValueInPlaceEx    $INTSCANINI_FILE $workFile = Database remote_db     yes
	util_setIniValueInPlaceEx    $INTSCANINI_FILE $workFile = Database ARM_DB        yes
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DSN           IWSS
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database JdbcUrl       jdbc:odbc:IWSS
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database SqlPath       $SQL_PATH
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DB            $POSTGRES_DATABASE
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DB_HOSTNAME   $POSTGRES_HOST
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DB_PORT       $POSTGRES_PORT
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database User          $DBUSER
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database Password      $ENCPWD
}

cleanup()
{
	bkup_cleanup
	rm -rf $TMP_DIR
}

armActivated
if [ $? = 0  ] ; then
	echo "This server is already activated - run arm_deactivate.sh before rerunning the activation script" 1>&2
	exit 0
fi

initx

saveFiles

testPsqlConnection

testOdbcConnection

updateIntscanIni

updateMetricsNotifyAdmin

setArmCrontabEx

enableLocalDbCmds no

restartDaemons

cleanup

echo "ARM activation finished successfully."

exit 0
