#!/bin/sh

VAR_DIR=/var/iwss
USR_DIR=/usr/iwss
#VAR_DIR=tst/var
#USR_DIR=tst/usr

ARM_DIR=$VAR_DIR/ARM_ACTIVATION
TMP_DIR=$ARM_DIR/tmp
BKUP_DIR=$ARM_DIR/bkup

LIB_PATH=$USR_DIR/lib
SQL_PATH=$USR_DIR/sql/postgresql
PG_BIN=$USR_DIR/PostgreSQL/bin

PGPASS_FILE=$VAR_DIR/.pgpass
ODBCINI_FILE=$VAR_DIR/odbc.ini
ODBCINSTINI_FILE=$VAR_DIR/odbcinst.ini
INTSCANINI_FILE=$VAR_DIR/intscan.ini

UIHELPER=$VAR_DIR/AdminUI/uihelper

IWSS_RESTART_SCRIPTS='canHttpd logtodb proxy ftp MetricMgmtd'

OS=`uname -s`

restartDaemons()
{
	for script in $IWSS_RESTART_SCRIPTS ; do
		$USR_DIR/S99IS$script stop
		$USR_DIR/S99IS$script start
	done
}

armDirExists()
{
	if [ -r $ARM_DIR ] ; then
		return 0
	else
		return 1
	fi
}

armActivated()
{
	util_checkVal $INTSCANINI_FILE = Database      ARM_DB     yes
	return $?
}

setCrontab()
{
	xcrontabFile=$1
	if [ -x $UIHELPER ] ; then
		# -- IWSA busybox crontab needs to run as root, so use uihelper
		$UIHELPER "crontab $xcrontabFile -u iscan"
	else
		crontab $xcrontabFile
	fi
	if [ $? -ne 0 ] ; then
		util_funcErr setCrontab "crontab failed when setting $xcrontabFile"
		return 1
	fi
	
	echo "$xcrontabFile set"
	return 0
}

restartCrond()
{
	if [ ! -x /sbin/service ] ; then
		util_funcWarn restartCrond "crond not restarted: /sbin/service not available"
	elif [ ! -x $UIHELPER ] ; then
		util_funcWarn restartCrond "crond not restarted: $UIHELPER not available"
	else
		$UIHELPER "/sbin/service crond restart"
		if [ $? -ne 0 ] ; then
			util_funcWarn restartCrond "crond not restarted: $UIHELPER invocation failed"
		fi
	fi
}

locateIscanFile()
{
	xfileName=$1
	if [ -r $VAR_DIR/$xfileName ] ; then
		echo "$VAR_DIR/$xfileName"
	elif [ -r $USR_DIR/$xfileName ] ; then
		echo "$USR_DIR/$xfileName"
	else
		util_funcErr locateIscanFile "$xfileName not found in either $VAR_DIR or $USR_DIR"
		return 1
	fi
}

setArmCrontabEx()
{
	setArmCrontab
	if [ $? -ne 0 ] ; then
		util_die
	fi
}

setArmCrontab()
{
	iscan_crontab=`locateIscanFile crontab.iscan`
	if [ "" = "$iscan_crontab" ] ; then
		return 1
	fi
	
	sed -e "/\/usr\/iwss\/bin\/schedulereport/d" \
        -e "/\/usr\/iwss\/bin\/DbOldDataCleanup\.sh/d" \
        -e "/\/usr\/iwss\/bin\/db_reindex\.sh/d" \
        -e "/\/usr\/iwss\/bin\/db_vacuum\.sh/d" \
         $iscan_crontab > $ARM_DIR/crontab.arm

	if [ $? -ne 0 ] ; then
		util_funcErr setArmCrontab "sed failed when editing $iscan_crontab"
		return 1
	fi
	
	setCrontab $ARM_DIR/crontab.arm
	if [ $? -ne 0 ] ; then
		return 1
	fi

	restartCrond
	
	return 0
}

setIscanCrontab()
{
	iscan_crontab=`locateIscanFile crontab.iscan`
	if [ "" = "$iscan_crontab" ] ; then
		return 1
	fi
	
	setCrontab $iscan_crontab
	if [ $? -ne 0 ] ; then
		return 1
	fi

	restartCrond

	return 0
}

enableLocalDbCmds()
{
	enable=$1
	if [ ! -d /etc/clish ] ; then
		return 0
	fi
	if [ ! -r /etc/clish/funcs.sh ] ; then
		util_funcWarn disable_database_command "/etc/clish exists but /etc/clish/funcs.sh is not accessible"
		return 0
	fi
	grep -q "disable_database_command()" /etc/clish/funcs.sh
	if [ $? -ne 0 ] ; then
		util_funcWarn disable_database_command "/etc/clish/funcs.sh does not have ARM specific patch applied"
		return 0
	fi
	
	if [ "$enable" = "yes" ] ; then
		( source /etc/clish/funcs.sh && enable_database_command )
		if [ $? -ne 0 ] ; then
			util_funcWarn disable_database_command "Invocation of enable_database_command in /etc/clish/funcs.sh failed"
			return 0
		fi
	else
		( source /etc/clish/funcs.sh && disable_database_command )
		if [ $? -ne 0 ] ; then
			util_funcWarn disable_database_command "Invocation of disable_database_command in /etc/clish/funcs.sh failed"
			return 0
		fi
	fi
}
