#!/bin/sh
# ./deactivate

. ./util_source.sh
. ./arm_activation_common.sh

error_exit()
{
	bkup_restoreFiles
	bkup_cleanup
	
	echo "ARM deactivation failed. Nothing has been changed." 1>&2
	exit 1
}

handleOperationErr()
{
	echo "Script execution aborted" 1>&2
	error_exit
}

trap "handleOperationErr" 10

handleEnvErr()
{
	echo "Script execution terminated: execution problem" 1>&2
	error_exit
}

trap "handleEnvErr" 1 2 3 4 5 6 7 8 11 12 13 14 15

initx()
{
	if [ ! -r $ARM_DIR ] ; then
		echo "ARM activation file save directory does not exist or is not accessible: $ARM_DIR" 1>&2
		error_exit
	fi
	
	mkdir -p $TMP_DIR
	bkup_initEx $BKUP_DIR
	saveFile_initEx $ARM_DIR
}

cleanup()
{
	bkup_cleanup
	rm -rf $TMP_DIR
	rm -rf $ARM_DIR
}

updateIni()
{
	savedIniFile=`saveFile_savedFile $INTSCANINI_FILE`
	test "" != "$savedIniFile" || util_funcFatal updateIni "saved intscan.ini file not found"
	
	x_remote_db=`util_getIniValue $savedIniFile = Database remote_db`
	test "" != "$x_remote_db" || util_funcFatal updateIni "[Database]remote_db value is empty in saved intscan.ini"
	x_DSN=`util_getIniValue $savedIniFile = Database DSN`
	test "" != "$x_DSN" || util_funcFatal updateIni "[Database]DSN value is empty in saved intscan.ini"
	x_JdbcUrl=`util_getIniValue $savedIniFile = Database JdbcUrl`
	test "" != "$x_JdbcUrl" || util_funcFatal updateIni "[Database]JdbcUrl value is empty in saved intscan.ini"
	x_SqlPath=`util_getIniValue $savedIniFile = Database SqlPath`
	test "" != "$x_SqlPath" || util_funcFatal updateIni "[Database]SqlPath value is empty in saved intscan.ini"
	x_DB=`util_getIniValue $savedIniFile = Database DB`
	test "" != "$x_DB" || util_funcFatal updateIni "[Database]DB value is empty in saved intscan.ini"
	x_DB_HOSTNAME=`util_getIniValue $savedIniFile = Database DB_HOSTNAME`
	test "" != "$x_DB_HOSTNAME" || util_funcFatal updateIni "[Database]DB_HOSTNAME value is empty in saved intscan.ini"
	x_DB_PORT=`util_getIniValue $savedIniFile = Database DB_PORT`
	test "" != "$x_DB_PORT" || util_funcFatal updateIni "[Database]DB_PORT value is empty in saved intscan.ini"
	x_User=`util_getIniValue $savedIniFile = Database User`
	test "" != "$x_User" || util_funcFatal updateIni "[Database]User value is empty in saved intscan.ini"
	x_Password=`util_getIniValue $savedIniFile = Database Password`
	test "" != "$x_Password" || util_funcFatal updateIni "[Database]Password value is empty in saved intscan.ini"

	workFile=$TMP_DIR/intscan.ini.work

	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database remote_db     $x_remote_db
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database ARM_DB        no
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DSN           $x_DSN
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database JdbcUrl       $x_JdbcUrl
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database SqlPath       $x_SqlPath
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DB            $x_DB
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DB_HOSTNAME   $x_DB_HOSTNAME
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database DB_PORT       $x_DB_PORT
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database User          $x_User
	util_changeIniValueInPlaceEx $INTSCANINI_FILE $workFile = Database Password      $x_Password
}

deactivate()
{
	bkup_pushFile    $PGPASS_FILE
	saveFile_restore $PGPASS_FILE
	
	bkup_pushFileEx    $ODBCINI_FILE
	saveFile_restoreEx $ODBCINI_FILE

	bkup_pushFileEx    $ODBCINSTINI_FILE
	saveFile_restoreEx $ODBCINSTINI_FILE

	bkup_pushFileEx    $INTSCANINI_FILE
	updateIni
}

armActivated
if [ $? != 0  ] ; then
	echo "This server is not currently activated " 1>&2
	exit 0
fi

initx

deactivate

setIscanCrontab

enableLocalDbCmds yes

restartDaemons

cleanup

echo "ARM deactivation finished successfully."

exit 0
