#!/bin/sh

. ./util_source.sh
. ./arm_activation_common.sh

export PATH=$PG_BIN:$PATH

PSQL_CMD=/usr/iwss/PostgreSQL/bin/psql
TMP_DIR=/etc/iscan/tmp

tar_file=$1; shift
tables=$1; shift

clearCsvFiles()
{
	tableFiles=
	for tbl
	do
		tableFiles="$tableFiles $tbl.csv"
	done
	
	rm $tableFiles 2> /dev/null
}

cleanup()
{
	clearCsvFiles  $tables
	if [ "" != "$cmd_file" ] ; then
		rm $cmd_file 2> /dev/null
	fi
}

error_exit()
{
	cleanup
	exit 1
}

handleOperationErr()
{
	trap 10
	echo "Script execution aborted" 1>&2
	error_exit
}

trap "handleOperationErr" 10

handleEnvErr()
{
	trap 1 2 3 4 5 6 7 8 11 12 13 14 15
	echo "Script execution terminated: execution problem" 1>&2
	error_exit
}

trap "handleEnvErr" 1 2 3 4 5 6 7 8 11 12 13 14 15

#
# migrateExport.sh Tables.tar 10.2.42.238 "tb_policy tb_rule tb_entity tb_prioritylist tb_entitytype tb_policytype"
#

getOdbcVal()
{
	xval=`util_getIniValue $ODBCINI_FILE = $1 $2`
	if [ "" = "$xval" ] ; then
		util_funcErr getOdbcVal "failed to get [$1]$2 from $ODBCINI_FILE"
		return 1
	fi
	echo $xval
}

db_hostname=`getOdbcVal IWSS Servername`;
if [ 0 != $? ] ; then
	error_exit
fi
db_port=`getOdbcVal IWSS Port`;
if [ 0 != $? ] ; then
	error_exit
fi
db_user=`getOdbcVal IWSS UserName`;
if [ 0 != $? ] ; then
	error_exit
fi
db_name=`getOdbcVal IWSS Database`;
if [ 0 != $? ] ; then
	error_exit
fi
db_pw=`getOdbcVal IWSS Password`;
if [ 0 != $? ] ; then
	error_exit
fi


#tables="tb_policy tb_rule tb_entity tb_prioritylist tb_entitytype tb_policytype"


tarCsvFiles()
{
	tableFiles=
	for tbl
	do
		tableFiles="$tableFiles $tbl.csv"
	done
	
	tar czf $tar_file $tableFiles
	if [ 0 -ne $? ] ; then
		util_funcErr tarCsvFiles "failed to generate export package tar file: $tar_file"
		error_exit
	fi
}

getSchemaName()
{
	xstuff=`$PSQL_CMD -h $db_hostname -p $db_port -U $db_user -d $db_name -c "\d tb_policy;" | grep -i "from.*farm_schema_.*tb_policy" | sed -e "s/.*FROM \(farm_schema_.*\).tb_policy.*/\1/" 2>/dev/null`
	if [ "" != "$xstuff" ] ; then
		xstuff="$xstuff."
	fi
	#xstuff=`$PSQL_CMD -h $db_hostname -p $db_port -U $db_user -d $db_name -c "\d tb_policy"  | grep "FROM farm_schema_.*\.tb_policy" -o`
	#echo "SCHEMA QUERY RESULT: $xstuff" 1>&2
	#xstuff=`echo $xstuff | grep "farm_schema_.*\." -o`
	echo "$xstuff"
}

initCmdFile()
{
	cmdFile="cmd_$$.txt"
	echo "\set ON_ERROR_STOP" > $cmdFile
	echo $cmdFile
}

genCopies()
{
	# -- /bin/echo "\copy" - the "\c" can cause problems, so emit the '\' separately
	for tbl
	do
		echo -n '\' >> $cmd_file
		echo "copy ${db_schema}$tbl to $tbl.csv with delimiter ',' " >> $cmd_file
	done
}

dumpTables()
{
	$PSQL_CMD -h $db_hostname -p $db_port -U $db_user -d $db_name -f $cmd_file
	rc=$?
	if [ 0 -ne $rc ] ; then
		util_funcErr dumpTables "Dump of tables via PSQL failed: rc = $rc"
		error_exit
	fi
	echo "TABLES DUMPED: RC = $rc"
}

work_dir=$TMP_DIR/armmigrate_$$
mkdir $work_dir
if [ ! -x $work_dir ] ; then
	util_funcErr main "failed to create work directory: $work_dir"
	exit 1
fi

cd $work_dir
trap "cd /etc/iscan; rm -rf $work_dir" 0

db_schema=`getSchemaName`
echo "SCHEMA NAME IS: [$db_schema]"

cmd_file=`initCmdFile` 

genCopies $tables

dumpTables

tarCsvFiles $tables

cleanup

exit 0
