#!/bin/sh

THIS_SCRIPT_NAME=`basename $0`
# -- determine the home directory of this script
THIS_DIR=`dirname $0`
xstuff=`echo $0 | cut -c1-2`
if [ "." = "$THIS_DIR" -a "./" != "$xstuff" ] ; then
	# -- probably in $PATH
	THIS_DIR=`which $THIS_SCRIPT_NAME` 2> /dev/null
	if [ "" = "$THIS_DIR" ] ; then
		# -- give up
		THIS_DIR="."
	fi
fi
THIS_DIR=`cd $THIS_DIR; pwd`

ISCAN_BASE_DIR=/etc/iscan

usage()
{
	echo "Usage (activation):"
	echo "    $THIS_SCRIPT_NAME  -r psqlparam=<armHost>:<psqlPort>:<dbName>:<dbUserName>:<dbPassword>"
	echo "Usage (deactivation):"
	echo "    $THIS_SCRIPT_NAME  -u"
	echo "NOTE: must be run as user iscan"
}

if [ "" = "$1" -o "?" = "$1" ] ; then
	usage
	exit 0
fi

xuserName=`id -un 2> /dev/null`
if [ "" != "$xuserName" -a "iscan" != "$xuserName" ] ; then
	echo "$THIS_SCRIPT_NAME: ERROR: this script must be run as user iscan" 1>&2
	exit 2
fi

setupLog()
{
	ARM_LOG=$ISCAN_BASE_DIR/log/arm_register.log
	touch $ARM_LOG
	chmod a+w $ARM_LOG
	echo "--------------------------------------------------------------------------------" >> $ARM_LOG
	date >> $ARM_LOG
}

logErr()
{
	echo "$1" >> $ARM_LOG
	echo "$THIS_SCRIPT_NAME: $1" 1>&2
}

log()
{
	echo "$1" >> $ARM_LOG
	echo "$THIS_SCRIPT_NAME: $1"
}

setupLog

ARM_SCRIPTS_DIR=$THIS_DIR/arm_scripts

if [ ! -x $ARM_SCRIPTS_DIR ] ; then
	logErr "Cannot continue - support scripts are not available in expected directory: $ARM_SCRIPTS_DIR"
	exit 1
fi

mode=
if [ "-r" = "$1" ] ; then
	mode="activate"
elif [ "-u" = "$1" ] ; then
	mode="deactivate"
else
	logErr "Invalid operation: $1"
	usage
	exit 1
fi

cd $ARM_SCRIPTS_DIR

exitCode=0

activatedHost=`./arm_status.sh`
activated=$?

if [ "$mode" = "activate" ] ; then
	if [ $activated -eq 0 ] ; then
		logErr "This device is already activated with the ARM at $activatedHost"
		exit 2
	fi
	
	psqlparam=`echo $2 | cut -d '=' -f 2`

	armIp=`echo $psqlparam | cut -d ':' -f 1`
	armPort=`echo $psqlparam | cut -d ':' -f 2`
	armDb=`echo $psqlparam | cut -d ':' -f 3`
	armDbuser=`echo $psqlparam | cut -d ':' -f 4`
	armDbpw=`echo $psqlparam | cut -d ':' -f 5`

	log "Activating device with the ARM at $armIp"
	./arm_activate.sh $armIp $armPort $armDb $armDbuser $armDbpw >> $ARM_LOG 2>> $ARM_LOG
	exitCode=$?
else
	if [ $activated -ne 0 ] ; then
		logErr "This device is not activated with ARM"
		exit 3
	fi
	
	log "Deactivating device from the ARM at $activatedHost"
	./arm_deactivate.sh >> $ARM_LOG 2>> $ARM_LOG
	exitCode=$?
fi

if [ 0 -eq $exitCode ] ; then
	logErr "$mode operation succeeded"
else
	log "$mode operation failed: exit code: $exitCode"
fi

exit $exitCode
