#!/bin/sh

TMP_DIR=/tmp/iwss_postgres_env
VAR_DIR=/var/iwss
LIB_PATH=/etc/iscan/lib
SQL_PATH=/usr/iwss/sql/postgresql
PG_BIN=/usr/iwss/PostgreSQL/bin
PGPASS_FILE=/etc/iscan/.pgpass
OS=`uname -s`
REMOTE_DB=0
POSTGRES_HOST=localhost

error_exit()
{
	echo "IWSS PostgreSQL environment set up failed.  Nothing has been changed."
	echo "Fix your problem and try again later."
	rm -rf $TMP_DIR
	exit
}

mkdir -p $TMP_DIR
PATH=/etc/iscan/PostgreSQL/bin:$PATH ; export PATH

# Test PostgreSQL connectivity via psql
echo "Use remote PostgreSQL database [ Yes/No ] (Default: No)"
read DB_REMOTE_V

if [ -z "$DB_REMOTE_V" -o "$DB_REMOTE_V" = "No" -o "$DB_REMOTE_V" = "no" -o "$DB_REMOTE_V" = "n" -o "$DB_REMOTE_V" = "N" -o "$DB_REMOTE_V" = "NO" ] ; then
        REMOTE_DB=0
else
        REMOTE_DB=1
fi

#echo "REMOTE_DB:" $REMOTE_DB

if [ "$REMOTE_DB" = "1" ] ; then

	echo "Specify PostgreSQL server name or IP address"
	read POSTGRES_HOST

	if [ -z "$POSTGRES_HOST" -o "$POSTGRES_HOST" = "localhost" -o "$POSTGRES_HOST" = "127.0.0.1" ] ; then
        	POSTGRES_HOST=localhost
        	REMOTE_DB=0
	fi
fi

echo "Specify port number of PostgreSQL [ 5432 ]"
read POSTGRES_PORT
if [ -z "$POSTGRES_PORT" ] ; then POSTGRES_PORT=5432 ; fi

echo "Specify database name of PostgreSQL [ iwss ]"
read POSTGRES_DATABASE
if [ -z "$POSTGRES_DATABASE" ] ; then POSTGRES_DATABASE=iwss ; fi

echo "Specify the user name for PostgreSQL [ sa ]"
read DBUSER
if [ -z "$DBUSER" ] ; then DBUSER=sa ; fi

echo "Specify the password for user \"$DBUSER\""
read PGPASSWORD
export PGPASSWORD
makePgpass()
{
	echo "$POSTGRES_HOST:$POSTGRES_PORT:*:$DBUSER:$PGPASSWORD" > $PGPASS_FILE
	echo "$POSTGRES_HOST:$POSTGRES_PORT:*:iscan:$PGPASSWORD" >> $PGPASS_FILE
	chown iscan $PGPASS_FILE
	chgrp iscan $PGPASS_FILE
	chmod 600 $PGPASS_FILE	
}
if [ ! -z "$PGPASSWORD" ] ; then
	makePgpass
else
	rm -f $PGPASS_FILE
fi

if $PG_BIN/psql -h $POSTGRES_HOST -p $POSTGRES_PORT -U $DBUSER -d $POSTGRES_DATABASE < /dev/null ; then
	echo "Connection via psql successful"
else
	echo 'Connection via psql failed'
	echo 'The reason may be one of the following'
	echo '  The hostname/IP address, port number is wrong.'
	echo '  PostgreSQL is down.'
	echo '  PostgreSQL down not allow TCP/IP connection ( "-i" option for postmaster )'
	echo '  PostgreSQL does not allow connection from this machine. ( pg_hba.conf )'
	echo '  PostgreSQL does not have user or database designated.'
	echo '  Password was wrong'
	error_exit
fi

cat /etc/iscan/odbcinst.ini > $TMP_DIR/odbcinst.ini
cat /etc/iscan/odbc.ini |                                                 \
	sed -e "s|\(Database \{0,\}= \{0,\}\).\{0,\}|\1$POSTGRES_DATABASE|"   \
	-e "/^\[IWSS\]/,/^\[.\{0,\}\]/s|\(Servername \{0,\}= \{0,\}\).\{0,\}|\1$POSTGRES_HOST|"     \
	-e "/^\[IWSS\]/,/^\[.\{0,\}\]/s|\(Port \{0,\}= \{0,\}\).\{0,\}|\1$POSTGRES_PORT|"           \
	-e "/^\[IWSS\]/,/^\[.\{0,\}\]/s|\(UserName \{0,\}= \{0,\}\).\{0,\}|\1$DBUSER|"              \
	-e "/^\[IWSS\]/,/^\[.\{0,\}\]/s|\(Password \{0,\}= \{0,\}\).\{0,\}|\1$PGPASSWORD|" > $TMP_DIR/odbc.ini

if [ ! -f /usr/iwss/isql ] ; then
	echo "/usr/iwss/isql missing"
fi

# unixODBC test
LD_LIBRARY_PATH=$LIB_PATH
export LD_LIBRARY_PATH
ODBCSYSINI=$TMP_DIR 
export ODBCSYSINI
ODBCINI=$TMP_DIR/odbc.ini 
export ODBCINI
/usr/iwss/isql -b -v IWSS < /dev/null
EXIT_CODE=$?
# To allow SIGPIPE ( Broken Pipe ), allow exit code 141 on Solaris
if [ $EXIT_CODE = 0 ] || [ "SunOS" = "$OS" -a $EXIT_CODE = 141 ] ; then
	echo "Connection via unixODBC successful"
else
	echo "Connection via unixODBC failed"
	error_exit
fi

# Modify isinst.ini
echo "Modifying intscan.ini"
ENCPWD=`/usr/iwss/bin/encpw $PGPASSWORD`

cp -f /etc/iscan/intscan.ini /etc/iscan/intscan.ini.bak
if [ $REMOTE_DB == "1" ] ; then
	sed -e "/^\[Database\]/,/^\[.\{0,\}\]/s/\(remote_db=\).\{0,\}/\1yes/"	\
	/etc/iscan/intscan.ini.bak > /etc/iscan/intscan.ini
else
	sed -e "/^\[Database\]/,/^\[.\{0,\}\]/s/\(remote_db=\).\{0,\}/\1no/"	\
	/etc/iscan/intscan.ini.bak > /etc/iscan/intscan.ini
fi

cp -f /etc/iscan/intscan.ini /etc/iscan/intscan.ini.bak
sed -e "/^\[Database\]/,/^\[.\{0,\}\]/s/\(DSN=\).\{0,\}/\1IWSS/"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s/\(JdbcUrl=jdbc:odbc:\).\{0,\}/\1IWSS/"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s|\(SqlPath=\).\{0,\}|\1$SQL_PATH|"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s|\(DB=\).\{0,\}|\1$POSTGRES_DATABASE|"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s|\(DB_HOSTNAME=\).\{0,\}|\1$POSTGRES_HOST|"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s|\(DB_PORT=\).\{0,\}|\1$POSTGRES_PORT|"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s|\(User=\).\{0,\}|\1$DBUSER|"	\
    -e "/^\[Database\]/,/^\[.\{0,\}\]/s|\(Password=\).\{0,\}|\1$ENCPWD|"	\
	/etc/iscan/intscan.ini.bak > /etc/iscan/intscan.ini
rm -f /etc/iscan/intscan.ini.bak

# Modify odbcinst.ini and odbc.ini
echo "Updating ODBC configuration files"
cat $TMP_DIR/odbcinst.ini > /etc/iscan/odbcinst.ini
cat $TMP_DIR/odbc.ini     > /etc/iscan/odbc.ini

ODBCSYSINI=$VAR_DIR 
export ODBCSYSINI
ODBCINI=$VAR_DIR/odbc.ini 
export ODBCINI

echo
echo "Do you want to create tables and stored procedures on the designated PostgreSQL server ? ( y/n ) [ n ]"
echo "  -- Notice --"
echo "  All existing data in the IWSS related table will be lost if you select YES"
echo
read RESP
case $RESP in
Y*|y*)
	su - iscan -c "$PG_BIN/psql -h $POSTGRES_HOST -p $POSTGRES_PORT -U $DBUSER -d $POSTGRES_DATABASE < $SQL_PATH/install/RemoveTables.sql"
	cd $SQL_PATH/install ; 
	su - iscan -c "$SQL_PATH/install/InitDatabase.sh $POSTGRES_HOST $POSTGRES_PORT $POSTGRES_DATABASE $DBUSER"
	;;
esac

#Restart only enabled scanning daemon
HTTPDaemonScript="S99ISproxy"
FTPDaemonScript="S99ISftp"

HTTPDaemonStatus=`grep ui_set_http_daemon /etc/iscan/intscan.ini | cut -d'=' -f2`
FTPDaemonStatus=`grep ui_set_ftp_daemon /etc/iscan/intscan.ini | cut -d'=' -f2`
if test $HTTPDaemonStatus = stop ; then
	HTTPDaemonScript=
fi
if test $FTPDaemonStatus = stop ; then
	FTPDaemonScript=
fi

#for script in canHttpd logtodb proxy ftp MetricMgmtd; do
#	/usr/iwss/S99IS$script stop
#	/usr/iwss/S99IS$script start
#done
scripts="S99IScanHttpd S99ISlogtodb $HTTPDaemonScript $FTPDaemonScript S99ISMetricMgmtd"
for script in $scripts ; do
	/usr/iwss/$script stop
	/usr/iwss/$script start
done

echo "IWSS PostgreSQL environment set-up finished successfully."

rm -rf $TMP_DIR

