#! /bin/sh

# ########################################### #
# OS detection and platform specific commands #
# ########################################### #

SYS=`uname -s`
if test $SYS = "SunOS" ; then
    MACHINE="Sol"
    ECHO="echo"
    PS="ps -ef"
else 
	if test $SYS = "Linux" ; then
    MACHINE="Linux"
    ECHO="echo -e"
    PS="ps -ef --width 1000"
	else
    echo $SYS "is an unsupported OS platform."
    exit 1
	fi 
fi

# ############### #
# Asking function #
# ############### #

yesno(){
	yn_result=""
	while [ -z "$yn_result" ]; do
		read yn_reply
		case "$yn_reply" in
			[Yy][Ee][Ss]) # yes, YES, Yes...etc
				yn_result=0;;
			[Nn][Oo]) # no, NO, No...etc
				yn_result=1;;
			[Yy]) # Y,y...etc
				yn_result=0;;
			[Nn]) # N,n...etc
				yn_result=1;;				
			*)
				printf "No\n"
				yn_result=1;;
		esac
	done
	return $yn_result
}

# #################### #
# Files and path setup #
# #################### #

STOP_CMD='STOP_MCP.CMD'
LOGOFF_CMD='LOGOFF_MCP.CMD'
UNREG_CMD='UNREG_MCP.CMD'
IWSS_PATH=/etc/iscan
ISAGENT_PATH=`cat $IWSS_PATH/pkg/ISAGENT_MCP`
if [ ! -d $ISAGENT_PATH ]; then
    $ECHO "$ISAGENT_PATH directory not found"
    exit -1
fi

# ################ #
# Cleanup function #
# ################ #

cleanup_by_term(){
		IFS=$'\n'
		processes=`ps -e | grep -v grep | grep En_Main | awk '{print $1}'`
		for process in "${processes}"; do
			if [ "$process" != "" ]; then
				kill -TERM $process
			fi
		done
}

cleanup_by_force(){
		IFS=$'\n'
		processes=`ps -e | grep -v grep | grep En_Main | awk '{print $1}'`
		for process in "${processes}"; do
			if [ "$process" != "" ]; then
				kill -9 $process
			fi
		done
		rm -f $ISAGENT_PATH/*.CMD
}

# #################### #
# Main logical routine #
# #################### #

cd $ISAGENT_PATH
ENTITY_PID=`cat $ISAGENT_PATH/Product.ini | grep 'ENTITY_pid=' | cut -b 12-`
if [ "$ENTITY_PID" = "" ]; then
	ENTITY_PID=`ps -e | grep -v grep | grep 'En_Main' | cut -b 1-5`
fi

if [ "$ENTITY_PID" != "" ]; then
	CHECK_ENTITY="ps -p $ENTITY_PID | grep -v grep | grep 'En_Main' > /dev/null"
	
	eval "$CHECK_ENTITY"
	if [ $? = 0 ]; then
		printf "Stopping InterScan Web Security Suite 3.1 MCP agent"
		export LD_LIBRARY_PATH=/usr/iwss/lib:$IWSS_PATH:$ISAGENT_PATH:
		touch $STOP_CMD && chown iscan:iscan $STOP_CMD
		if [ "$1" = "logoff" ]; then
			touch $LOGOFF_CMD
		fi
		
		if [ "$1" = "unregister" ]; then
			touch $UNREG_CMD
		fi

		cleanup_by_term
		
		LOOP=0
		MAX_LOOP=6
		while [ $LOOP -lt `expr $MAX_LOOP + 1` ]; do
			eval "$CHECK_ENTITY"
			if [ $? != 0 ]; then
				LOOP=$MAX_LOOP
				printf "stopped.\n"
				break
			fi
			if [ $LOOP -eq $MAX_LOOP ]; then
				if [ "$1" = "force" ]; then
					eval "$CHECK_ENTITY"
					if [ $? = 0 ]; then
					
						cleanup_by_force
						
						if [ $? = 0 ]; then
							printf "force stopped.\n"
						else
							printf "Try to stop it manually.\n"
						fi
					fi
				else
					if [ "$1" != "unregister" ]; then
						printf "time out.\n"
						printf "The shutdown time exceed "`expr $MAX_LOOP \* 10`" second(s)!"
							eval "$CHECK_ENTITY"
							if [ $? = 0 ]; then
							
								cleanup_by_force
								
								if [ $? = 0 ]; then
									printf "The InterScan Web Security Suite 3.1 MCP Agent is force stopped.\n"
								else
									printf "Try to stop it manually.\n"
								fi
							fi

					else
						eval "$CHECK_ENTITY"
						if [ $? = 0 ]; then
						
							cleanup_by_force
							
							if [ $? = 0 ]; then
								printf "force stopped.\n"
							else
								printf "Try to stop it manually.\n"
							fi
						fi
					fi
				fi
				rm -f *.CMD
				break
			fi
			LOOP=`expr $LOOP + 1`			
			sleep 10
			printf "."
		done
	else
		printf "The InterScan Web Security Suite 3.1 MCP Agent is not running!\n"
		cleanup_by_force
	fi
else
	printf "The InterScan Web Security Suite 3.1 MCP Agent is shutdown.\n"
fi
