#!/bin/sh

usage()
{
	echo "$0 <start|stop|restart>"
	exit
}

case `uname -s` in
	Linux)
		ARCH=linux
		;;
	SunOS)
		ARCH=sol
		;;
	*)
		ARCH=unknown
		echo "Unknown platform.  Stop the script."
		exit
		;;
esac

BINDIR=/usr/iwss
DATADIR=/var/iwss

JAVA_HOME=$BINDIR/AdminUI/jre
JRE_HOME=$BINDIR/AdminUI/jre
PATH=$JAVA_HOME/bin:$PATH
TOMCAT_HOME=$BINDIR/AdminUI/tomcat
PATCH_ROOT=/etc/iscan/patch
TOMCAT_PIDFILE=/etc/iscan/pids/tomcat.pids
export JAVA_HOME JRE_HOME PATH TOMCAT_HOME PATCH_ROOT


case `uname -s` in
	Linux)
		LD_LIBRARY_PATH=$BINDIR/lib/mt:$BINDIR/lib:$LD_LIBRARY_PATH
		JAVA_OPTS="-Djava.library.path=$BINDIR/lib/mt:$BINDIR/lib -Djava.awt.headless=true -Dfile.encoding=UTF-8"
		;;
	SunOS)
		LD_LIBRARY_PATH=$BINDIR/lib/st:$BINDIR/lib:$LD_LIBRARY_PATH
		JAVA_OPTS="-Djava.library.path=$BINDIR/lib/st:$BINDIR/lib -Djava.awt.headless=true -Dfile.encoding=UTF-8"
		;;
	*)
		echo "Unknown platform.  Stop the script."
		exit
		;;
esac

export LD_LIBRARY_PATH JAVA_OPTS

ODBCSYSINI=$DATADIR
ODBCINI=$DATADIR/odbc.ini
export ODBCSYSINI ODBCINI

# For Kerberos5
KRB5_CONFIG=$DATADIR/krb5.conf
export KRB5_CONFIG

# To enable Oracle to handle multibyte characters
NLS_LANG=american_america.utf8
export NLS_LANG

#Set CATALINA_OPTS
CATALINA_OPTS="-Xmx256m"
export CATALINA_OPTS

ISTOMCATALIVE()
{
	ps -ef | grep $JAVA_HOME/bin/java | grep -v "-server" | grep -v grep > /dev/null
}

PIDOFTOMCAT()
{
	PID_INDEX=2
	if ps --help 2>&1 | grep BusyBox > /dev/null ; then
		PID_INDEX=1
	fi
	ps -ef | grep $JAVA_HOME/bin/java | grep -v "-server" | grep -v grep | awk "{print \$$PID_INDEX}"
}

start()
{
#	mkdir -p $TOMCAT_HOME/logs
	$TOMCAT_HOME/bin/startup.sh
	#IWSA-3.1-00119
	sleep 3
	touch $TOMCAT_PIDFILE
	chmod 644 $TOMCAT_PIDFILE
}

stop()
{
	rm -rf $TOMCAT_PIDFILE
	$TOMCAT_HOME/bin/shutdown.sh
	# should wait for tomcat to completely finish before returning
	COUNT=0
	while ISTOMCATALIVE ; do
		sleep 1;
		COUNT=`expr $COUNT + 1`
		if [ "$COUNT" -eq "30" ] ; then
			#kill the java process
			#find the parent id
			for i in `PIDOFTOMCAT` ; do
				echo "kill $i"
				kill -TERM $i
			done
	    fi
	done

	COUNT=0
	while ISTOMCATALIVE ; do
		sleep 1;
		COUNT=`expr $COUNT + 1`
		if [ "$COUNT" -eq "30" ] ; then
			#kill the java process
			#find the parent id
			for i in `PIDOFTOMCAT` ; do
				echo "kill -KILL $i"
				kill -KILL $i
			done
	    fi
	done
}

case $1 in
	start)
		start
		;;
	stop)
		stop
		;;
	restart)
		TOMCAT_PROCESS=`ps -ef | grep -v grep | grep $JAVA_HOME/bin/java | grep -v "-server"`
	        if [  $? -eq 0  ] ; then
			stop
			start
		fi
		;;
	check)
		TOMCAT_PROCESS=`ps -ef | grep -v grep | grep $JAVA_HOME/bin/java | grep -v "-server"`
	        if [  $? -eq 0  ] ; then
			echo "start"
		else
			echo "stop"
		fi
		;;
	*)
		usage
		;;
esac

