#!/bin/sh

IWSS_HOME=/etc/iscan
BINTARGET=/usr/iwss
DATATARGET=/var/iwss
SOFTWARETARGET=/opt/trend/iwss
BINDIR=bin
DATADIR=data
CALLER=UNINSTALL
export CALLER

die()
{
	echo $@ >&2
	exit 1
}

#########################
# Detect existing version
#########################
if [ ! -e $IWSS_HOME ] ; then
    die "$IWSS_HOME directory not found. No previous version of IWSS installed."
fi

OLD_VER_NUM=`/etc/iscan/iwssd -v | awk -F"[-_ .]" '{print $2}'`
OLD_VER_NUM_2=`/etc/iscan/iwssd -v | awk -F"[-_ .]" '{print $3}'`

if [ $OLD_VER_NUM = "LINUX" -a $OLD_VER_NUM_2 = "3" ]; then
	OLD_VER_NUM=3
fi

case $OLD_VER_NUM in
    3) ;; #version 3.x - continue 
    2) die "Version 2.x detected. Please manually remove it and try again." ;; ##./uninstallIwss20.sh ;; #version 2.x
    *) die "Version 1.x or unknown detected. Please manually remove it and try again." ;; #version 1.x or unknown
esac

if [ "0" -ne `id -u` ]; then
	die "You must be root to uninstall IWSS"
fi

# Stop svcmonitor first, otherwise it restarts other daemon.
$BINTARGET/S99ISsvcmonitor stop

for SCRIPT in $BINTARGET/S99IS* ; do
	if [ $SCRIPT != $BINTARGET/S99ISdatabase -a $SCRIPT != $BINTARGET/S99ISsvcmonitor ] ; then
		$SCRIPT stop
	fi
done

if [ -f $BINTARGET/uninstalldb.sh ] ; then
	$BINTARGET/uninstalldb.sh
fi

#cleanup shared resources
if [ -x $BINTARGET/bin/cleanup ] ; then
	$BINTARGET/bin/cleanup
	if [ $? != 0 ] ; then
        	echo "WARNING: Unable to cleanup share memory used!"
	fi
fi
rm -f /tmp/temp_err.txt

if [ -x /usr/sbin/userdel ] ; then
	/usr/sbin/userdel iscan
fi
if grep iscan /etc/group > /dev/null ; then
	if [ -x /usr/sbin/groupdel ] ; then
		/usr/sbin/groupdel iscan
	fi
fi

if [ "$1" = "migration" ]; then
	# Try to backup exists MCP agent settings for migration purpose.
	
	MCP_PATH="/usr/iwss/ISAGENT_MCP"
	if [ -f $MCP_PATH/Agent.ini ]; then
		cp -fru $MCP_PATH/Agent.ini /etc/Agent.ini
		echo "Backed up '$MCP_PATH/Agent.ini' to /etc/"
	fi
	
	if [ -f $MCP_PATH/Product.ini ]; then
		cp -fru $MCP_PATH/Product.ini /etc/Product.ini
		echo "Backed up '$MCP_PATH/Product.ini' to /etc/"
	fi
fi

#remove start/stop links in rc folder
find /etc/rc.d -follow -name "*IWSS*" -exec rm -f {} \; > /dev/null 2>&1

cd -P $BINTARGET ; cd .. ; rm -rf $BINDIR
cd -P $DATATARGET ; cd .. ; rm -rf $DATADIR
rm -f $IWSS_HOME
rm -rf $SOFTWARETARGET
rm -rf $BINTARGET
rm -rf $DATATARGET

#kill the schedulereport process, if it still running
kill -9 `ps -ef | grep schedulereport | grep -v grep | awk '{print $2}'` > /dev/null 2>&1

exit 0

