#!/bin/sh

#Goto the end of file before you start to read this file.
#We assume the pwd has extracted files and dir

# Naming convention
# F_  means a subroutine

F_usage() {
	echo "Usage: $0 install_root_dir backup_dir (upload_check|apply_now) "
	echo "This script should backup for this patch, stop the daemon, apply this patch and start daemons."
}

CHECK_OR_APPLY="$1"
if [ -z "$CHECK_OR_APPLY" ] ; then
	echo "3nd argument should be either upload_check or apply_now"
	F_usage
	exit 4
fi

INSTALL_DIR="$2"
if [ -z "$INSTALL_DIR" ] ; then
	echo "1st argument should be installation directory."
	F_usage	
	exit 2
fi

if [ "${CHECK_OR_APPLY}" = "apply_now" ] ; then
		BACKUP_DIR="$3"
		if [ -z "$BACKUP_DIR" ] ; then
			echo "2nd argument should be backup directory."
			F_usage
			exit 3
		fi
fi

PATCHINFOINI=stargate_patch.ini
PATCHMGMINI=${INSTALL_DIR}/patch/config/patch_management.ini

. ./ini_util.sh
. ./stargate_patch_common.sh

PATCH_NUMBER=`F_ini_get $PATCHINFOINI PatchInfo Number`
#
# Update a patch file record 
# param: patch_file_info_line
# 
# return 0
#
F_add_to_patch_record(){

	_file_info="$1"
	_SECTION="$2"
	_num_files=`F_ini_get ${PATCHMGMINI} ${_SECTION} NumberOfAppliedFiles`
	_i=0
	if [ -z "$_num_files" ] ; then
		_num_files=0
	fi
	while [ $_i -lt $_num_files ] ; do

	    _fpath=`P_get_file_info ${PATCHMGMINI} ${_SECTION} $_i path`
		# This one already exist, so overwrite it
		if [ "$_fpath" = "$_filepath" ] ; then
			F_ini_add_key "$PATCHMGMINI" "$_SECTION" "File$_index" "$_file_info"
			return 0	
		fi

		 _i=`expr $_i + 1 `
	done

	#add a new key value
	F_ini_add_key "$PATCHMGMINI" "$_SECTION" "File$_num_files" "$_file_info"
	_new_num_files=`expr $_num_files + 1`
	F_ini_add_key "$PATCHMGMINI" "$_SECTION" "NumberOfAppliedFiles" "$_new_num_files"
	
	return 1
}


#
# detect if a newer patch file is on the system
# param: full path
# param: file version that is going to apply
#
# return: 0 if the system has a newer patch
#
F_detect_previous_patch_file(){

	_filepath="$1"
	_fileversion="$2"
	_num_files=`F_ini_get ${PATCHMGMINI} AppliedFileRecord NumberOfAppliedFiles`
	_i=0
	if [ -z "$_num_files" ] ; then
		return 1
	fi
	while [ $_i -lt $_num_files ] ; do

	    _fpath=`P_get_file_info ${PATCHMGMINI} AppliedFileRecord $_i path`
		#echo "debug ${_fpath}"
		if [ "$_fpath" = "$_filepath" ] ; then
			_ver=`P_get_file_info ${PATCHMGMINI} AppliedFileRecord $_i version`
			#echo "debug ver ${_ver} para ${_fileversion}"
			if [ $_ver -gt $_fileversion ] ; then
				echo "The system has $_filepath version $_ver."
				return 0
			fi
		fi

		 _i=`expr $_i + 1 `
	done
	return 1
}

# backup a list of files to a dir
# $1 install root dir 
# $2 backup dir
F_backup(){

	echo "Backing up the files that are going to be overwritten."
	#echo "If the system has a newer patch, it is kept."
	_index=0
	_install_root=$1
	_backup_dir=$2

	_backup_file_list=
	_smart_backup_file_list=
	_smart_backup_root=smart_backup_root/

	_number_of_file_items=`F_ini_get $PATCHINFOINI PatchInfo NumberOfFileItems`
	if [ $? -ne 0 ] ; then
		echo "Cannot get number of files in the patch ini."
		return 1
	fi
	_smart_backup=`F_ini_get $PATCHINFOINI PatchInfo SmartBackup`
	if [ $? -ne 0 ] ; then
		echo "Default patch ini SmartBackup is 1."
		_smart_backup=1
	fi

	#backup applied record into tmp #force delete previous tmp 
	F_ini_delete_section "$PATCHMGMINI" "$TMP_SECTION" > /dev/null 
	_orig_section=`F_ini_get_section    "$PATCHMGMINI" "$APPLIED_RECORD_SECTION"`
	if [ $? -ne 0 ] ; then
		echo "The $PATCHMGMINI $APPLIED_RECORD_SECTION is empty."
	fi
	F_ini_append_section "$PATCHMGMINI" "$TMP_SECTION" "$_orig_section"


	while [ "$_index" -lt $_number_of_file_items ]
	do
		_fileName=`P_get_file_info $PATCHINFOINI PatchInfo $_index name`
		_fullPath=`P_get_file_info $PATCHINFOINI PatchInfo $_index path`
		_thisVersion=`P_get_file_info $PATCHINFOINI PatchInfo $_index version`
		#if the system has newer version, we won't backup
		F_detect_previous_patch_file ${_fullPath} ${_thisVersion}	
		if [ "$?" = "0" ] ; then	
			if [ "$_smart_backup" = "1" ] ; then
				echo "Smart backup ${_fullPath}."
				_smart_backup_file=${_smart_backup_root}/${_fullPath}

				#cp the smart backup to a specific sub dir
				mkdir -p `dirname ${_smart_backup_file}`
				cp -a files/$_fileName $_smart_backup_file

				#set right mode and permission before going into smart backup
				_owner=`P_get_file_info $PATCHINFOINI PatchInfo $_index owner`
				if [ -n "$_owner" ] ; then
					chown $_owner $_smart_backup_file
				fi
				_permission=`P_get_file_info $PATCHINFOINI PatchInfo $_index permission`
				if [ -n "$_permission" ] ; then
					chmod $_permission $_smart_backup_file
				fi

				#delete the first '/' is it exist
				_my_first_char=`expr substr "$_fullPath" 1 1`
				if [ "$_my_first_char" = "/" ] ; then
					_fullPath=`echo $_fullPath | sed -e 's/^.//'`
				fi
				_smart_backup_file_list="${_smart_backup_file_list} ${_fullPath}"
				echo "Add ${_fullPath} to smart backup"
	
				#add smart backup to the backup record
				#they will be rolling back into this version
				_f_info=`P_get_file_info $PATCHINFOINI PatchInfo $_index all`
				F_add_to_patch_record "$_f_info" "$TMP_SECTION"
	
			else
				echo "Skip backup ${_fullPath}."
			fi
		#copy to the backup dir
		elif [ -f "$_fullPath" ]; then
			_backup_file_list="$_backup_file_list $_fullPath"
			echo "Add $_fullPath to normal backup."
		else
			echo "Warning: The file $_fullPath is not readable. We won't backup this file."
		fi

		_index=`expr $_index + 1`
	done

	#normal backup
	if [ -n "$_backup_file_list" ] ; then
		echo "Writing backup $BACKUP_TAR."
		tar zcvf "$_backup_dir/$BACKUP_TAR" $_backup_file_list
	else
		echo "No backup files needed. $BACKUP_TAR is not generated."
	fi
	#smart backup
	if [ -n "$_smart_backup_file_list" ] ; then
		echo "Writing smart backup $SMART_BACKUP_TAR."
		tar zcvf "$_backup_dir/$SMART_BACKUP_TAR" -C "${_smart_backup_root}" ${_smart_backup_file_list}
	else
		echo "No smart backup files needed. $SMART_BACKUP_TAR is not generated."
	fi

	#also save ini and sh
	cp -a *.ini *.sh $_backup_dir

	# Backup patch_management.ini
	cp -a /etc/iscan/patch/config/patch_management.ini $_backup_dir

	return 0

}

#
# F_verify
# Make sure the patch has what it said it contains
#
F_verify(){

	echo "Verifying the files in the patch."
	_index=0
	_install_root=$1
	_number_of_file_items=`F_ini_get $PATCHINFOINI PatchInfo NumberOfFileItems`
	if [ $? -ne 0 ] ; then
		echo "Cannot get number of files in the patch ini."
		return 1
	fi
	while [ "$_index" -lt $_number_of_file_items ]
	do
		_fullPath=`P_get_file_info $PATCHINFOINI PatchInfo $_index path`
		
		#make sure the patch contains the file it said
		_patchFile=`P_get_file_info $PATCHINFOINI PatchInfo $_index name`
		if [ -z "$_patchFile" ] ; then
			echo "The patch ini file $PATCHINFOINI should have correct file info."
			return 5
		fi
		_patchPath="files/$_patchFile"

		if [ ! -f "$_patchPath" ] ; then
			echo "The patch file $_patchPath was not available. The patch may be corrupted."
			return 4
		fi

		_index=`expr $_index + 1`
	done
	echo "Verification OK."
	return 0
}




#
# F_apply
# If it returns non-zero, make sure it's not a half-way apply. This function should take care of itself.
#
F_apply() {
	echo "Applying the patch files."
	_index=0
	_install_root=$1
	
	# add for ARM Integration Hotfix	
	mkdir -p /etc/iscan/arm_scripts
	mkdir -p /opt/trend/iwss/bin/ImportExport/bin
	mkdir -p /opt/trend/iwss/bin/ImportExport/config
	
	_number_of_file_items=`F_ini_get $PATCHINFOINI PatchInfo NumberOfFileItems`
	if [ $? -ne 0 ] ; then
		echo "Cannot get number of files in the patch ini."
		return 4
	fi	

	#copy the files and set owner, permission
	while [ "$_index" -lt $_number_of_file_items ]
	do
		_fullPath=`P_get_file_info $PATCHINFOINI PatchInfo $_index path`
		_patchFile=`P_get_file_info $PATCHINFOINI PatchInfo $_index name`
		_patchPath="files/$_patchFile"
		_thisVersion=`P_get_file_info $PATCHINFOINI PatchInfo $_index version`
	
		# don't copy it there is a newer version
		F_detect_previous_patch_file ${_fullPath} ${_thisVersion}	
		if [ "$?" = "0" ] ; then
			#smart apply
			_smart_apply=`F_ini_get $PATCHINFOINI PatchInfo SmartApply`
			if [ "$_smart_apply" = "1" ] ; then
				echo "Thie file ${_fullPath} is kept because it is a newer version."
				_index=`expr $_index + 1`
				continue
			else
				echo "Overwriting newer version file ${_fullPath}."	
			fi
		else
			echo "No previous patch file of ${_fullPath}."
		fi
	
		if [ -L "$_fullPath" ] ; then
			echo "Warning: $_fullPath is a symbolic link."
		fi
		if [ -f "$_fullPath" ] ; then
			printf "%s" "<"
			ls -l $_fullPath
		fi
		# mv $_fullPath /dev/null	
		cp -a $_patchPath $_fullPath 
		if [ $? -ne 0 ] ; then
			echo "Unable to overwrite $_fullPath with patch $_patchPath."
			_index=`expr $_index + 1`
			continue
		fi
		#echo "Copied $_fullPath from $_patchFile"
		#optionally set owner and permission
		_owner=`P_get_file_info $PATCHINFOINI PatchInfo $_index owner`
		if [ -n "$_owner" ] ; then
			chown $_owner $_fullPath
			#if [ "$?" = "0" ] ; then
				#echo "Changed file owner to $_owner."
			#fi
		fi
		_permission=`P_get_file_info $PATCHINFOINI PatchInfo $_index permission`
		if [ -n "$_permission" ] ; then
			chmod $_permission $_fullPath
			#if [ "$?" = "0" ] ; then
				#echo "Changed file permission to $_permission."
			#fi
		fi
			
		if [ -f "$_fullPath" ] ; then
			printf "%s" ">"
			ls -l $_fullPath
		fi

		# record this file in the patchmanagement.ini
		
		_f_info=`P_get_file_info $PATCHINFOINI PatchInfo $_index all`
		F_add_to_patch_record "$_f_info" "$TMP_SECTION"
		
		_index=`expr $_index + 1`
	done

	#delete backup if any
	F_ini_delete_section $PATCHMGMINI "${PATCH_NUMBER}_${BACKUP_APPLIED_RECORD_SECTION}" 

	#rename current to backup
	F_ini_rename_section $PATCHMGMINI "$APPLIED_RECORD_SECTION" "${PATCH_NUMBER}_${BACKUP_APPLIED_RECORD_SECTION}"

	#rename tmp to current
	F_ini_rename_section $PATCHMGMINI "$TMP_SECTION" "$APPLIED_RECORD_SECTION" 
	return 0

}

F_update_ini() {
	echo "Updating the patch management ini file."
	_section=`F_ini_get_section $PATCHINFOINI PatchInfo` 

	F_ini_append_section $PATCHMGMINI "$PATCH_NUMBER" "$_section" 
	if [ $? -ne 0 ] ; then
		return 1
	fi
	F_ini_add_applied_list $PATCHMGMINI "$PATCH_NUMBER"

	#
	# Set the AppliedDate
	#
	_trend_format_date=`date "+%m/%d/%Y %H:%M:%S"`
	F_ini_set $PATCHMGMINI "$PATCH_NUMBER" "AppliedDate"  "$_trend_format_date"

	#
	#
	# Disable all rollbacks except for myself
	# It's means only the last one can be rollback. Even if the last one is rollback, the last second one can't be rollback.
	# This is due to storage constraints.
    #
	#

	_applied_patches=`F_ini_get $PATCHMGMINI PatchManagement AppliedPatches`
	for i in $_applied_patches 
	do
		if [ "$PATCH_NUMBER" = "$i" ] ; then
			F_ini_set $PATCHMGMINI "$i" "Rollback" "1"
			#echo "Set $i rollback to 1."
		else
			F_ini_set $PATCHMGMINI "$i" "Rollback" "0"
			#echo "Set $i rollback to 0."
		fi	
	done

}

F_check_required_fields() {

	if [ ! -f "$PATCHMGMINI" ] ; then
		echo "Cannot find $PATCHMGMINI."
		return 1
	fi
	if [ ! -f "$PATCHINFOINI" ] ; then
		echo "Cannot find $PATCHINFOINI."
		return 1
	fi

	_number_of_file_items=`F_ini_get $PATCHINFOINI PatchInfo NumberOfFileItems`
	if [ $? -ne 0 ] ; then
		echo "Cannot find [PatchInfo] Number of FileOfFileItems in $PATCHMGMINI."
		return 1
	fi
	return 0

}

F_check_build_number()
{
	_patch_build_number=`F_ini_get $PATCHINFOINI PatchInfo Build`
	_current_build_number=`/usr/iwss/iwssd -v | cut -d" " -f2 | cut -d_ -f4`
	if [ 0 -eq "$_current_build_number" ] ; then
		echo "Failed to retrieve installed IWSS build number"
		return 1
	fi
	if [ 0 -eq "$_patch_build_number" ] ; then
		echo "Cannot get build number for this patch.  Install anyway."
		return 0
	fi
	if [ "$_current_build_number" -ge "$_patch_build_number" ] ; then
		echo "Installed build number ($_current_build_number) is greater than or equal to the patch build number ($_patch_build_number)"
		return 2
	fi
	echo "Build number check OK ($_patch_build_number for this patch vs $_current_build_number installed)"
	return 0
}

F_check_build_minimum()
{
	_current_build_number=`/usr/iwss/iwssd -v | cut -d" " -f2 | cut -d_ -f4`
	_patch_required_number=`F_ini_get $PATCHINFOINI PatchInfo MinBld`
	if [ 0 -eq "$_patch_required_number" ] ; then
		echo "Cannot get required build number for this patch.  Install anyway."
		return 0
	fi
	if [ "$_current_build_number" -lt "$_patch_required_number" ] ; then
		echo "Current build ($_current_build_number) is older than the required build ($_patch_required_number)"
		echo "Please patch your system to at least build ($_patch_required_number) before applying this update"
		return 2
	fi
	return 0
}

F_check_IWSS_version()
{
	_expected_IWSS_version=3.1
	_current_IWSS_version=`/usr/iwss/iwss-process -v|cut -d " " -f2 | cut -d "_" -f1 | cut -d "-" -f1`
	if [ "$_expected_IWSS_version" = "$_current_IWSS_version" ] ; then
	echo "The IWSS version is 3.1"
	return 0
	else 
    echo "The IWSS version is not 3.1, Quit"
    return 2	
	fi
}

F_check_dependency() {
	#echo "Checking Dependency."
	
	_applied_patches=`F_ini_get $PATCHMGMINI PatchManagement AppliedPatches`
	
	#stop if the patch number is already in AppliedPatches..
	for i in $_applied_patches 
	do
		if [ "$PATCH_NUMBER" = "$i" ] ; then
			echo "Cannot apply this patch. The patch script has detected a same patch number."
			return 2
		fi
	done
	#delete the section if there is an old section
	F_ini_get_section $PATCHMGMINI $PATCH_NUMBER > /dev/null 2>&1
	if [ $? -eq 0 ] ; then
		echo "The patch section is still in $PATCHMGMINI. The old section will overwritten."
		
		F_ini_delete_section $PATCHMGMINI $PATCH_NUMBER
	fi
	echo "Dependency Check OK."
	return 0
}

F_check_requirement() {
	#Return error if I require a patch that doesn't exist.

	_requires_number=`F_ini_get $PATCHINFOINI PatchInfo Requires`
	if [ -z "$_requires_number" ] ; then
		return 0	
	fi
	if [ -n "$_requires_number" ] ; then

		_found_require=0
		for j in $_applied_patches 
		do
			if [ "$_requires_number" = "$j" ] ; then
				_found_require=1
			fi
		done
		if [ "$_found_require" = "0" ] ; then
			echo "Cannot find the required previous patch $_requires_number."
			return 3
		fi
	fi
	
	return 0
}


F_upload_check() {

		F_check_required_fields
		if [ $? -ne 0 ] ; then
			F_log "The patch format is incorrect. Please check required fields in the configuration file."
			exit $ERR_REQ
		fi
		
		F_check_IWSS_version
		if [ $? -ne 0 ] ; then
			F_log "Build version incorrect. Exit."
			exit $ERR_APP
		fi
		
		F_check_build_number
		if [ $? -ne 0 ] ; then
			F_log "Cannot pass build check. Exit."
			exit $ERR_DEP
		fi

		F_check_dependency 
		if [ $? -ne 0 ] ; then
			F_log "Cannot pass dependency check. Exit."
			exit $ERR_DEP
		fi

		F_check_requirement
		if [ $? -ne 0 ] ; then
			F_log "Cannot pass requirement check. Exit."
			exit $ERR_REQ_P
		fi

		F_check_build_minimum
		if [ $? -ne 0 ] ; then
			F_log "Cannot pass minimum build check. Exit."
			exit $ERR_REQ_P
		fi
		
		F_verify 		$INSTALL_DIR 
		if [ $? -ne 0 ] ; then
			F_log "Cannot verify the patch. Exit."
			exit $ERR_VER
		fi
}

F_create_sym_link()
{
######################################################
# Added for SEG TRK #139436
# Create symbolic link for libodbcpsql.so
######################################################
                
                if [ -f /usr/iwss/lib/libodbcpsql.so.2.0 ] ; then
                        mv -f /usr/iwss/lib/libodbcpsql.so.2.0 /usr/iwss/lib/libodbcpsql.so.orig.so.2.0
                fi
                        ln -s /usr/iwss/lib/libodbcpsql.so.2.0.0 /usr/iwss/lib/libodbcpsql.so.2.0

                if [ -f /usr/iwss/lib/libodbcpsql.so.2 ] ; then
                        mv -f /usr/iwss/lib/libodbcpsql.so.2 /usr/iwss/lib/libodbcpsql.so.orig.2
                fi
                        ln -s /usr/iwss/lib/libodbcpsql.so.2.0 /usr/iwss/lib/libodbcpsql.so.2

                if [ -f /usr/iwss/lib/libodbcpsql.so ] ; then
                        mv -f /usr/iwss/lib/libodbcpsql.so /usr/iwss/lib/libodbcpsql.orig.so
                fi
                	ln -s /usr/iwss/lib/libodbcpsql.so.2 /usr/iwss/lib/libodbcpsql.so


}
F_apply_now() {
		#################################################
		# Custom action for IWSS 3.0 patch
		
		
		# No action defined at this time
		
		#################################################
		
		F_backup 		$INSTALL_DIR $BACKUP_DIR
		if [ $? -ne 0 ] ; then
			F_log "Cannot backup the system successfully. Exit."
			exit $ERR_BAK
		fi

		F_stop_daemons 	$INSTALL_DIR

		F_apply 		$INSTALL_DIR $BACKUP_DIR
		if [ $? -ne 0  ] ; then
			F_log "Cannot apply patch successfully. Rolling back."
			F_rollback $INSTALL_DIR $BACKUP_DIR	
			echo "Start the daemons and exit."
			F_start_daemons $INSTALL_DIR
			exit $ERR_APP
		fi

	    if [ -f /usr/iwss/lib/libodbcpsql.orig.so ] ; then
        F_log "No need to update SYM"
        else 
                F_create_sym_link
	         	F_log "Creating symbolic link for PostgreSQL"
        fi
        echo "Clear JSP Cache" 
                ###############################################
                #Update Tomcat to 5.5.31
                ###############################################
                tar -zcvf /opt/trend/iwss/data/AdminUI/tomcat/tomcatbak5527.tgz /opt/trend/iwss/data/AdminUI/tomcat/*
                rm -rf /opt/trend/iwss/data/AdminUI/tomcat/bin
                rm -rf /opt/trend/iwss/data/AdminUI/tomcat/server
                rm -rf /opt/trend/iwss/data/AdminUI/tomcat/common
                tar -zxvf /opt/trend/iwss/data/AdminUI/tomcat/tomcat5531.tgz -C /opt/trend/iwss/data/AdminUI/tomcat/
                chown -R iscan:iscan /usr/iwss/AdminUI/tomcat/bin /usr/iwss/AdminUI/tomcat/server /usr/iwss/AdminUI/tomcat/common
                chmod 755 /usr/iwss/AdminUI/tomcat/bin
                rm -rf /usr/iwss/AdminUI/tomcat/work/Standalone/localhost/_/org/apache/jsp/*
                ############################################### 
                #A FR for access and URL blocking log export
                tar -zxvf /etc/iscan/log2csv.tgz -C /etc/iscan/
                rm -rf /etc/iscan/log2csv.tgz
                ###############################################  
                #echo Remove unnessrary update items...
                #touch /var/iwss/intscan_tmp.ini
                #sed '/Imp2p_type.*/'d /var/iwss/intscan.ini>/var/iwss/intscan_tmp.ini
                #cp --reply=yes /var/iwss/intscan_tmp.ini /var/iwss/intscan.ini
                #sed '/Imp2p_starthour.*/'d /var/iwss/intscan.ini>/var/iwss/intscan_tmp.ini
                #cp --reply=yes /var/iwss/intscan_tmp.ini /var/iwss/intscan.ini
                #sed '/Imp2p_startminute.*/'d /var/iwss/intscan.ini>/var/iwss/intscan_tmp.ini
                #cp --reply=yes /var/iwss/intscan_tmp.ini /var/iwss/intscan.ini
                #sed '/Imp2p_frequency.*/'d /var/iwss/intscan.ini>/var/iwss/intscan_tmp.ini
                #cp --reply=yes /var/iwss/intscan_tmp.ini /var/iwss/intscan.ini
                #echo Remove unnessrary update items done              
                #################################################
		F_update_ini    $INSTALL_DIR 
		#if possible, rollback ini when failed....
		F_start_daemons $INSTALL_DIR
		F_log "The patch script is finished."
		exit 0
}

if [ "$CHECK_OR_APPLY" = "apply_now" ] ; then
	#check again just to make sure
	F_upload_check  
	F_apply_now
elif [ "$CHECK_OR_APPLY" = "upload_check" ] ; then
	F_upload_check
fi
